@@ -39,14 +39,14 @@ SKGAdvicePlugin::~SKGAdvicePlugin()
     currentDocument = nullptr;
 }
 
-bool SKGAdvicePlugin::setupActions(SKGDocument* iDocument)
+bool SKGAdvicePlugin::setupActions(SKGDocument *iDocument)
 {
     SKGTRACEINFUNC(10)
 
     currentDocument = iDocument;
 
-    setComponentName(QLatin1String("skg_advice"), title());
-    setXMLFile(QLatin1String("skg_advice.rc"));
+    setComponentName(QStringLiteral("skg_advice"), title());
+    setXMLFile(QStringLiteral("skg_advice.rc"));
 
     // Create yours actions here
     return true;
@@ -67,7 +67,7 @@ QString SKGAdvicePlugin::getDashboardWidgetTitle(int iIndex)
     return i18nc("Noun, a list of items", "Tip of the day");
 }
 
-SKGBoardWidget* SKGAdvicePlugin::getDashboardWidget(int iIndex)
+SKGBoardWidget *SKGAdvicePlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) {
         return new SKGAdviceBoardWidget(SKGMainPanel::getMainPanel(), currentDocument);
@@ -82,7 +82,7 @@ QString SKGAdvicePlugin::title() const
 
 QString SKGAdvicePlugin::icon() const
 {
-    return QLatin1String("help-hint");
+    return QStringLiteral("help-hint");
 }
 
 QString SKGAdvicePlugin::toolTip() const
@@ -98,8 +98,10 @@ int SKGAdvicePlugin::getOrder() const
 QStringList SKGAdvicePlugin::tips() const
 {
     QStringList output;
-    output.push_back(i18nc("Description of a tip", "<p>… Skrooge can give you advice on how to manage your accounts. See the <a href=\"skg://dashboard_plugin\">dashboard</a>.</p>"));
-    output.push_back(i18nc("Description of a tip", "<p>… Skrooge can automatically apply recommended corrections. See the <a href=\"skg://dashboard_plugin\">dashboard</a>.</p>"));
+    output.push_back(i18nc("Description of a tip",
+                           "<p>… Skrooge can give you advice on how to manage your accounts. See the <a href=\"skg://dashboard_plugin\">dashboard</a>.</p>"));
+    output.push_back(i18nc("Description of a tip",
+                           "<p>… Skrooge can automatically apply recommended corrections. See the <a href=\"skg://dashboard_plugin\">dashboard</a>.</p>"));
     return output;
 }
 
