@@ -100,12 +100,6 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument *iDocument)
         m_bookmarkMenu->setProperty("id", 0);
         connect(m_bookmarkMenu, &QMenu::aboutToShow, this, &SKGBookmarkPlugin::onShowBookmarkMenu);
     }
-#ifdef SKG_QT6
-
-#else
-    actBookmark->setStickyMenu(false);
-    actBookmark->setDelayed(false);
-#endif
     actBookmark->setData(0);
     actBookmark->setPriority(QAction::LowPriority);
 
