@@ -32,9 +32,18 @@
 #include "skgzoomselector.h"
 #include <utility>
 
-SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument, QMenu* iMenu)
-    : SKGWidget(iParent, iDocument), m_flowLayout(nullptr), m_menu(nullptr), m_addMenu(nullptr),
-      m_layoutF(nullptr), m_layout1(nullptr), m_layout2(nullptr), m_layout3(nullptr), m_layout4(nullptr), m_content(nullptr), m_layout(0)
+SKGDashboardWidget::SKGDashboardWidget(QWidget *iParent, SKGDocument *iDocument, QMenu *iMenu)
+    : SKGWidget(iParent, iDocument)
+    , m_flowLayout(nullptr)
+    , m_menu(nullptr)
+    , m_addMenu(nullptr)
+    , m_layoutF(nullptr)
+    , m_layout1(nullptr)
+    , m_layout2(nullptr)
+    , m_layout3(nullptr)
+    , m_layout4(nullptr)
+    , m_content(nullptr)
+    , m_layout(0)
 {
     SKGTRACEINFUNC(1)
     if (iDocument == nullptr) {
@@ -52,7 +61,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         m_menu = new QMenu(this);
 
         connect(this, &SKGDashboardWidget::customContextMenuRequested, this, &SKGDashboardWidget::showHeaderMenu);
-        m_addMenu = m_menu->addMenu(SKGServices::fromTheme(QLatin1String("configure")),  i18nc("Verb", "Configure the dashboard"));
+        m_addMenu = m_menu->addMenu(SKGServices::fromTheme(QStringLiteral("configure")), i18nc("Verb", "Configure the dashboard"));
     }
 
     auto verticalLayout = new QVBoxLayout(this);
@@ -115,12 +124,12 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
     // Build menu
     if (m_addMenu != nullptr) {
         // Add layouts sub menu
-        auto layoutMenu = m_addMenu->addMenu(SKGServices::fromTheme(QLatin1String("labplot-editbreaklayout")),  i18nc("Verb", "Choose layout …"));
+        auto layoutMenu = m_addMenu->addMenu(SKGServices::fromTheme(QStringLiteral("labplot-editbreaklayout")), i18nc("Verb", "Choose layout …"));
         auto alignmentGroup = new QActionGroup(this);
         {
             m_layoutF = layoutMenu->addAction(i18nc("Verb", "Flow"));
             if (m_layoutF != nullptr) {
-                m_layoutF->setIcon(SKGServices::fromTheme(QLatin1String("text-flow-into-frame")));
+                m_layoutF->setIcon(SKGServices::fromTheme(QStringLiteral("text-flow-into-frame")));
                 m_layoutF->setCheckable(true);
                 m_layoutF->setData(0);
                 connect(m_layoutF, &QAction::triggered, this, &SKGDashboardWidget::onChangeLayout);
@@ -131,7 +140,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         {
             m_layout1 = layoutMenu->addAction(i18nc("Verb", "1 column"));
             if (m_layout1 != nullptr) {
-                m_layout1->setIcon(SKGServices::fromTheme(QLatin1String("object-columns")));
+                m_layout1->setIcon(SKGServices::fromTheme(QStringLiteral("object-columns")));
                 m_layout1->setCheckable(true);
                 m_layout1->setData(1);
                 connect(m_layout1, &QAction::triggered, this, &SKGDashboardWidget::onChangeLayout);
@@ -142,7 +151,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         {
             m_layout2 = layoutMenu->addAction(i18nc("Verb", "2 columns"));
             if (m_layout2 != nullptr) {
-                m_layout2->setIcon(SKGServices::fromTheme(QLatin1String("object-columns")));
+                m_layout2->setIcon(SKGServices::fromTheme(QStringLiteral("object-columns")));
                 m_layout2->setCheckable(true);
                 m_layout2->setData(2);
                 connect(m_layout2, &QAction::triggered, this, &SKGDashboardWidget::onChangeLayout);
@@ -153,7 +162,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         {
             m_layout3 = layoutMenu->addAction(i18nc("Verb", "3 columns"));
             if (m_layout3 != nullptr) {
-                m_layout3->setIcon(SKGServices::fromTheme(QLatin1String("object-columns")));
+                m_layout3->setIcon(SKGServices::fromTheme(QStringLiteral("object-columns")));
                 m_layout3->setCheckable(true);
                 m_layout3->setData(3);
                 connect(m_layout3, &QAction::triggered, this, &SKGDashboardWidget::onChangeLayout);
@@ -164,7 +173,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         {
             m_layout4 = layoutMenu->addAction(i18nc("Verb", "4 columns"));
             if (m_layout4 != nullptr) {
-                m_layout4->setIcon(SKGServices::fromTheme(QLatin1String("object-columns")));
+                m_layout4->setIcon(SKGServices::fromTheme(QStringLiteral("object-columns")));
                 m_layout4->setCheckable(true);
                 m_layout4->setData(4);
                 connect(m_layout4, &QAction::triggered, this, &SKGDashboardWidget::onChangeLayout);
@@ -183,20 +192,20 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         int added = 0;
         auto currentMenu = m_addMenu;
         while (index >= 0) {
-            SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
+            SKGInterfacePlugin *plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
             if (plugin != nullptr) {
                 int nbdbw = plugin->getNbDashboardWidgets();
                 for (int j = 0; j < nbdbw; ++j) {
                     added++;
                     if (added % 10 == 0) {
-                        currentMenu = currentMenu->addMenu(SKGServices::fromTheme(QLatin1String("list-add")),  i18nc("Verb", "More …"));
+                        currentMenu = currentMenu->addMenu(SKGServices::fromTheme(QStringLiteral("list-add")), i18nc("Verb", "More …"));
                     }
 
                     // Create menu
-                    QAction* act = currentMenu->addAction(plugin->getDashboardWidgetTitle(j));
+                    QAction *act = currentMenu->addAction(plugin->getDashboardWidgetTitle(j));
                     if (act != nullptr) {
                         act->setIcon(SKGServices::fromTheme(plugin->icon()));
-                        act->setData(QString(plugin->objectName() % QLatin1Char('-') % SKGServices::intToString(j)));
+                        act->setData(QString(plugin->objectName() % u'-' % SKGServices::intToString(j)));
 
                         connect(act, &QAction::triggered, this, &SKGDashboardWidget::onAddWidget);
                     }
@@ -229,10 +238,10 @@ SKGDashboardWidget::~SKGDashboardWidget()
 QString SKGDashboardWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QLatin1String("SKGML"));
-    QDomElement root = doc.createElement(QLatin1String("parameters"));
+    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomElement root = doc.createElement(QStringLiteral("parameters"));
     doc.appendChild(root);
-    root.setAttribute(QLatin1String("layout"), m_layout);
+    root.setAttribute(QStringLiteral("layout"), m_layout);
 
     int nb = m_items.count();
     for (int i = 0; i < nb; ++i) {
@@ -240,26 +249,26 @@ QString SKGDashboardWidget::getState()
         root.appendChild(element);
 
         QStringList param = SKGServices::splitCSVLine(m_items.at(i), '-');
-        SKGBoardWidget* item = m_itemsPointers.at(i);
+        SKGBoardWidget *item = m_itemsPointers.at(i);
         if (item != nullptr) {
-            element.setAttribute(QLatin1String("name"), param.at(0));
-            element.setAttribute(QLatin1String("index"), param.at(1));
-            element.setAttribute(QLatin1String("state"), item->getState());
-            element.setAttribute(QLatin1String("zoom"), SKGServices::intToString(item->getZoomRatio() * 5 - 15));
+            element.setAttribute(QStringLiteral("name"), param.at(0));
+            element.setAttribute(QStringLiteral("index"), param.at(1));
+            element.setAttribute(QStringLiteral("state"), item->getState());
+            element.setAttribute(QStringLiteral("zoom"), SKGServices::intToString(item->getZoomRatio() * 5 - 15));
         }
     }
     return doc.toString();
 }
 
-void SKGDashboardWidget::setState(const QString& iState)
+void SKGDashboardWidget::setState(const QString &iState)
 {
     SKGTRACEINFUNC(10)
 
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString layout = root.attribute(QLatin1String("layout"));
+    QString layout = root.attribute(QStringLiteral("layout"));
     if (!layout.isEmpty()) {
         m_layout = SKGServices::stringToInt(layout);
     }
@@ -267,7 +276,7 @@ void SKGDashboardWidget::setState(const QString& iState)
     // Initialisation
     int nb = (m_flowLayout != nullptr ? m_flowLayout->count() : 0);
     for (int i = 0; i < nb; ++i) {
-        SKGBoardWidget* item = m_itemsPointers.at(0);
+        SKGBoardWidget *item = m_itemsPointers.at(0);
         if (item != nullptr) {
             m_flowLayout->removeWidget(item);
             item->hide();
@@ -294,17 +303,17 @@ void SKGDashboardWidget::setState(const QString& iState)
     while (index > 0) {
         QDomElement element = root.firstChildElement("ITEM-" % SKGServices::intToString(index));
         if (!element.isNull()) {
-            SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByName(element.attribute(QLatin1String("name")));
-            QString indexString = element.attribute(QLatin1String("index"));
+            SKGInterfacePlugin *plugin = SKGMainPanel::getMainPanel()->getPluginByName(element.attribute(QStringLiteral("name")));
+            QString indexString = element.attribute(QStringLiteral("index"));
             if (indexString.isEmpty()) {
                 indexString = '0';
             }
-            QString zoom = element.attribute(QLatin1String("zoom"));
+            QString zoom = element.attribute(QStringLiteral("zoom"));
             if (zoom.isEmpty()) {
                 zoom = '0';
             }
             if (plugin != nullptr) {
-                addItem(plugin, SKGServices::stringToInt(indexString), SKGServices::stringToInt(zoom), element.attribute(QLatin1String("state")));
+                addItem(plugin, SKGServices::stringToInt(indexString), SKGServices::stringToInt(zoom), element.attribute(QStringLiteral("state")));
             }
         } else {
             index = -1;
@@ -313,11 +322,11 @@ void SKGDashboardWidget::setState(const QString& iState)
     }
 
     // In case of reset
-    if (m_items.isEmpty() && root.attribute(QLatin1String("zoomPosition")).isEmpty()) {
+    if (m_items.isEmpty() && root.attribute(QStringLiteral("zoomPosition")).isEmpty()) {
         int index2 = 0;
         while (index2 >= 0) {
-            SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index2);
-            if (plugin != nullptr && dynamic_cast<SKGDashboardPlugin*>(plugin) == nullptr) {
+            SKGInterfacePlugin *plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index2);
+            if (plugin != nullptr && dynamic_cast<SKGDashboardPlugin *>(plugin) == nullptr) {
                 int nb2 = plugin->getNbDashboardWidgets();
                 for (int j = 0; j < nb2; ++j) {
                     addItem(plugin, j);
@@ -330,9 +339,9 @@ void SKGDashboardWidget::setState(const QString& iState)
     }
 }
 
-QList< QWidget* > SKGDashboardWidget::printableWidgets()
+QList<QWidget *> SKGDashboardWidget::printableWidgets()
 {
-    QList< QWidget* > output;
+    QList<QWidget *> output;
     output.reserve(m_itemsPointers.count());
     for (auto w : std::as_const(m_itemsPointers)) {
         output.push_back(w);
@@ -341,7 +350,7 @@ QList< QWidget* > SKGDashboardWidget::printableWidgets()
     return output;
 }
 
-bool SKGDashboardWidget::eventFilter(QObject* iObject, QEvent* iEvent)
+bool SKGDashboardWidget::eventFilter(QObject *iObject, QEvent *iEvent)
 {
     if ((iEvent != nullptr) && iEvent->type() == QEvent::HoverLeave) {
         // Leave widget
@@ -349,20 +358,16 @@ bool SKGDashboardWidget::eventFilter(QObject* iObject, QEvent* iEvent)
         return true;
     }
 
-    if ((iEvent != nullptr) && (iObject != nullptr) &&
-        (iEvent->type() == QEvent::MouseButtonPress ||
-         iEvent->type() == QEvent::MouseButtonRelease ||
-         iEvent->type() == QEvent::MouseMove ||
-         iEvent->type() == QEvent::DragEnter ||
-         iEvent->type() == QEvent::DragMove ||
-         iEvent->type() == QEvent::Drop ||
-         iEvent->type() == QEvent::HoverMove)) {
+    if ((iEvent != nullptr) && (iObject != nullptr)
+        && (iEvent->type() == QEvent::MouseButtonPress || iEvent->type() == QEvent::MouseButtonRelease || iEvent->type() == QEvent::MouseMove
+            || iEvent->type() == QEvent::DragEnter || iEvent->type() == QEvent::DragMove || iEvent->type() == QEvent::Drop
+            || iEvent->type() == QEvent::HoverMove)) {
         // Search SKGBoardWidget corresponding to this widget
-        SKGBoardWidget* toMove = nullptr;
+        SKGBoardWidget *toMove = nullptr;
         int toMoveIndex = -1;
         int nb = m_itemsPointers.count();
         for (int i = 0; toMove == nullptr && i < nb; ++i) {
-            SKGBoardWidget* w = m_itemsPointers.at(i);
+            SKGBoardWidget *w = m_itemsPointers.at(i);
             if ((w != nullptr) && w->getDragWidget() == iObject) {
                 toMove = w;
                 toMoveIndex = i;
@@ -371,30 +376,30 @@ bool SKGDashboardWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
         if (iEvent->type() == QEvent::MouseButtonPress) {
             // Drag
-            auto* mevent = dynamic_cast<QMouseEvent*>(iEvent);
+            auto *mevent = dynamic_cast<QMouseEvent *>(iEvent);
             if (mevent && mevent->button() == Qt::LeftButton) {
                 m_clickedPoint = mevent->pos();
                 m_timer.stop();
             }
         } else if (iEvent->type() == QEvent::MouseButtonRelease) {
             // Drag
-            auto* mevent = dynamic_cast<QMouseEvent*>(iEvent);
+            auto *mevent = dynamic_cast<QMouseEvent *>(iEvent);
             if (mevent && mevent->button() == Qt::LeftButton) {
                 m_clickedPoint = QPoint(-1, -1);
             }
         } else if (iEvent->type() == QEvent::MouseMove) {
             // Drag
             if (m_clickedPoint != QPoint(-1, -1) && toMoveIndex != -1) {
-                auto* mevent = dynamic_cast<QMouseEvent*>(iEvent);
+                auto *mevent = dynamic_cast<QMouseEvent *>(iEvent);
                 if (mevent) {
                     int distance = (mevent->pos() - m_clickedPoint).manhattanLength();
                     if (distance >= QApplication::startDragDistance()) {
                         auto mimeData = new QMimeData;
-                        mimeData->setData(QLatin1String("application/x-SKGDashboardWidget"), SKGServices::intToString(toMoveIndex).toLatin1());
+                        mimeData->setData(QStringLiteral("application/x-SKGDashboardWidget"), SKGServices::intToString(toMoveIndex).toLatin1());
 
                         auto drag = new QDrag(this);
                         drag->setMimeData(mimeData);
-                        drag->exec();  // krazy:exclude=crashy
+                        drag->exec(); // krazy:exclude=crashy
 
                         return true;
                     }
@@ -402,17 +407,17 @@ bool SKGDashboardWidget::eventFilter(QObject* iObject, QEvent* iEvent)
             }
         } else if (iEvent->type() == QEvent::DragEnter) {
             // Drop move
-            auto* devent = dynamic_cast<QDragEnterEvent*>(iEvent);
-            if (devent && devent->mimeData()->hasFormat(QLatin1String("application/x-SKGDashboardWidget"))) {
+            auto *devent = dynamic_cast<QDragEnterEvent *>(iEvent);
+            if (devent && devent->mimeData()->hasFormat(QStringLiteral("application/x-SKGDashboardWidget"))) {
                 devent->accept();
 
                 return true;
             }
         } else if (iEvent->type() == QEvent::DragMove) {
             // Drop move
-            auto* devent = dynamic_cast<QDragMoveEvent*>(iEvent);
-            if (devent && devent->mimeData()->hasFormat(QLatin1String("application/x-SKGDashboardWidget"))) {
-                int oldPos = SKGServices::stringToInt(devent->mimeData()->data(QLatin1String("application/x-SKGDashboardWidget")));
+            auto *devent = dynamic_cast<QDragMoveEvent *>(iEvent);
+            if (devent && devent->mimeData()->hasFormat(QStringLiteral("application/x-SKGDashboardWidget"))) {
+                int oldPos = SKGServices::stringToInt(devent->mimeData()->data(QStringLiteral("application/x-SKGDashboardWidget")));
                 if (oldPos != toMoveIndex) {
                     devent->accept();
                 } else {
@@ -423,9 +428,9 @@ bool SKGDashboardWidget::eventFilter(QObject* iObject, QEvent* iEvent)
             }
         } else if (iEvent->type() == QEvent::Drop) {
             // Drop
-            auto* devent = dynamic_cast<QDropEvent*>(iEvent);
-            if (devent && devent->mimeData()->hasFormat(QLatin1String("application/x-SKGDashboardWidget"))) {
-                int oldPos = SKGServices::stringToInt(devent->mimeData()->data(QLatin1String("application/x-SKGDashboardWidget")));
+            auto *devent = dynamic_cast<QDropEvent *>(iEvent);
+            if (devent && devent->mimeData()->hasFormat(QStringLiteral("application/x-SKGDashboardWidget"))) {
+                int oldPos = SKGServices::stringToInt(devent->mimeData()->data(QStringLiteral("application/x-SKGDashboardWidget")));
 
                 if (oldPos + 1 == toMoveIndex) {
                     ++toMoveIndex;
@@ -454,12 +459,12 @@ void SKGDashboardWidget::showHeaderMenu(const QPoint iPos)
 
 void SKGDashboardWidget::onAddWidget()
 {
-    auto* send = qobject_cast<QAction*>(this->sender());
+    auto *send = qobject_cast<QAction *>(this->sender());
     if (send != nullptr) {
         QString id = send->data().toString();
         QStringList param = SKGServices::splitCSVLine(id, '-');
 
-        SKGInterfacePlugin* db = SKGMainPanel::getMainPanel()->getPluginByName(param.at(0));
+        SKGInterfacePlugin *db = SKGMainPanel::getMainPanel()->getPluginByName(param.at(0));
         if (db != nullptr) {
             addItem(db, SKGServices::stringToInt(param.at(1)));
         }
@@ -468,7 +473,7 @@ void SKGDashboardWidget::onAddWidget()
 
 void SKGDashboardWidget::onChangeLayout()
 {
-    auto* send = qobject_cast<QAction*>(this->sender());
+    auto *send = qobject_cast<QAction *>(this->sender());
     if (send != nullptr) {
         m_layout = send->data().toInt();
         setState(getState());
@@ -478,7 +483,7 @@ void SKGDashboardWidget::onChangeLayout()
 void SKGDashboardWidget::onMoveWidget(int iMove)
 {
     // Get current position
-    QWidget* send = qobject_cast<QWidget*>(this->sender());
+    QWidget *send = qobject_cast<QWidget *>(this->sender());
     if (send != nullptr) {
         int currentPos = m_itemsPointers.indexOf(parentBoardWidget(send));
         int newPos = currentPos + iMove;
@@ -501,11 +506,11 @@ void SKGDashboardWidget::moveItem(int iFrom, int iTo)
         m_itemsPointers.move(iFrom, iTo);
 
         // Build list of items in the right order
-        QList<SKGBoardWidget*> listWidgets;
+        QList<SKGBoardWidget *> listWidgets;
         int nb = m_itemsPointers.count();
         listWidgets.reserve(nb);
         for (int i = 0; i < nb; ++i) {
-            SKGBoardWidget* wgt2 = m_itemsPointers.at(i);
+            SKGBoardWidget *wgt2 = m_itemsPointers.at(i);
             m_flowLayout->removeWidget(wgt2);
             listWidgets.push_back(wgt2);
         }
@@ -513,18 +518,18 @@ void SKGDashboardWidget::moveItem(int iFrom, int iTo)
         // Add items
         nb = listWidgets.count();
         for (int i = 0; i < nb; ++i) {
-            SKGBoardWidget* dbw = listWidgets.at(i);
+            SKGBoardWidget *dbw = listWidgets.at(i);
             dbw->setParent(m_content);
             m_flowLayout->addWidget(dbw);
         }
     }
 }
 
-SKGBoardWidget* SKGDashboardWidget::parentBoardWidget(QWidget* iWidget)
+SKGBoardWidget *SKGDashboardWidget::parentBoardWidget(QWidget *iWidget)
 {
-    auto* output = qobject_cast< SKGBoardWidget* >(iWidget);
+    auto *output = qobject_cast<SKGBoardWidget *>(iWidget);
     if ((output == nullptr) && (iWidget != nullptr)) {
-        QWidget* iParent = iWidget->parentWidget();
+        QWidget *iParent = iWidget->parentWidget();
         if (iParent != nullptr) {
             output = SKGDashboardWidget::parentBoardWidget(iParent);
         }
@@ -536,13 +541,13 @@ SKGBoardWidget* SKGDashboardWidget::parentBoardWidget(QWidget* iWidget)
 void SKGDashboardWidget::onRemoveWidget()
 {
     int p = -1;
-    QWidget* send = qobject_cast<QWidget*>(this->sender());
+    QWidget *send = qobject_cast<QWidget *>(this->sender());
     if (send != nullptr) {
         p = m_itemsPointers.indexOf(parentBoardWidget(send));
     }
     if (p >= 0) {
         // Get item
-        SKGBoardWidget* wgt = m_itemsPointers.at(p);
+        SKGBoardWidget *wgt = m_itemsPointers.at(p);
 
         // Delete widget
         m_flowLayout->removeWidget(wgt);
@@ -555,10 +560,10 @@ void SKGDashboardWidget::onRemoveWidget()
     }
 }
 
-void SKGDashboardWidget::addItem(SKGInterfacePlugin* iDashboard, int iIndex, int iZoom, const QString& iState)
+void SKGDashboardWidget::addItem(SKGInterfacePlugin *iDashboard, int iIndex, int iZoom, const QString &iState)
 {
     if ((iDashboard != nullptr) && (m_flowLayout != nullptr)) {
-        SKGBoardWidget* dbw = iDashboard->getDashboardWidget(iIndex);
+        SKGBoardWidget *dbw = iDashboard->getDashboardWidget(iIndex);
         if (dbw != nullptr) {
             // Add widget
             dbw->setParent(m_content);
@@ -566,7 +571,7 @@ void SKGDashboardWidget::addItem(SKGInterfacePlugin* iDashboard, int iIndex, int
             if (m_layout == 0) {
                 m_flowLayout->addWidget(dbw);
             } else {
-                auto* grid = qobject_cast< QGridLayout* >(m_flowLayout);
+                auto *grid = qobject_cast<QGridLayout *>(m_flowLayout);
                 if (grid) {
                     int nbItem = grid->count();
                     int row = nbItem / m_layout;
@@ -576,7 +581,7 @@ void SKGDashboardWidget::addItem(SKGInterfacePlugin* iDashboard, int iIndex, int
             }
 
             // Install filter
-            QWidget* drag = dbw->getDragWidget();
+            QWidget *drag = dbw->getDragWidget();
             if (drag != nullptr) {
                 drag->installEventFilter(this);
                 drag->setAcceptDrops(true);
@@ -590,7 +595,7 @@ void SKGDashboardWidget::addItem(SKGInterfacePlugin* iDashboard, int iIndex, int
             // Set size
             dbw->setZoomRatio((iZoom + 15.0) / 5.0);
 
-            QString id = iDashboard->objectName() % QLatin1Char('-') % SKGServices::intToString(iIndex);
+            QString id = iDashboard->objectName() % u'-' % SKGServices::intToString(iIndex);
             m_items.push_back(id);
             m_itemsPointers.push_back(dbw);
         }
