@@ -10,11 +10,7 @@
  */
 #include "skgdocumentfilter.h"
 
-#ifdef SKG_QT6
 #include <ktexttemplate/util.h>
-#else
-#include <grantlee/util.h>
-#endif
 
 #include "skgdocument.h"
 #include "skgmainpanel.h"
