@@ -10,12 +10,7 @@
  *
  * @author Stephane MANKOWSKI
  */
-#ifdef SKG_QT6
 #include <KTextTemplate/TagLibraryInterface>
-#else
-#include <grantlee/taglibraryinterface.h>
-#define KTextTemplate Grantlee
-#endif
 #include <qobject.h>
 
 /**
