@@ -12,11 +12,7 @@
 #include "skgobjectbase.h"
 #include "skgtraces.h"
 
-#ifdef SKG_QT6
 #include "ktexttemplate/util.h"
-#else
-#include "grantlee/util.h"
-#endif
 
 QVariant SKGObjectFilter::doFilter(const QVariant &input, const QVariant &argument, bool autoescape) const
 {
