@@ -13,11 +13,7 @@
 #include <kaboutdata.h>
 #include <kzip.h>
 
-#ifdef SKG_QT6
 #include <KNSWidgets/Dialog>
-#else
-#include <kns3/qtquickdialogwrapper.h>
-#endif
 #include <qdesktopservices.h>
 #include <qdir.h>
 #include <qdom.h>
@@ -307,11 +303,7 @@ void SKGMonthlyPluginWidget::onPeriodChanged()
 
 void SKGMonthlyPluginWidget::onGetNewHotStuff()
 {
-#ifdef SKG_QT6
     QPointer<KNSWidgets::Dialog> dialog = new KNSWidgets::Dialog(KAboutData::applicationData().componentName() % "_monthly.knsrc", this);
-#else
-    QPointer<KNS3::QtQuickDialogWrapper> dialog = new KNS3::QtQuickDialogWrapper(KAboutData::applicationData().componentName() % "_monthly.knsrc", this);
-#endif
     dialog->exec();
 
     fillTemplateList();
