@@ -120,12 +120,6 @@ bool SKGPropertiesPlugin::setupActions(SKGDocument *iDocument)
         new KToolBarPopupAction(SKGServices::fromTheme(icon()), i18nc("Allows user to add a user defined property on an object", "Add property"), this);
     m_addPropertyMenu = actAddProperty->popupMenu();
     connect(m_addPropertyMenu, &QMenu::aboutToShow, this, &SKGPropertiesPlugin::onShowAddPropertyMenu);
-#ifdef SKG_QT6
-
-#else
-    actAddProperty->setStickyMenu(false);
-    actAddProperty->setDelayed(false);
-#endif
     registerGlobalAction(QStringLiteral("add_property"),
                          actAddProperty,
                          QStringList() << QStringLiteral("query:type='table' AND name NOT LIKE 'doctransaction%'"),
