@@ -78,11 +78,6 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument *iDocument)
     m_undoAction->setPriority(QAction::LowPriority);
     m_undoMenu = m_undoAction->popupMenu();
     connect(m_undoMenu, &QMenu::aboutToShow, this, &SKGUndoRedoPlugin::onShowUndoMenu);
-#ifdef SKG_QT6
-
-#else
-    m_undoAction->setStickyMenu(false);
-#endif
     m_undoAction->setData(1);
     registerGlobalAction(QStringLiteral("edit_undo"), m_undoAction);
 
@@ -93,11 +88,6 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument *iDocument)
     m_redoAction->setPriority(QAction::LowPriority);
     m_redoMenu = m_redoAction->popupMenu();
     connect(m_redoMenu, &QMenu::aboutToShow, this, &SKGUndoRedoPlugin::onShowRedoMenu);
-#ifdef SKG_QT6
-
-#else
-    m_redoAction->setStickyMenu(false);
-#endif
     m_redoAction->setData(1);
     registerGlobalAction(QStringLiteral("edit_redo"), m_redoAction);
 
