@@ -17,7 +17,7 @@
 #include "skgobjectmodelbase.h"
 #include "skgtraces.h"
 
-SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(QWidget* iParent, SKGDocument* iDocument)
+SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(QWidget *iParent, SKGDocument *iDocument)
     : SKGWidget(iParent, iDocument)
 {
     SKGTRACEINFUNC(1)
@@ -31,31 +31,32 @@ SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(QWidget* iParent, SKGDo
     newPalette.setColor(QPalette::Base, Qt::transparent);
     ui.kTransactionList->setPalette(newPalette);
 
-    auto modelview = new SKGObjectModelBase(getDocument(), QLatin1String("doctransaction"), QLatin1String("1=1 ORDER BY d_date DESC, id DESC"), this);
+    auto modelview = new SKGObjectModelBase(getDocument(), QStringLiteral("doctransaction"), QStringLiteral("1=1 ORDER BY d_date DESC, id DESC"), this);
     ui.kTransactionList->setModel(modelview);
     ui.kTransactionList->header()->hide();
 
-    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("edit_clear_history"));
+    QAction *act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("edit_clear_history"));
     if (act != nullptr) {
         ui.kClearHistoryBtn->setIcon(act->icon());
         connect(ui.kClearHistoryBtn, &QPushButton::clicked, act, &QAction::trigger);
     }
 
-    ui.kTransactionList->setDefaultSaveParameters(getDocument(), QLatin1String("SKG_DEFAULT_UNDOREDO"));
+    ui.kTransactionList->setDefaultSaveParameters(getDocument(), QStringLiteral("SKG_DEFAULT_UNDOREDO"));
 
     connect(ui.kTransactionList, &SKGTableView::doubleClicked, this, &SKGUndoRedoPluginDockWidget::onUndoRedo);
     connect(ui.kTransactionList, &SKGTableView::selectionChangedDelayed, this, &SKGUndoRedoPluginDockWidget::selectionChanged);
-    connect(getDocument(), &SKGDocument::transactionSuccessfullyEnded, ui.kTransactionList, &SKGTableView::resizeColumnsToContentsDelayed, Qt::QueuedConnection);
+    connect(getDocument(),
+            &SKGDocument::transactionSuccessfullyEnded,
+            ui.kTransactionList,
+            &SKGTableView::resizeColumnsToContentsDelayed,
+            Qt::QueuedConnection);
 
     ui.kTransactionList->setTextResizable(false);
 }
 
-SKGUndoRedoPluginDockWidget::~SKGUndoRedoPluginDockWidget()
-{
-    SKGTRACEINFUNC(1)
-}
+SKGUndoRedoPluginDockWidget::~SKGUndoRedoPluginDockWidget(){SKGTRACEINFUNC(1)}
 
-QWidget* SKGUndoRedoPluginDockWidget::mainWidget()
+QWidget *SKGUndoRedoPluginDockWidget::mainWidget()
 {
     return ui.kTransactionList;
 }
@@ -69,7 +70,8 @@ void SKGUndoRedoPluginDockWidget::onClearHistory()
 
     // status bar
     IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Clear history successfully done.")))
-    else {
+    else
+    {
         err.addError(ERR_FAIL, i18nc("Error message", "Clear history failed"));
     }
 
@@ -77,7 +79,7 @@ void SKGUndoRedoPluginDockWidget::onClearHistory()
     SKGMainPanel::displayErrorMessage(err);
 }
 
-void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex& index)
+void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex &index)
 {
     SKGTRACEINFUNC(1)
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -85,12 +87,12 @@ void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex& index)
     // Get Selection
     SKGError err;
     SKGDocument::UndoRedoMode mode = SKGDocument::UNDO;
-    auto* model = qobject_cast<SKGObjectModelBase*>(ui.kTransactionList->model());
+    auto *model = qobject_cast<SKGObjectModelBase *>(ui.kTransactionList->model());
     if (model != nullptr) {
         SKGObjectBase obj = model->getObject(index);
         int id = obj.getID();
         int lastExecuted = -1;
-        mode = (obj.getAttribute(QLatin1String("t_mode")) == QLatin1String("U") ? SKGDocument::UNDO : SKGDocument::REDO);
+        mode = (obj.getAttribute(QStringLiteral("t_mode")) == QStringLiteral("U") ? SKGDocument::UNDO : SKGDocument::REDO);
         do {
             lastExecuted = getDocument()->getTransactionToProcess(mode);
             err = getDocument()->undoRedoTransaction(mode);
@@ -99,8 +101,12 @@ void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex& index)
     QApplication::restoreOverrideCursor();
 
     // status bar
-    IFOKDO(err, SKGError(0, mode == SKGDocument::UNDO ? i18nc("Message for successful user action", "Undo successfully done.") : i18nc("Message for successful user action", "Redo successfully done.")))
-    else {
+    IFOKDO(err,
+           SKGError(0,
+                    mode == SKGDocument::UNDO ? i18nc("Message for successful user action", "Undo successfully done.")
+                                              : i18nc("Message for successful user action", "Redo successfully done.")))
+    else
+    {
         err.addError(ERR_FAIL, mode == SKGDocument::UNDO ? i18nc("Error message", "Undo failed") : i18nc("Error message", "Redo failed"));
     }
 
