@@ -69,7 +69,6 @@ SKGError SKGImportPluginGnc::importFile()
         int errorLine = 0;
         int errorCol = 0;
         bool contentOK = false;
-#ifdef SKG_QT6
         const auto &content = QString::fromUtf8(file.readAll());
         const auto &result = doc.setContent(content);
 
@@ -77,9 +76,6 @@ SKGError SKGImportPluginGnc::importFile()
         errorLine = result.errorLine;
         errorCol = result.errorColumn;
         errorMsg = result.errorMessage;
-#else
-        contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
-#endif
         file.close();
 
         if (!contentOK) {
