@@ -87,11 +87,7 @@ SKGError SKGImportPluginIif::importFile()
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) {
-#ifdef SKG_QT6
                 stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
-#else
-                stream.setCodec(m_importer->getCodec().toLatin1().constData());
-#endif
             }
 
             // Import
@@ -359,11 +355,7 @@ SKGError SKGImportPluginIif::exportFile()
     } else {
         QTextStream stream(&file);
         if (!m_importer->getCodec().isEmpty()) {
-#ifdef SKG_QT6
             stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
-#else
-            stream.setCodec(m_importer->getCodec().toLatin1().constData());
-#endif
         }
 
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export %1 file", "IIF"), 4);
