@@ -728,7 +728,6 @@ SKGError SKGImportPluginKmy::importFile()
         int errorLine = 0;
         int errorCol = 0;
         bool contentOK = false;
-#ifdef SKG_QT6
         const auto &content = QString::fromUtf8(file.readAll());
         const auto &result = doc.setContent(content);
 
@@ -736,9 +735,6 @@ SKGError SKGImportPluginKmy::importFile()
         errorLine = result.errorLine;
         errorCol = result.errorColumn;
         errorMsg = result.errorMessage;
-#else
-        contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
-#endif
         file.close();
 
         if (!contentOK) {
