@@ -80,11 +80,7 @@ SKGError SKGImportPluginLedger::exportFile()
         QLocale en(QLocale::C);
         QTextStream stream(&file);
         if (!m_importer->getCodec().isEmpty()) {
-#ifdef SKG_QT6
             stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
-#else
-            stream.setCodec(m_importer->getCodec().toLatin1().constData());
-#endif
         }
         stream << "; -*- ledger file generated by Skrooge -*-" << Qt::endl;
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export %1 file", "ledger"), 2);
@@ -259,7 +255,6 @@ SKGError SKGImportPluginLedger::importFile()
             int errorLine = 0;
             int errorCol = 0;
             bool contentOK = false;
-#ifdef SKG_QT6
             const auto &content = QString::fromUtf8(file.readAll());
             const auto &result = doc.setContent(content);
 
@@ -267,9 +262,6 @@ SKGError SKGImportPluginLedger::importFile()
             errorLine = result.errorLine;
             errorCol = result.errorColumn;
             errorMsg = result.errorMessage;
-#else
-            contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
-#endif
             file.close();
 
             // Get root
