@@ -28,20 +28,19 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginMmb, "metadata.json")
 
-SKGImportPluginMmb::SKGImportPluginMmb(QObject* iImporter, const QVariantList& iArg)
+SKGImportPluginMmb::SKGImportPluginMmb(QObject *iImporter, const QVariantList &iArg)
     : SKGImportPlugin(iImporter)
 {
     SKGTRACEINFUNC(10)
     Q_UNUSED(iArg)
 }
 
-SKGImportPluginMmb::~SKGImportPluginMmb()
-    = default;
+SKGImportPluginMmb::~SKGImportPluginMmb() = default;
 
 bool SKGImportPluginMmb::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("MMB"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("MMB"));
 }
 
 SKGError SKGImportPluginMmb::importFile()
@@ -53,38 +52,47 @@ SKGError SKGImportPluginMmb::importFile()
     SKGTRACEINFUNCRC(2, err)
 
     {
-        QSqlDatabase originalDocument(QSqlDatabase::addDatabase(QLatin1String("SKGSQLCIPHER"), QLatin1String("originalDocument")));
+        QSqlDatabase originalDocument(QSqlDatabase::addDatabase(QStringLiteral("SKGSQLCIPHER"), QStringLiteral("originalDocument")));
         originalDocument.setDatabaseName(m_importer->getLocalFileName());
         if (!originalDocument.open()) {
             // Set error message
             QSqlError sqlErr = originalDocument.lastError();
             err = SKGError(SQLLITEERROR + sqlErr.nativeErrorCode().toInt(), sqlErr.text());
         }
-        IFOK(err) {
+        IFOK(err)
+        {
             QMap<QString, SKGUnitObject> mapUnit;
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MMB"), 9);
 
             // Step 1 - units
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGStringListList listUnits;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT CURRENCYID, CURRENCYNAME, PFX_SYMBOL, SFX_SYMBOL, DECIMAL_POINT, GROUP_SEPARATOR, UNIT_NAME, CENT_NAME, SCALE, BASECONVRATE, CURRENCY_SYMBOL, "
-                        "(CASE WHEN EXISTS (SELECT 1 FROM INFOTABLE_V1 WHERE INFONAME='BASECURRENCYID' AND INFOVALUE=CURRENCYID) THEN 'Y' ELSE 'N' END) AS PRIMARYUNIT FROM CURRENCYFORMATS_V1"), listUnits);
-                IFOK(err) {
+                err =
+                    SKGServices::executeSelectSqliteOrder(originalDocument,
+                                                          QStringLiteral("SELECT CURRENCYID, CURRENCYNAME, PFX_SYMBOL, SFX_SYMBOL, DECIMAL_POINT, "
+                                                                         "GROUP_SEPARATOR, UNIT_NAME, CENT_NAME, SCALE, BASECONVRATE, CURRENCY_SYMBOL, "
+                                                                         "(CASE WHEN EXISTS (SELECT 1 FROM INFOTABLE_V1 WHERE INFONAME='BASECURRENCYID' AND "
+                                                                         "INFOVALUE=CURRENCYID) THEN 'Y' ELSE 'N' END) AS PRIMARYUNIT FROM CURRENCYFORMATS_V1"),
+                                                          listUnits);
+                IFOK(err)
+                {
                     int nb = listUnits.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        const QStringList& attributes = listUnits.at(i + 1);
+                        const QStringList &attributes = listUnits.at(i + 1);
 
                         SKGUnitObject unit(m_importer->getDocument());
                         err = unit.setName(attributes.at(1));
-                        IFOK(err) {
+                        IFOK(err)
+                        {
                             QString symbol = attributes.at(2);
                             if (symbol.isEmpty()) {
                                 symbol = attributes.at(3);
                             }
                             err = unit.setSymbol(symbol);
                         }
-                        if (!err && attributes.at(11) == QLatin1String("Y")) {
+                        if (!err && attributes.at(11) == QStringLiteral("Y")) {
                             err = unit.setType(SKGUnitObject::PRIMARY);
                         }
                         IFOKDO(err, unit.save())
@@ -94,28 +102,35 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
             // Step 2 - bank and accounts
             QMap<QString, SKGAccountObject> mapAccount;
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGStringListList listAccounts;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT ACCOUNTID, ACCOUNTNAME, ACCOUNTTYPE, ACCOUNTNUM, STATUS, NOTES, HELDAT, WEBSITE, CONTACTINFO, ACCESSINFO, INITIALBAL, FAVORITEACCT, CURRENCYID FROM ACCOUNTLIST_V1"), listAccounts);
-                IFOK(err) {
+                err = SKGServices::executeSelectSqliteOrder(
+                    originalDocument,
+                    QStringLiteral("SELECT ACCOUNTID, ACCOUNTNAME, ACCOUNTTYPE, ACCOUNTNUM, STATUS, NOTES, HELDAT, WEBSITE, CONTACTINFO, ACCESSINFO, "
+                                   "INITIALBAL, FAVORITEACCT, CURRENCYID FROM ACCOUNTLIST_V1"),
+                    listAccounts);
+                IFOK(err)
+                {
                     int nb = listAccounts.count() - 1;
                     IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks and accounts"), nb))
                     for (int i = 0; !err && i < nb; ++i) {
-                        const QStringList& attributes = listAccounts.at(i + 1);
+                        const QStringList &attributes = listAccounts.at(i + 1);
 
                         // Create bank
                         SKGBankObject bank(m_importer->getDocument());
-                        IFOK(err) {
+                        IFOK(err)
+                        {
                             QString bankName = attributes.at(6);
                             if (bankName.isEmpty()) {
-                                bankName = QLatin1String("MMEX");
+                                bankName = QStringLiteral("MMEX");
                             }
                             err = bank.setName(bankName);
                         }
@@ -125,12 +140,12 @@ SKGError SKGImportPluginMmb::importFile()
                         SKGAccountObject account;
                         err = bank.addAccount(account);
                         IFOKDO(err, account.setName(attributes.at(1)))
-                        IFOKDO(err, account.setType(attributes.at(2) == QLatin1String("Checking") ? SKGAccountObject::CURRENT : SKGAccountObject::INVESTMENT))
+                        IFOKDO(err, account.setType(attributes.at(2) == QStringLiteral("Checking") ? SKGAccountObject::CURRENT : SKGAccountObject::INVESTMENT))
                         IFOKDO(err, account.setNumber(attributes.at(3)))
                         IFOKDO(err, account.setComment(attributes.at(5)))
                         IFOKDO(err, account.setAgencyAddress(attributes.at(8)))
-                        IFOKDO(err, account.bookmark(attributes.at(11) == QLatin1String("TRUE")))
-                        IFOKDO(err, account.setClosed(attributes.at(4) != QLatin1String("Open")))
+                        IFOKDO(err, account.bookmark(attributes.at(11) == QStringLiteral("TRUE")))
+                        IFOKDO(err, account.setClosed(attributes.at(4) != QStringLiteral("Open")))
                         IFOKDO(err, account.save())
                         IFOKDO(err, account.setInitialBalance(SKGServices::stringToDouble(attributes.at(10)), mapUnit[attributes.at(12)]))
                         IFOKDO(err, account.save())
@@ -140,21 +155,23 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
             // Step 3 - categories
             QMap<QString, SKGCategoryObject> mapCategory;
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGStringListList listCategories;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT CATEGID, CATEGNAME FROM CATEGORY_V1"), listCategories);
-                IFOK(err) {
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT CATEGID, CATEGNAME FROM CATEGORY_V1"), listCategories);
+                IFOK(err)
+                {
                     int nb = listCategories.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        const QStringList& attributes = listCategories.at(i + 1);
+                        const QStringList &attributes = listCategories.at(i + 1);
 
                         SKGCategoryObject cat(m_importer->getDocument());
                         err = cat.setName(attributes.at(1));
@@ -165,21 +182,25 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
             // Step 4 - sub categories
             QMap<QString, SKGCategoryObject> mapSubCategory;
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGStringListList listCategories;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT SUBCATEGID, SUBCATEGNAME, CATEGID FROM SUBCATEGORY_V1"), listCategories);
-                IFOK(err) {
+                err = SKGServices::executeSelectSqliteOrder(originalDocument,
+                                                            QStringLiteral("SELECT SUBCATEGID, SUBCATEGNAME, CATEGID FROM SUBCATEGORY_V1"),
+                                                            listCategories);
+                IFOK(err)
+                {
                     int nb = listCategories.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        const QStringList& attributes = listCategories.at(i + 1);
+                        const QStringList &attributes = listCategories.at(i + 1);
 
                         SKGCategoryObject cat(m_importer->getDocument());
                         err = cat.setName(attributes.at(1));
@@ -191,21 +212,23 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
             // Step 5 - payee
             QMap<QString, SKGPayeeObject> mapPayee;
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGStringListList listPayee;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT PAYEEID, PAYEENAME FROM PAYEE_V1"), listPayee);
-                IFOK(err) {
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT PAYEEID, PAYEENAME FROM PAYEE_V1"), listPayee);
+                IFOK(err)
+                {
                     int nb = listPayee.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        const QStringList& attributes = listPayee.at(i + 1);
+                        const QStringList &attributes = listPayee.at(i + 1);
 
                         SKGPayeeObject payee(m_importer->getDocument());
                         err = payee.setName(attributes.at(1));
@@ -216,73 +239,89 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
             // Step 6 - transactions
             QMap<QString, SKGOperationObject> mapOperation;
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGStringListList listOperations;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT * FROM ("
-                        "SELECT TRANSID, ACCOUNTID, TOACCOUNTID, PAYEEID, TRANSCODE, TRANSAMOUNT, STATUS, TRANSACTIONNUMBER, NOTES, CATEGID, SUBCATEGID, TRANSDATE, FOLLOWUPID, TOTRANSAMOUNT, 'N/A'  , 'N/A', 'N/A' FROM CHECKINGACCOUNT_V1 UNION "
-                        "SELECT BDID,    ACCOUNTID, TOACCOUNTID, PAYEEID, TRANSCODE, TRANSAMOUNT, STATUS, TRANSACTIONNUMBER, NOTES, CATEGID, SUBCATEGID, TRANSDATE, FOLLOWUPID, TOTRANSAMOUNT, REPEATS, NEXTOCCURRENCEDATE, NUMOCCURRENCES FROM BILLSDEPOSITS_V1)"), listOperations);
-                IFOK(err) {
+                err = SKGServices::executeSelectSqliteOrder(
+                    originalDocument,
+                    QStringLiteral("SELECT * FROM ("
+                                   "SELECT TRANSID, ACCOUNTID, TOACCOUNTID, PAYEEID, TRANSCODE, TRANSAMOUNT, STATUS, TRANSACTIONNUMBER, NOTES, CATEGID, "
+                                   "SUBCATEGID, TRANSDATE, FOLLOWUPID, TOTRANSAMOUNT, 'N/A'  , 'N/A', 'N/A' FROM CHECKINGACCOUNT_V1 UNION "
+                                   "SELECT BDID,    ACCOUNTID, TOACCOUNTID, PAYEEID, TRANSCODE, TRANSAMOUNT, STATUS, TRANSACTIONNUMBER, NOTES, CATEGID, "
+                                   "SUBCATEGID, TRANSDATE, FOLLOWUPID, TOTRANSAMOUNT, REPEATS, NEXTOCCURRENCEDATE, NUMOCCURRENCES FROM BILLSDEPOSITS_V1)"),
+                    listOperations);
+                IFOK(err)
+                {
                     int nb = listOperations.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        const QStringList& attributes = listOperations.at(i + 1);
-                        if (attributes.at(6) != QLatin1String("V")) {  // Void
-                            bool recurrent = (attributes.at(14) != QLatin1String("N/A"));
-                            const QString& idTarget = attributes.at(2);
+                        const QStringList &attributes = listOperations.at(i + 1);
+                        if (attributes.at(6) != QStringLiteral("V")) { // Void
+                            bool recurrent = (attributes.at(14) != QStringLiteral("N/A"));
+                            const QString &idTarget = attributes.at(2);
                             SKGAccountObject acc = mapAccount[attributes.at(1)];
                             SKGUnitObject unit;
                             IFOKDO(err, acc.getUnit(unit))
 
                             SKGOperationObject op;
                             IFOKDO(err, acc.addOperation(op, true))
-                            IFOK(err) {
-                                const QString& id = attributes.at(3);
-                                if (id != QLatin1String("-1")) {
+                            IFOK(err)
+                            {
+                                const QString &id = attributes.at(3);
+                                if (id != QStringLiteral("-1")) {
                                     err = op.setPayee(mapPayee[id]);
                                 }
                             }
                             IFOKDO(err, op.setNumber(attributes.at(7)))
                             IFOKDO(err, op.setComment(attributes.at(8)))
                             IFOKDO(err, op.setDate(SKGServices::stringToDate(attributes.at(11))))
-                            IFOKDO(err, op.setAttribute(QLatin1String("t_imported"), QLatin1String("T")))
+                            IFOKDO(err, op.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
                             IFOKDO(err, op.setImportID("MMEX-" % attributes.at(0)))
                             IFOKDO(err, op.setUnit(unit))
-                            IFOKDO(err, op.bookmark(attributes.at(6) == QLatin1String("F")))
+                            IFOKDO(err, op.bookmark(attributes.at(6) == QStringLiteral("F")))
                             IFOKDO(err, op.setTemplate(recurrent))
-                            IFOKDO(err, op.setStatus(attributes.at(6) == QLatin1String("R") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
+                            IFOKDO(err, op.setStatus(attributes.at(6) == QStringLiteral("R") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
                             IFOKDO(err, op.save())
 
                             // Get splits
-                            IFOK(err) {
+                            IFOK(err)
+                            {
                                 SKGStringListList listSubOperations;
-                                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT SPLITTRANSID, CATEGID, SUBCATEGID, SPLITTRANSAMOUNT FROM ") % (recurrent ? "BUDGET" : "") % "SPLITTRANSACTIONS_V1 WHERE TRANSID=" % attributes.at(0), listSubOperations);
-                                IFOK(err) {
+                                err = SKGServices::executeSelectSqliteOrder(originalDocument,
+                                                                            QStringLiteral("SELECT SPLITTRANSID, CATEGID, SUBCATEGID, SPLITTRANSAMOUNT FROM ")
+                                                                                % (recurrent ? "BUDGET" : "") % "SPLITTRANSACTIONS_V1 WHERE TRANSID="
+                                                                                % attributes.at(0),
+                                                                            listSubOperations);
+                                IFOK(err)
+                                {
                                     int nb2 = listSubOperations.count() - 1;
                                     if (nb2 <= 0) {
                                         // No split
                                         SKGSubOperationObject subop;
                                         IFOKDO(err, op.addSubOperation(subop))
-                                        IFOK(err) {
+                                        IFOK(err)
+                                        {
                                             QString id = attributes.at(10);
-                                            if (id == QLatin1String("-1")) {
+                                            if (id == QStringLiteral("-1")) {
                                                 id = attributes.at(9);
-                                                if (id != QLatin1String("-1")) {
+                                                if (id != QStringLiteral("-1")) {
                                                     err = subop.setCategory(mapSubCategory[id]);
                                                 }
                                             } else {
                                                 err = subop.setCategory(mapCategory[id]);
                                             }
                                         }
-                                        IFOK(err) {
+                                        IFOK(err)
+                                        {
                                             double q = SKGServices::stringToDouble(attributes.at(5));
-                                            if (attributes.at(4) == QLatin1String("Withdrawal") || idTarget != QLatin1String("-1")) {
+                                            if (attributes.at(4) == QStringLiteral("Withdrawal") || idTarget != QStringLiteral("-1")) {
                                                 q = -q;
                                             }
                                             err = subop.setQuantity(q);
@@ -291,24 +330,26 @@ SKGError SKGImportPluginMmb::importFile()
                                     } else {
                                         // Has splits
                                         for (int j = 0; !err && j < nb2; ++j) {
-                                            const QStringList& attributesSubOp = listSubOperations.at(j + 1);
+                                            const QStringList &attributesSubOp = listSubOperations.at(j + 1);
 
                                             SKGSubOperationObject subop;
                                             IFOKDO(err, op.addSubOperation(subop))
-                                            IFOK(err) {
+                                            IFOK(err)
+                                            {
                                                 QString id = attributesSubOp.at(2);
-                                                if (id == QLatin1String("-1")) {
+                                                if (id == QStringLiteral("-1")) {
                                                     id = attributesSubOp.at(1);
-                                                    if (id != QLatin1String("-1")) {
+                                                    if (id != QStringLiteral("-1")) {
                                                         err = subop.setCategory(mapCategory[id]);
                                                     }
                                                 } else {
                                                     err = subop.setCategory(mapSubCategory[id]);
                                                 }
                                             }
-                                            IFOK(err) {
+                                            IFOK(err)
+                                            {
                                                 double q = SKGServices::stringToDouble(attributesSubOp.at(3));
-                                                if (attributes.at(4) == QLatin1String("Withdrawal") || idTarget != QLatin1String("-1")) {
+                                                if (attributes.at(4) == QStringLiteral("Withdrawal") || idTarget != QStringLiteral("-1")) {
                                                     q = -q;
                                                 }
                                                 err = subop.setQuantity(q);
@@ -320,12 +361,12 @@ SKGError SKGImportPluginMmb::importFile()
                             }
 
                             // Case Transfer
-                            if (!err && idTarget != QLatin1String("-1")) {
+                            if (!err && idTarget != QStringLiteral("-1")) {
                                 SKGOperationObject op2;
                                 err = op.duplicate(op2, op.getDate());
                                 IFOKDO(err, op2.setStatus(op.getStatus()))
                                 IFOKDO(err, op2.bookmark(op.isBookmarked()))
-                                IFOKDO(err, op2.setAttribute(QLatin1String("t_imported"), QLatin1String("T")))
+                                IFOKDO(err, op2.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
                                 IFOKDO(err, op2.setImportID("MMEX-" % attributes.at(0) % "_TR"))
                                 IFOKDO(err, op2.save())
 
@@ -352,7 +393,8 @@ SKGError SKGImportPluginMmb::importFile()
                                     IFOKDO(err, recu.timeLimit(true))
                                 }
                                 int repeats = SKGServices::stringToInt(attributes.at(14));
-                                IFOK(err) {
+                                IFOK(err)
+                                {
                                     switch (repeats) {
                                     case 1:
                                         // Weekly
@@ -417,20 +459,25 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
             // Step 7 - stock
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGStringListList listStock;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT STOCKID, HELDAT, PURCHASEDATE, STOCKNAME, SYMBOL, NUMSHARES, PURCHASEPRICE, NOTES, CURRENTPRICE, VALUE, COMMISSION FROM STOCK_V1"), listStock);
-                IFOK(err) {
+                err = SKGServices::executeSelectSqliteOrder(originalDocument,
+                                                            QStringLiteral("SELECT STOCKID, HELDAT, PURCHASEDATE, STOCKNAME, SYMBOL, NUMSHARES, PURCHASEPRICE, "
+                                                                           "NOTES, CURRENTPRICE, VALUE, COMMISSION FROM STOCK_V1"),
+                                                            listStock);
+                IFOK(err)
+                {
                     int nb = listStock.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import stocks"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        const QStringList& attributes = listStock.at(i + 1);
+                        const QStringList &attributes = listStock.at(i + 1);
 
                         // Create unit
                         SKGUnitObject unit(m_importer->getDocument());
@@ -460,7 +507,7 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOKDO(err, acc.addOperation(op, true))
                         IFOKDO(err, op.setComment(attributes.at(7)))
                         IFOKDO(err, op.setDate(SKGServices::stringToDate(attributes.at(2))))
-                        IFOKDO(err, op.setAttribute(QLatin1String("t_imported"), QLatin1String("T")))
+                        IFOKDO(err, op.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
                         IFOKDO(err, op.setImportID("MMEX-STOCK-" % attributes.at(0)))
                         IFOKDO(err, op.setUnit(unit))
                         IFOKDO(err, op.save())
@@ -474,7 +521,7 @@ SKGError SKGImportPluginMmb::importFile()
                         if(!err) err = acc.addOperation(op2, true);
                         if(!err) err = op2.setComment(attributes.at(7));
                         if(!err) err = op2.setDate(SKGServices::stringToDate(attributes.at(2)));
-                        if(!err) err = op2.setAttribute(QLatin1String("t_imported"), QLatin1String("T"));
+                        if(!err) err = op2.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T"));
                         if(!err) err = op2.setImportID("MMEX-STOCK-" % attributes.at(0)% "_TR");
                         if(!err) err = op2.setUnit(unitCurrency);
                         if(!err) err = op2.save();
@@ -490,22 +537,27 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(7))
 
             // Step 8 - asset
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGStringListList listAssets;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT ASSETID, STARTDATE, ASSETNAME, VALUE, VALUECHANGE, NOTES, VALUECHANGERATE, ASSETTYPE FROM ASSETS_V1"), listAssets);
-                IFOK(err) {
+                err = SKGServices::executeSelectSqliteOrder(
+                    originalDocument,
+                    QStringLiteral("SELECT ASSETID, STARTDATE, ASSETNAME, VALUE, VALUECHANGE, NOTES, VALUECHANGERATE, ASSETTYPE FROM ASSETS_V1"),
+                    listAssets);
+                IFOK(err)
+                {
                     int nb = listAssets.count() - 1;
                     if (nb != 0) {
                         // Create account
                         // Create bank
                         SKGBankObject bank(m_importer->getDocument());
-                        IFOKDO(err, bank.setName(QLatin1String("MMEX")))
+                        IFOKDO(err, bank.setName(QStringLiteral("MMEX")))
                         IFOKDO(err, bank.save())
 
                         // Create account
@@ -517,14 +569,17 @@ SKGError SKGImportPluginMmb::importFile()
 
                         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import assets"), nb);
                         for (int i = 0; !err && i < nb; ++i) {
-                            const QStringList& attributes = listAssets.at(i + 1);
+                            const QStringList &attributes = listAssets.at(i + 1);
 
                             // Create unit
                             SKGUnitObject unit(m_importer->getDocument());
                             err = unit.setName(attributes.at(2));
                             IFOKDO(err, unit.setSymbol(attributes.at(2)))
                             IFOKDO(err, unit.setType(SKGUnitObject::OBJECT))
-                            IFOKDO(err, unit.setInternetCode(QLatin1String("=") % (attributes.at(4) == QLatin1String("Depreciates") ? QLatin1String("-") : QLatin1String("+")) % attributes.at(6)))
+                            IFOKDO(err,
+                                   unit.setInternetCode(QStringLiteral("=")
+                                                        % (attributes.at(4) == QStringLiteral("Depreciates") ? QStringLiteral("-") : QStringLiteral("+"))
+                                                        % attributes.at(6)))
                             IFOKDO(err, unit.save())
 
                             SKGUnitValueObject unitValue;
@@ -538,7 +593,7 @@ SKGError SKGImportPluginMmb::importFile()
                             IFOKDO(err, account.addOperation(op, true))
                             IFOKDO(err, op.setComment(attributes.at(5)))
                             IFOKDO(err, op.setDate(SKGServices::stringToDate(attributes.at(1))))
-                            IFOKDO(err, op.setAttribute(QLatin1String("t_imported"), QLatin1String("T")))
+                            IFOKDO(err, op.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
                             IFOKDO(err, op.setImportID("MMEX-ASSET-" % attributes.at(0)))
                             IFOKDO(err, op.setUnit(unit))
                             IFOKDO(err, op.save())
@@ -551,45 +606,51 @@ SKGError SKGImportPluginMmb::importFile()
                             IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                         }
 
-                        SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                        SKGENDTRANSACTION(m_importer->getDocument(), err)
                     }
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(8))
 
             // Step 9 - budgets
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGStringListList listBudgets;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT BUDGETENTRYID, (SELECT Y.BUDGETYEARNAME FROM BUDGETYEAR_V1 Y WHERE Y.BUDGETYEARID=BUDGETTABLE_V1.BUDGETYEARID), CATEGID, SUBCATEGID, PERIOD, AMOUNT FROM BUDGETTABLE_V1"), listBudgets);
-                IFOK(err) {
+                err = SKGServices::executeSelectSqliteOrder(
+                    originalDocument,
+                    QStringLiteral("SELECT BUDGETENTRYID, (SELECT Y.BUDGETYEARNAME FROM BUDGETYEAR_V1 Y WHERE Y.BUDGETYEARID=BUDGETTABLE_V1.BUDGETYEARID), "
+                                   "CATEGID, SUBCATEGID, PERIOD, AMOUNT FROM BUDGETTABLE_V1"),
+                    listBudgets);
+                IFOK(err)
+                {
                     int nb = listBudgets.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import budgets"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
-                        const QStringList& attributes = listBudgets.at(i + 1);
+                        const QStringList &attributes = listBudgets.at(i + 1);
 
-                        const QString& period = attributes.at(4);
+                        const QString &period = attributes.at(4);
 
                         int step = 0;
                         double coef = 0;
-                        if (period == QLatin1String("Weekly")) {
+                        if (period == QStringLiteral("Weekly")) {
                             coef = 52.0 / 12.0;
                             step = 1;
-                        } else if (period == QLatin1String("Monthly")) {
+                        } else if (period == QStringLiteral("Monthly")) {
                             coef = 1;
                             step = 1;
-                        } else if (period == QLatin1String("Bi-Weekly")) {
+                        } else if (period == QStringLiteral("Bi-Weekly")) {
                             coef = 52.0 / 12.0 / 2.0;
                             step = 1;
-                        } else if (period == QLatin1String("Bi-Monthly")) {
+                        } else if (period == QStringLiteral("Bi-Monthly")) {
                             coef = 1;
                             step = 2;
-                        } else if (period == QLatin1String("Quarterly")) {
+                        } else if (period == QStringLiteral("Quarterly")) {
                             coef = 1;
                             step = 4;
-                        } else if (period == QLatin1String("Half-Yearly")) {
+                        } else if (period == QStringLiteral("Half-Yearly")) {
                             coef = 1;
                             step = 6;
-                        } else if (period == QLatin1String("Yearly")) {
+                        } else if (period == QStringLiteral("Yearly")) {
                             coef = 1;
                             step = 12;
                         }
@@ -599,11 +660,12 @@ SKGError SKGImportPluginMmb::importFile()
                                 SKGBudgetObject bug(m_importer->getDocument());
                                 err = bug.setYear(SKGServices::stringToInt(attributes.at(1)));
                                 IFOKDO(err, bug.setMonth(step == 12 ? 0 : j + 1))
-                                IFOK(err) {
+                                IFOK(err)
+                                {
                                     QString id = attributes.at(3);
-                                    if (id == QLatin1String("-1")) {
+                                    if (id == QStringLiteral("-1")) {
                                         id = attributes.at(2);
-                                        if (id != QLatin1String("-1")) {
+                                        if (id != QStringLiteral("-1")) {
                                             err = bug.setCategory(mapCategory[id]);
                                         }
                                     } else {
@@ -618,18 +680,18 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(9))
 
-            SKGENDTRANSACTION(m_importer->getDocument(),  err)
+            SKGENDTRANSACTION(m_importer->getDocument(), err)
 
-            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE")))
+            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE")))
         }
         originalDocument.close();
     }
-    QSqlDatabase::removeDatabase(QLatin1String("originalDocument"));
+    QSqlDatabase::removeDatabase(QStringLiteral("originalDocument"));
     return err;
 }
 
