@@ -29,6 +29,7 @@
 QMap<QString, SKGUnitObject> SKGImportPluginMny::m_mapIdSecurity;
 QMap<QString, SKGAccountObject> SKGImportPluginMny::m_mapIdAccount;
 QMap<QString, SKGCategoryObject> SKGImportPluginMny::m_mapIdCategory;
+QMap<QString, SKGTrackerObject> SKGImportPluginMny::m_mapIdTracker;
 QMap<QString, SKGPayeeObject> SKGImportPluginMny::m_mapIdPayee;
 
 /**
@@ -124,11 +125,17 @@ SKGError SKGImportPluginMny::importFile()
     }
 
     QString sunriise_jar = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) % "/sunriise.jar";
-    if (!QFile(sunriise_jar).exists()) {
-        if (m_importParameters.value(QStringLiteral("install_sunriise")) == QStringLiteral("Y")) {
+    int expected_sunriise_version = 1; // This number must be incremented at each new version of sunriise
+    auto sunriise_version = SKGServices::stringToInt(m_importer->getDocument()->getParameter(QStringLiteral("SKG_SUNRIISE_VERSION"), QStringLiteral("0")));
+    auto sunriize_installation_requested = m_importParameters.value(QStringLiteral("install_sunriise")) == QStringLiteral("Y");
+    auto sunriise_already_installed = QFile(sunriise_jar).exists();
+    if (!sunriise_already_installed || sunriise_version != expected_sunriise_version) {
+        if (sunriise_already_installed || sunriize_installation_requested) {
             QDir().mkpath(QFileInfo(sunriise_jar).dir().path());
             err = SKGServices::upload(QUrl(QStringLiteral("https://skrooge.org/files/sunriise.jar")), QUrl::fromLocalFile(sunriise_jar));
             IFKO(err) return err;
+
+            m_importer->getDocument()->setParameter(QStringLiteral("SKG_SUNRIISE_VERSION"), QString::number(expected_sunriise_version));
         } else {
             err.setReturnCode(ERR_INSTALL)
                 .setMessage(i18nc("Error message", "The sunriise application is needed for Microsoft Money import but is not installed in '%1'", sunriise_jar));
@@ -141,6 +148,7 @@ SKGError SKGImportPluginMny::importFile()
     m_mapIdSecurity.clear();
     m_mapIdAccount.clear();
     m_mapIdCategory.clear();
+    m_mapIdTracker.clear();
     m_mapIdPayee.clear();
 
     // Execute sunriise
@@ -182,20 +190,41 @@ SKGError SKGImportPluginMny::importFile()
                     for (int i = 0; !err && i < nb && index < nb; ++i) {
                         QVariantMap category = list.at(i).toMap();
 
-                        QString parentId = category[QStringLiteral("parentId")].toString();
-                        QString id = category[QStringLiteral("id")].toString();
-                        QString name = category[QStringLiteral("name")].toString();
-                        int level = category[QStringLiteral("level")].toInt();
+                        int classificationId = category[QStringLiteral("classificationId")].toInt();
+                        if (classificationId == 0) {
+                            // This is a category
+                            QString parentId = category[QStringLiteral("parentId")].toString();
+                            QString id = category[QStringLiteral("id")].toString();
+                            QString name = category[QStringLiteral("name")].toString();
+                            int level = category[QStringLiteral("level")].toInt();
 
-                        if (level == t) {
-                            SKGCategoryObject catObject(m_importer->getDocument());
-                            err = catObject.setName(name);
-                            if (!err && !parentId.isEmpty()) {
-                                err = catObject.setParentCategory(m_mapIdCategory[parentId]);
+                            if (level == t) {
+                                SKGCategoryObject catObject(m_importer->getDocument());
+                                err = catObject.setName(name);
+                                if (!err && !parentId.isEmpty()) {
+                                    err = catObject.setParentCategory(m_mapIdCategory[parentId]);
+                                }
+                                IFOKDO(err, catObject.save())
+
+                                m_mapIdCategory[id] = catObject;
+
+                                ++index;
+                                IFOKDO(err, m_importer->getDocument()->stepForward(index))
+                            }
+                        } else if (classificationId > 0) {
+                            // This is a tracker
+                            QString id = category[QStringLiteral("id")].toString();
+                            QString name = category[QStringLiteral("name")].toString();
+                            QString parentId = category[QStringLiteral("parentId")].toString();
+                            if (!parentId.isEmpty()) {
+                                name = m_mapIdTracker[parentId].getName() % OBJECTSEPARATOR % name;
                             }
-                            IFOKDO(err, catObject.save())
 
-                            m_mapIdCategory[id] = catObject;
+                            SKGTrackerObject trackObject(m_importer->getDocument());
+                            err = trackObject.setName(name);
+                            IFOKDO(err, trackObject.save())
+
+                            m_mapIdTracker[id] = trackObject;
 
                             ++index;
                             IFOKDO(err, m_importer->getDocument()->stepForward(index))
@@ -259,6 +288,15 @@ SKGError SKGImportPluginMny::importFile()
                     QString id = unit[QStringLiteral("id")].toString();
                     QString name = unit[QStringLiteral("name")].toString();
                     QString symbol = unit[QStringLiteral("symbol")].toString();
+                    QString internetCode;
+
+                    // BUG: 507235 vvv
+                    auto symbol_items = SKGServices::splitCSVLine(symbol, ':');
+                    if (symbol_items.count() == 2) {
+                        symbol = symbol_items.at(1);
+                        internetCode = symbol;
+                    }
+                    // BUG: 507235 ^^^
                     if (symbol.isEmpty()) {
                         symbol = name;
                     }
@@ -268,6 +306,7 @@ SKGError SKGImportPluginMny::importFile()
                     err = unitobject.setName(name);
                     IFOKDO(err, unitobject.setSymbol(symbol))
                     IFOKDO(err, unitobject.setType(SKGUnitObject::SHARE))
+                    IFOKDO(err, unitobject.setInternetCode(internetCode))
                     // The unit is not saved because it will be saved when used
 
                     m_mapIdSecurity[id] = unitobject;
@@ -310,7 +349,7 @@ SKGError SKGImportPluginMny::importFile()
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import accounts"), nb);
 
             SKGBankObject bank(m_importer->getDocument());
-            IFOKDO(err, bank.setName(QStringLiteral("Microsof Money")))
+            IFOKDO(err, bank.setName(QStringLiteral("Microsoft Money")))
             IFOKDO(err, bank.save())
 
             // Create accounts
@@ -429,6 +468,20 @@ SKGError SKGImportPluginMny::importFile()
 
                             double amount = operation[QStringLiteral("amount")].toDouble();
 
+                            // BUG: 507235 vvv
+                            if (operation[QStringLiteral("investment")].toBool()) {
+                                amount = operation[QStringLiteral("quantity")].toDouble();
+
+                                if (operation[QStringLiteral("price")].toDouble() != 0.0) {
+                                    SKGUnitValueObject unitval;
+                                    IFOKDO(err, unitObj.addUnitValue(unitval))
+                                    IFOKDO(err, unitval.setQuantity(operation[QStringLiteral("price")].toDouble()))
+                                    IFOKDO(err, unitval.setDate(operationObj.getDate()))
+                                    IFOKDO(err, unitval.save())
+                                }
+                            }
+                            // BUG: 507235 ^^^
+
                             // Is it a split?
                             QVariantList splits = operation[QStringLiteral("splits")].toList();
                             int nbs = splits.count();
@@ -444,9 +497,16 @@ SKGError SKGImportPluginMny::importFile()
                                     if (!catId.isEmpty() && !err) {
                                         err = subOperationObj.setCategory(m_mapIdCategory[catId]);
                                     }
+                                    QString trackId = transaction[QStringLiteral("class2")].toString();
+                                    if (trackId.isEmpty() || trackId == QStringLiteral("-1")) {
+                                        trackId = transaction[QStringLiteral("class1")].toString();
+                                    }
+                                    if (!trackId.isEmpty() && trackId != QStringLiteral("-1") && !err) {
+                                        err = subOperationObj.setTracker(m_mapIdTracker[trackId]);
+                                    }
                                     double splitAmount = transaction[QStringLiteral("amount")].toDouble();
                                     IFOKDO(err, subOperationObj.setQuantity(splitAmount))
-                                    IFOKDO(err, subOperationObj.setComment(operation[QStringLiteral("memo")].toString()))
+                                    IFOKDO(err, subOperationObj.setComment(transaction[QStringLiteral("memo")].toString()))
                                     IFOKDO(err, subOperationObj.save(false, false))
                                     amount -= splitAmount;
                                 }
@@ -475,6 +535,13 @@ SKGError SKGImportPluginMny::importFile()
                                 if (!catId.isEmpty() && !err) {
                                     err = subOperationObj.setCategory(m_mapIdCategory[catId]);
                                 }
+                                QString trackId = operation[QStringLiteral("class2")].toString();
+                                if (trackId.isEmpty() || trackId == QStringLiteral("-1")) {
+                                    trackId = operation[QStringLiteral("class1")].toString();
+                                }
+                                if (!trackId.isEmpty() && trackId != QStringLiteral("-1") && !err) {
+                                    err = subOperationObj.setTracker(m_mapIdTracker[trackId]);
+                                }
                                 IFOKDO(err, subOperationObj.setQuantity(amount))
                                 IFOKDO(err, subOperationObj.setComment(operation[QStringLiteral("memo")].toString()))
                                 IFOKDO(err, subOperationObj.save(false, false))
