@@ -79,11 +79,7 @@ SKGError SKGImportPluginQif::importFile()
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) {
-#ifdef SKG_QT6
                 stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
-#else
-                stream.setCodec(m_importer->getCodec().toLatin1().constData());
-#endif
             }
 
             // load file in memory
@@ -996,11 +992,7 @@ SKGError SKGImportPluginQif::exportFile()
     } else {
         QTextStream stream(&file);
         if (!m_importer->getCodec().isEmpty()) {
-#ifdef SKG_QT6
             stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
-#else
-            stream.setCodec(m_importer->getCodec().toLatin1().constData());
-#endif
         }
 
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export %1 file", "QIF"), 3);
