@@ -27,28 +27,29 @@
 #include "skgservices.h"
 #include "skgtraces.h"
 
-#define SQLDRIVERNAME QLatin1String("SKGSQLCIPHER")
+#define SQLDRIVERNAME QStringLiteral("SKGSQLCIPHER")
 /**
  * This plugin factory.
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginSkg, "metadata.json")
 
-SKGImportPluginSkg::SKGImportPluginSkg(QObject* iImporter, const QVariantList& iArg)
+SKGImportPluginSkg::SKGImportPluginSkg(QObject *iImporter, const QVariantList &iArg)
     : SKGImportPlugin(iImporter)
 {
     SKGTRACEINFUNC(10)
     Q_UNUSED(iArg)
 
-    m_importParameters[QLatin1String("password")] = QString();
+    m_importParameters[QStringLiteral("password")] = QString();
 }
 
-SKGImportPluginSkg::~SKGImportPluginSkg()
-    = default;
+SKGImportPluginSkg::~SKGImportPluginSkg() = default;
 
 bool SKGImportPluginSkg::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("SKG") || m_importer->getFileNameExtension() == QLatin1String("SQLITE") || m_importer->getFileNameExtension() == QLatin1String("SQLCIPHER"));
+    return (m_importer->getDocument() == nullptr ? true
+                                                 : m_importer->getFileNameExtension() == QStringLiteral("SKG")
+                    || m_importer->getFileNameExtension() == QStringLiteral("SQLITE") || m_importer->getFileNameExtension() == QStringLiteral("SQLCIPHER"));
 }
 
 SKGError SKGImportPluginSkg::importFile()
@@ -60,19 +61,22 @@ SKGError SKGImportPluginSkg::importFile()
     SKGTRACEINFUNCRC(2, err)
     QString lfile = m_importer->getLocalFileName();
     if (lfile.isEmpty()) {
-        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().toDisplayString()));
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message", "Open file '%1' failed", m_importer->getFileName().toDisplayString()));
     } else {
         SKGDocumentBank docOrigin;
-        err = docOrigin.load(lfile, m_importParameters.value(QLatin1String("password")));
-        IFOK(err) {
+        err = docOrigin.load(lfile, m_importParameters.value(QStringLiteral("password")));
+        IFOK(err)
+        {
             QMap<QString, SKGObjectBase> mapOriginNew;
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "SKG"), 10);
 
             // Step 1 - units
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGObjectBase::SKGListSKGObjectBase listUnits;
-                err = docOrigin.getObjects(QLatin1String("v_unit"), QLatin1String("1=1 order by rd_unit_id, t_type"), listUnits);
-                IFOK(err) {
+                err = docOrigin.getObjects(QStringLiteral("v_unit"), QStringLiteral("1=1 order by rd_unit_id, t_type"), listUnits);
+                IFOK(err)
+                {
                     int nb = listUnits.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -80,14 +84,16 @@ SKGError SKGImportPluginSkg::importFile()
                         SKGUnitObject unit(unitOrigin.cloneInto(m_importer->getDocument()));
                         if (unit.load().isFailed()) {
                             // This unit does not exist yet
-                            IFOK(err) {
+                            IFOK(err)
+                            {
                                 SKGUnitObject::UnitType unitType = unitOrigin.getType();
                                 if (unitType == SKGUnitObject::PRIMARY || unitType == SKGUnitObject::SECONDARY) {
                                     unitType = SKGUnitObject::CURRENCY;
                                 }
                                 err = unit.setType(unitType);
                             }
-                            IFOK(err) {
+                            IFOK(err)
+                            {
                                 SKGUnitObject parentUnitOrigin;
                                 unitOrigin.getUnit(parentUnitOrigin);
 
@@ -110,7 +116,7 @@ SKGError SKGImportPluginSkg::importFile()
                         for (int j = 0; !err && j < nb2; ++j) {
                             SKGUnitValueObject unitValueOrigin(listUnitsValues.at(j));
 
-                            SKGUnitValueObject  unitval;
+                            SKGUnitValueObject unitval;
                             err = unit.addUnitValue(unitval);
                             IFOKDO(err, unitval.setDate(unitValueOrigin.getDate()))
                             IFOKDO(err, unitval.setQuantity(unitValueOrigin.getQuantity()))
@@ -122,16 +128,18 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
             // Step 2 - bank and accounts
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGObjectBase::SKGListSKGObjectBase listBanks;
-                err = docOrigin.getObjects(QLatin1String("v_bank"), QString(), listBanks);
-                IFOK(err) {
+                err = docOrigin.getObjects(QStringLiteral("v_bank"), QString(), listBanks);
+                IFOK(err)
+                {
                     int nb = listBanks.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks and accounts"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -167,16 +175,18 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
             // Step 3 - categories
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGObjectBase::SKGListSKGObjectBase listCategories;
-                err = docOrigin.getObjects(QLatin1String("v_category"), QString(), listCategories);
-                IFOK(err) {
+                err = docOrigin.getObjects(QStringLiteral("v_category"), QString(), listCategories);
+                IFOK(err)
+                {
                     int nb = listCategories.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -190,16 +200,18 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
             // Step 4 - trackers
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGObjectBase::SKGListSKGObjectBase listRefund;
-                err = docOrigin.getObjects(QLatin1String("v_refund"), QString(), listRefund);
-                IFOK(err) {
+                err = docOrigin.getObjects(QStringLiteral("v_refund"), QString(), listRefund);
+                IFOK(err)
+                {
                     int nb = listRefund.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import trackers"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -212,37 +224,41 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
             // Step 5 - rules
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGObjectBase::SKGListSKGObjectBase listRules;
-                err = docOrigin.getObjects(QLatin1String("v_rule"), QString(), listRules);
-                IFOK(err) {
+                err = docOrigin.getObjects(QStringLiteral("v_rule"), QString(), listRules);
+                IFOK(err)
+                {
                     int nb = listRules.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import rules"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         SKGRuleObject rulOrigin(listRules.at(i));
                         SKGRuleObject rul(rulOrigin.cloneInto(m_importer->getDocument()));
-                        err = rul.save(false);  // Save only
+                        err = rul.save(false); // Save only
                         // Duplicate properties
                         IFOKDO(err, copyParameters(rulOrigin, rul))
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
             // Step 6 - payee
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGObjectBase::SKGListSKGObjectBase listPayee;
-                err = docOrigin.getObjects(QLatin1String("v_payee"), QString(), listPayee);
-                IFOK(err) {
+                err = docOrigin.getObjects(QStringLiteral("v_payee"), QString(), listPayee);
+                IFOK(err)
+                {
                     int nb = listPayee.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -258,50 +274,58 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
             // Step 7 - transactions and suboperation
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGObjectBase::SKGListSKGObjectBase listOperations;
-                err = docOrigin.getObjects(QLatin1String("v_operation"), QString(), listOperations);
-                IFOK(err) {
+                err = docOrigin.getObjects(QStringLiteral("v_operation"), QString(), listOperations);
+                IFOK(err)
+                {
                     int nb = listOperations.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         SKGOperationObject operationOrigin(listOperations.at(i));
                         SKGOperationObject operation(operationOrigin.cloneInto(m_importer->getDocument()));
-                        IFOKDO(err, operation.setAttribute(QLatin1String("r_recurrentoperation_id"), QString()))
+                        IFOKDO(err, operation.setAttribute(QStringLiteral("r_recurrentoperation_id"), QString()))
                         IFOKDO(err, operation.setImported(true))
-                        IFOK(err) {
+                        IFOK(err)
+                        {
                             QString importID = operationOrigin.getImportID();
                             if (importID.isEmpty()) {
                                 importID = "SKG-" % SKGServices::intToString(operationOrigin.getID());
                             }
                             err = operation.setImportID(importID);
                         }
-                        IFOK(err) {
+                        IFOK(err)
+                        {
                             SKGAccountObject actOrig;
                             err = operationOrigin.getParentAccount(actOrig);
-                            IFOK(err) {
+                            IFOK(err)
+                            {
                                 SKGAccountObject act(mapOriginNew[actOrig.getUniqueID()]);
-                                act.setClosed(false);  // To be sure that the modification is possible. NOT SAVED
+                                act.setClosed(false); // To be sure that the modification is possible. NOT SAVED
                                 IFOKDO(err, operation.setParentAccount(act))
                             }
                         }
-                        IFOK(err) {
+                        IFOK(err)
+                        {
                             SKGPayeeObject payeeOrig;
-                            operationOrigin.getPayee(payeeOrig);     // Error not managed
+                            operationOrigin.getPayee(payeeOrig); // Error not managed
                             IFOKDO(err, operation.setPayee(SKGPayeeObject(mapOriginNew[payeeOrig.getUniqueID()])))
                         }
-                        IFOK(err) {
+                        IFOK(err)
+                        {
                             SKGUnitObject unitOrig;
                             err = operationOrigin.getUnit(unitOrig);
                             IFOKDO(err, operation.setUnit(SKGUnitObject(mapOriginNew[unitOrig.getUniqueID()])))
                         }
-                        IFOK(err) {
+                        IFOK(err)
+                        {
                             SKGOperationObject groupOrig;
                             operationOrigin.getGroupOperation(groupOrig);
                             err = operation.setGroupOperation(SKGOperationObject(mapOriginNew[groupOrig.getUniqueID()]));
@@ -322,14 +346,16 @@ SKGError SKGImportPluginSkg::importFile()
 
                             SKGSubOperationObject subop(subopOrigin.cloneInto(m_importer->getDocument()));
                             err = subop.setParentOperation(operation);
-                            IFOK(err) {
+                            IFOK(err)
+                            {
                                 SKGCategoryObject catOrig;
-                                subopOrigin.getCategory(catOrig);    // Error not managed
+                                subopOrigin.getCategory(catOrig); // Error not managed
                                 err = subop.setCategory(SKGCategoryObject(mapOriginNew[catOrig.getUniqueID()]));
                             }
-                            IFOK(err) {
+                            IFOK(err)
+                            {
                                 SKGTrackerObject tracOrig;
-                                subopOrigin.getTracker(tracOrig);    // Error not managed
+                                subopOrigin.getTracker(tracOrig); // Error not managed
                                 IFOKDO(err, subop.setTracker(SKGTrackerObject(mapOriginNew[tracOrig.getUniqueID()]), true))
                             }
                             IFOKDO(err, subop.save(false))
@@ -340,22 +366,25 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
 
                         if (!err && i % 500 == 0) {
-                            err = m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE"));
+                            err = m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE"));
                         }
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(7))
             /*                                      SKGObjectBase opWithThisHash;
-                                                if ( SKGObjectBase::getObject ( m_importer->getDocument(), "operation", "t_imported IN ('Y','P') AND t_import_id='"+QString ( hash.toHex() ) +'\'', opWithThisHash ).isSucceeded() )*/
+                                                if ( SKGObjectBase::getObject ( m_importer->getDocument(), "operation", "t_imported IN ('Y','P') AND
+               t_import_id='"+QString ( hash.toHex() ) +'\'', opWithThisHash ).isSucceeded() )*/
 
             // Step 8 - recurrent
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGObjectBase::SKGListSKGObjectBase ListRecurrentOperations;
-                err = docOrigin.getObjects(QLatin1String("v_recurrentoperation"), QString(), ListRecurrentOperations);
-                IFOK(err) {
+                err = docOrigin.getObjects(QStringLiteral("v_recurrentoperation"), QString(), ListRecurrentOperations);
+                IFOK(err)
+                {
                     int nb = ListRecurrentOperations.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -373,23 +402,27 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(8))
 
             // Step 9 - nodes
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGObjectBase::SKGListSKGObjectBase listNodes;
-                err = docOrigin.getObjects(QLatin1String("v_node"), QString(), listNodes);
-                IFOK(err) {
+                err = docOrigin.getObjects(QStringLiteral("v_node"), QString(), listNodes);
+                IFOK(err)
+                {
                     int nb = listNodes.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import bookmarks"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         SKGNodeObject nodeOrigin(listNodes.at(i));
 
                         SKGNodeObject node;
-                        err = SKGNodeObject::createPathNode(m_importer->getDocument(), i18n("Imported bookmarks") % OBJECTSEPARATOR % nodeOrigin.getFullName(), node);
+                        err = SKGNodeObject::createPathNode(m_importer->getDocument(),
+                                                            i18n("Imported bookmarks") % OBJECTSEPARATOR % nodeOrigin.getFullName(),
+                                                            node);
                         IFOKDO(err, node.setData(nodeOrigin.getData()))
                         IFOKDO(err, node.setOrder(nodeOrigin.getOrder()))
                         IFOKDO(err, node.setAutoStart(nodeOrigin.isAutoStart()))
@@ -397,22 +430,25 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(9))
 
             // Step 10 - interest
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGObjectBase::SKGListSKGObjectBase listInterests;
-                err = docOrigin.getObjects(QLatin1String("v_interest"), QString(), listInterests);
-                IFOK(err) {
+                err = docOrigin.getObjects(QStringLiteral("v_interest"), QString(), listInterests);
+                IFOK(err)
+                {
                     int nb = listInterests.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import interests"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         SKGInterestObject interestOrigin(listInterests.at(i));
                         SKGInterestObject interest(interestOrigin.cloneInto(m_importer->getDocument()));
-                        IFOK(err) {
+                        IFOK(err)
+                        {
                             SKGAccountObject actOrig;
                             err = interestOrigin.getAccount(actOrig);
                             IFOKDO(err, interest.setAccount(SKGAccountObject(mapOriginNew[actOrig.getUniqueID()])))
@@ -425,21 +461,19 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                 }
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(10))
 
-            SKGENDTRANSACTION(m_importer->getDocument(),  err)
+            SKGENDTRANSACTION(m_importer->getDocument(), err)
 
-            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE")))
+            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE")))
         }
     }
     return err;
 }
 
-
-
 bool SKGImportPluginSkg::isExportPossible()
 {
     SKGTRACEINFUNC(10)
@@ -476,38 +510,43 @@ SKGError SKGImportPluginSkg::exportFile()
 
     QString tempFile = m_importer->getDocument()->getCurrentTemporaryFile();
     bool removeTempFile = false;
-    QString DBMode = m_importer->getDocument()->getParameter(QLatin1String("SKG_DATABASE_TYPE"));
+    QString DBMode = m_importer->getDocument()->getParameter(QStringLiteral("SKG_DATABASE_TYPE"));
 
-    if (m_importer->getDocument()->getCurrentFileName().isEmpty() || DBMode != QLatin1String("QSQLITE") || (ext == QLatin1String("SQLCIPHER") && !pwd.isEmpty())) {
+    if (m_importer->getDocument()->getCurrentFileName().isEmpty() || DBMode != QStringLiteral("QSQLITE")
+        || (ext == QStringLiteral("SQLCIPHER") && !pwd.isEmpty())) {
         // The database is only in memory
         tempFile = QDir::tempPath() % "/skg_" % QUuid::createUuid().toString() % ".skg";
         removeTempFile = true;
 
-        auto fileDb = QSqlDatabase::addDatabase(ext == QLatin1String("SQLITE") ? QLatin1String("QSQLITE") : SQLDRIVERNAME, tempFile);
+        auto fileDb = QSqlDatabase::addDatabase(ext == QStringLiteral("SQLITE") ? QStringLiteral("QSQLITE") : SQLDRIVERNAME, tempFile);
         fileDb.setDatabaseName(tempFile);
         if (!fileDb.open()) {
             // Set error message
             QSqlError sqlErr = fileDb.lastError();
             err = SKGError(SQLLITEERROR + sqlErr.nativeErrorCode().toInt(), sqlErr.text());
         } else {
-            if (ext == QLatin1String("SQLCIPHER") && !pwd.isEmpty()) {
+            if (ext == QStringLiteral("SQLCIPHER") && !pwd.isEmpty()) {
                 IFOKDO(err, SKGServices::executeSqliteOrder(fileDb, "PRAGMA KEY = '" % SKGServices::stringToSqlString(pwd) % "'"))
-                IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The sqlcipher database has been protected with the same password than your document"), SKGDocument::Information))
+                IFOKDO(err,
+                       m_importer->getDocument()->sendMessage(
+                           i18nc("An information message", "The sqlcipher database has been protected with the same password than your document"),
+                           SKGDocument::Information))
             }
 
             m_importer->getDocument()->getMainDatabase()->commit();
-            if (DBMode == QLatin1String("QSQLITE") && ext == QLatin1String("QSQLITE")) {
+            if (DBMode == QStringLiteral("QSQLITE") && ext == QStringLiteral("QSQLITE")) {
                 // The source database is a sqlite DB
                 IFOKDO(err, SKGServices::copySqliteDatabase(fileDb, *(m_importer->getDocument()->getMainDatabase()), false))
 
             } else {
                 // The source database is a sqcipher DB
-                if (ext == QLatin1String("SQLITE")) {
+                if (ext == QStringLiteral("SQLITE")) {
                     pwd = QString();
                 }
-                IFOKDO(err, m_importer->getDocument()->executeSqliteOrders(QStringList() << "ATTACH DATABASE '" % tempFile % "' AS sqlcipher KEY '" % SKGServices::stringToSqlString(pwd) % "'"
-                        << QLatin1String("SELECT SQLCIPHER_EXPORT('sqlcipher')")
-                        << QLatin1String("DETACH DATABASE sqlcipher")));
+                IFOKDO(err,
+                       m_importer->getDocument()->executeSqliteOrders(
+                           QStringList() << "ATTACH DATABASE '" % tempFile % "' AS sqlcipher KEY '" % SKGServices::stringToSqlString(pwd) % "'"
+                                         << QStringLiteral("SELECT SQLCIPHER_EXPORT('sqlcipher')") << QStringLiteral("DETACH DATABASE sqlcipher")));
             }
             m_importer->getDocument()->getMainDatabase()->transaction();
 
@@ -517,15 +556,17 @@ SKGError SKGImportPluginSkg::exportFile()
     }
 
     // Copy file to file
-    IFOK(err) {
-        if (ext != QLatin1String("SKG")) {
+    IFOK(err)
+    {
+        if (ext != QStringLiteral("SKG")) {
             if (SKGServices::upload(QUrl::fromLocalFile(tempFile), QUrl::fromLocalFile(file))) {
                 err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Creation file '%1' failed", file));
             }
         } else {
             bool mode;
             err = SKGServices::cryptFile(tempFile, file, QString(), true, m_importer->getDocument()->getDocumentHeader(), mode);
-            IFOK(err) {
+            IFOK(err)
+            {
                 SKGDocumentBank doc;
                 err = doc.load(file);
                 IFOKDO(err, doc.removeAllTransactions())
@@ -541,19 +582,21 @@ SKGError SKGImportPluginSkg::exportFile()
     return err;
 }
 
-SKGError SKGImportPluginSkg::copyParameters(const SKGObjectBase& iFrom, const SKGObjectBase& iTo)
+SKGError SKGImportPluginSkg::copyParameters(const SKGObjectBase &iFrom, const SKGObjectBase &iTo)
 {
     SKGError err;
 
     SKGObjectBase::SKGListSKGObjectBase params;
-    err = iFrom.getDocument()->getObjects(QLatin1String("parameters"), "t_uuid_parent='" % SKGServices::stringToSqlString(iFrom.getUniqueID()) % QLatin1Char('\''), params);
-    IFOK(err) {
+    err =
+        iFrom.getDocument()->getObjects(QStringLiteral("parameters"), "t_uuid_parent='" % SKGServices::stringToSqlString(iFrom.getUniqueID()) % u'\'', params);
+    IFOK(err)
+    {
         int nb = params.count();
-        SKGDocument* documentTarget = iTo.getDocument();
+        SKGDocument *documentTarget = iTo.getDocument();
         for (int i = 0; !err && i < nb; ++i) {
             SKGPropertyObject orig(params.at(i));
             SKGPropertyObject param(orig.cloneInto(documentTarget));
-            err = param.setAttribute(QLatin1String("t_uuid_parent"), iTo.getUniqueID());
+            err = param.setAttribute(QStringLiteral("t_uuid_parent"), iTo.getUniqueID());
             IFOKDO(err, param.save(true, false))
         }
     }
@@ -562,9 +605,8 @@ SKGError SKGImportPluginSkg::copyParameters(const SKGObjectBase& iFrom, const SK
 
 QString SKGImportPluginSkg::getMimeTypeFilter() const
 {
-    return "*.skg|" % i18nc("A file format", "Skrooge document") % '\n' %
-           "*.sqlcipher|" % i18nc("A file format", "SQLCipher document") % '\n' %
-           "*.sqlite|" % i18nc("A file format", "SQLite document");
+    return "*.skg|" % i18nc("A file format", "Skrooge document") % '\n' % "*.sqlcipher|" % i18nc("A file format", "SQLCipher document") % '\n' % "*.sqlite|"
+        % i18nc("A file format", "SQLite document");
 }
 
 #include <skgimportpluginskg.moc>
