@@ -26,20 +26,19 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginXhb, "metadata.json")
 
-SKGImportPluginXhb::SKGImportPluginXhb(QObject* iImporter, const QVariantList& iArg)
+SKGImportPluginXhb::SKGImportPluginXhb(QObject *iImporter, const QVariantList &iArg)
     : SKGImportPlugin(iImporter)
 {
     SKGTRACEINFUNC(10)
     Q_UNUSED(iArg)
 }
 
-SKGImportPluginXhb::~SKGImportPluginXhb()
-    = default;
+SKGImportPluginXhb::~SKGImportPluginXhb() = default;
 
 bool SKGImportPluginXhb::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("XHB"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("XHB"));
 }
 
 SKGError SKGImportPluginXhb::importFile()
@@ -54,7 +53,7 @@ SKGError SKGImportPluginXhb::importFile()
     // Open file
     KCompressionDevice file(m_importer->getLocalFileName(), KCompressionDevice::GZip);
     if (!file.open(QIODevice::ReadOnly)) {
-        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().toDisplayString()));
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message", "Open file '%1' failed", m_importer->getFileName().toDisplayString()));
     } else {
         QDomDocument doc;
 
@@ -62,28 +61,24 @@ SKGError SKGImportPluginXhb::importFile()
         QString errorMsg;
         int errorLine = 0;
         int errorCol = 0;
-        bool contentOK = false;        
-#ifdef SKG_QT6
-        const auto& content = QString::fromUtf8(file.readAll());
-        const auto& result= doc.setContent(content);
+        bool contentOK = false;
+        const auto &content = QString::fromUtf8(file.readAll());
+        const auto &result = doc.setContent(content);
 
         contentOK = !!result;
-        errorLine =result.errorLine;
-        errorCol =result.errorColumn;
-        errorMsg =result.errorMessage;
-#else        
-        contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
-#endif
+        errorLine = result.errorLine;
+        errorCol = result.errorColumn;
+        errorMsg = result.errorMessage;
         file.close();
 
         // Get root
         QDomElement docElem = doc.documentElement();
 
         if (!contentOK) {
-            err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
+            err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message", "%1-%2: '%3'", errorLine, errorCol, errorMsg));
         }
         if (!contentOK) {
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().toDisplayString()));
+            err.addError(ERR_INVALIDARG, i18nc("Error message", "Invalid XML content in file '%1'", m_importer->getFileName().toDisplayString()));
         } else {
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "XHB"), 4);
 
@@ -95,8 +90,9 @@ SKGError SKGImportPluginXhb::importFile()
             IFOKDO(err, m_importer->getDefaultUnit(unit))
 
             // Step 1-Create accounts
-            IFOK(err) {
-                QDomNodeList accountList = docElem.elementsByTagName(QLatin1String("account"));
+            IFOK(err)
+            {
+                QDomNodeList accountList = docElem.elementsByTagName(QStringLiteral("account"));
                 int nb = accountList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import accounts"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
@@ -105,9 +101,9 @@ SKGError SKGImportPluginXhb::importFile()
 
                     // Create the bank
                     SKGBankObject bank(m_importer->getDocument());
-                    QString bname = getAttribute(account,  QLatin1String("bankname"));
+                    QString bname = getAttribute(account, QStringLiteral("bankname"));
                     if (bname.isEmpty()) {
-                        bname = QLatin1String("HOMEBANK");
+                        bname = QStringLiteral("HOMEBANK");
                     }
                     IFOKDO(err, bank.setName(bname))
                     IFOKDO(err, bank.save())
@@ -115,15 +111,23 @@ SKGError SKGImportPluginXhb::importFile()
                     // Creation of the account
                     SKGAccountObject accountObj;
                     IFOKDO(err, bank.addAccount(accountObj))
-                    IFOKDO(err, accountObj.setName(getAttribute(account,  QLatin1String("name"))))
-                    IFOKDO(err, accountObj.setNumber(getAttribute(account,  QLatin1String("number"))))
-                    IFOKDO(err, accountObj.setMinLimitAmount(SKGServices::stringToDouble(getAttribute(account,  QLatin1String("minimum")))))
+                    IFOKDO(err, accountObj.setName(getAttribute(account, QStringLiteral("name"))))
+                    IFOKDO(err, accountObj.setNumber(getAttribute(account, QStringLiteral("number"))))
+                    IFOKDO(err, accountObj.setMinLimitAmount(SKGServices::stringToDouble(getAttribute(account, QStringLiteral("minimum")))))
                     IFOKDO(err, accountObj.minLimitAmountEnabled(accountObj.getMinLimitAmount() != 0.0))
-                    QString type = getAttribute(account,  QLatin1String("type"));
-                    IFOKDO(err, accountObj.setType(type == QLatin1String("2") ? SKGAccountObject::WALLET : (type == QLatin1String("3") ? SKGAccountObject::ASSETS : (type == QLatin1String("4") ? SKGAccountObject::CREDITCARD : (type == QLatin1String("5") ? SKGAccountObject::LOAN : SKGAccountObject::CURRENT)))))
-                    IFOK(err) {
-                        QString flags = getAttribute(account,  QLatin1String("flags"));
-                        err = accountObj.setClosed(flags == QLatin1String("2") ||  flags == QLatin1String("3"));
+                    QString type = getAttribute(account, QStringLiteral("type"));
+                    IFOKDO(err,
+                           accountObj.setType(type == QStringLiteral("2")
+                                                  ? SKGAccountObject::WALLET
+                                                  : (type == QStringLiteral("3")
+                                                         ? SKGAccountObject::ASSETS
+                                                         : (type == QStringLiteral("4")
+                                                                ? SKGAccountObject::CREDITCARD
+                                                                : (type == QStringLiteral("5") ? SKGAccountObject::LOAN : SKGAccountObject::CURRENT)))))
+                    IFOK(err)
+                    {
+                        QString flags = getAttribute(account, QStringLiteral("flags"));
+                        err = accountObj.setClosed(flags == QStringLiteral("2") || flags == QStringLiteral("3"));
                     }
                     IFOKDO(err, accountObj.save())
 
@@ -142,39 +146,41 @@ SKGError SKGImportPluginXhb::importFile()
                     }
 
                     // Set initial balance
-                    IFOKDO(err, accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  QLatin1String("initial"))), unit))
+                    IFOKDO(err, accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account, QStringLiteral("initial"))), unit))
 
-                    mapIdAccount[getAttribute(account,  QLatin1String("key"))] = accountObj;
+                    mapIdAccount[getAttribute(account, QStringLiteral("key"))] = accountObj;
 
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                SKGENDTRANSACTION(m_importer->getDocument(), err)
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
             // Step 2-Get payees
-            IFOK(err) {
-                QDomNodeList partyList = docElem.elementsByTagName(QLatin1String("pay"));
+            IFOK(err)
+            {
+                QDomNodeList partyList = docElem.elementsByTagName(QStringLiteral("pay"));
                 int nb = partyList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     // Get payee object
                     QDomElement party = partyList.at(i).toElement();
                     SKGPayeeObject payeeObject;
-                    err = SKGPayeeObject::createPayee(m_importer->getDocument(), getAttribute(party,  QLatin1String("name")), payeeObject);
-                    mapIdPayee[getAttribute(party,  QLatin1String("key"))] = payeeObject;
+                    err = SKGPayeeObject::createPayee(m_importer->getDocument(), getAttribute(party, QStringLiteral("name")), payeeObject);
+                    mapIdPayee[getAttribute(party, QStringLiteral("key"))] = payeeObject;
 
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                SKGENDTRANSACTION(m_importer->getDocument(), err)
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
             // Step 3-Create categories
-            IFOK(err) {
-                QDomNodeList categoryList = docElem.elementsByTagName(QLatin1String("cat"));
+            IFOK(err)
+            {
+                QDomNodeList categoryList = docElem.elementsByTagName(QStringLiteral("cat"));
                 int nb = categoryList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), 2 * nb);
                 for (int j = 0; !err && j < 2; ++j) {
@@ -185,31 +191,31 @@ SKGError SKGImportPluginXhb::importFile()
                         // Creation of the category
                         bool catCreated = false;
                         SKGCategoryObject catObj(m_importer->getDocument());
-                        QString parent2 = getAttribute(category,  QLatin1String("parent"));
+                        QString parent2 = getAttribute(category, QStringLiteral("parent"));
                         if (parent2.isEmpty()) {
                             parent2 = '0';
                         }
-                        if (parent2 == QLatin1String("0") && j == 0) {
-                            IFOKDO(err, catObj.setName(getAttribute(category,  QLatin1String("name"))))
+                        if (parent2 == QStringLiteral("0") && j == 0) {
+                            IFOKDO(err, catObj.setName(getAttribute(category, QStringLiteral("name"))))
                             IFOKDO(err, catObj.save())
 
-                            mapIdCategory[getAttribute(category,  QLatin1String("key"))] = catObj;
+                            mapIdCategory[getAttribute(category, QStringLiteral("key"))] = catObj;
                             catCreated = true;
 
-                        } else if (parent2 != QLatin1String("0") && j == 1) {
+                        } else if (parent2 != QStringLiteral("0") && j == 1) {
                             SKGCategoryObject catParentObj = mapIdCategory[parent2];
-                            IFOKDO(err, catObj.setName(getAttribute(category,  QLatin1String("name"))))
+                            IFOKDO(err, catObj.setName(getAttribute(category, QStringLiteral("name"))))
                             IFOKDO(err, catObj.setParentCategory(catParentObj))
                             IFOKDO(err, catObj.save())
 
-                            mapIdCategory[getAttribute(category,  QLatin1String("key"))] = catObj;
+                            mapIdCategory[getAttribute(category, QStringLiteral("key"))] = catObj;
                             catCreated = true;
                         }
 
                         // Creation of the attached budget
                         if (!err && catCreated) {
-                            QString b0 = getAttribute(category,  QLatin1String("b0"));
-                            QString b1 = getAttribute(category,  QLatin1String("b1"));
+                            QString b0 = getAttribute(category, QStringLiteral("b0"));
+                            QString b1 = getAttribute(category, QStringLiteral("b1"));
                             if (!b0.isEmpty() || !b1.isEmpty()) {
                                 for (int m = 1; !err && m <= 12; ++m) {
                                     SKGBudgetObject budget(m_importer->getDocument());
@@ -218,7 +224,9 @@ SKGError SKGImportPluginXhb::importFile()
                                     IFOKDO(err, budget.setCategory(catObj))
                                     IFOKDO(err, budget.setYear(year))
                                     IFOKDO(err, budget.setMonth(m))
-                                    IFOKDO(err, budget.setBudgetedAmount(SKGServices::stringToDouble(getAttribute(category,  QLatin1Char('b') % SKGServices::intToString(b0.isEmpty() ? m : 0)))))
+                                    IFOKDO(err,
+                                           budget.setBudgetedAmount(SKGServices::stringToDouble(
+                                               getAttribute(category, QLatin1Char('b') % SKGServices::intToString(b0.isEmpty() ? m : 0)))))
                                     IFOKDO(err, budget.save())
                                 }
                             }
@@ -228,15 +236,16 @@ SKGError SKGImportPluginXhb::importFile()
                     }
                 }
 
-                SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                SKGENDTRANSACTION(m_importer->getDocument(), err)
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
             // Step 4-Create transaction
-            IFOK(err) {
+            IFOK(err)
+            {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), 2);
                 for (int j = 1; !err && j <= 2; ++j) {
-                    QDomNodeList transactionList = docElem.elementsByTagName(j == 1 ? QLatin1String("ope") : QLatin1String("fav"));
+                    QDomNodeList transactionList = docElem.elementsByTagName(j == 1 ? QStringLiteral("ope") : QStringLiteral("fav"));
                     int nb = transactionList.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -244,29 +253,32 @@ SKGError SKGImportPluginXhb::importFile()
                         QDomElement transaction = transactionList.at(i).toElement();
 
                         // Get attributes
-                        QString idAccount = getAttribute(transaction,  QLatin1String("account"));
-                        // QString dst_account = getAttribute(transaction,  QLatin1String("dst_account"));
-                        if (idAccount != QLatin1String("0")) {
+                        QString idAccount = getAttribute(transaction, QStringLiteral("account"));
+                        // QString dst_account = getAttribute(transaction,  QStringLiteral("dst_account"));
+                        if (idAccount != QStringLiteral("0")) {
                             SKGAccountObject account = mapIdAccount[idAccount];
-                            QDate date = QDate(1, 1, 1).addDays(1 + SKGServices::stringToInt(getAttribute(transaction,  j == 1 ? QLatin1String("date") : QLatin1String("nextdate"))));
-                            QString mode = getAttribute(transaction,  QLatin1String("paymode"));
-                            if (mode == QLatin1String("1")) {
-                                mode = i18nc("Noun: type of payement", "Credit card");
-                            } else if (mode == QLatin1String("2")) {
-                                mode = i18nc("Noun: type of payement", "Check");
-                            } else if (mode == QLatin1String("3")) {
-                                mode = i18nc("Noun: type of payement", "Cash");
-                            } else if (mode == QLatin1String("4") || mode == QLatin1String("5")) {
-                                mode = i18nc("Noun: type of payement", "Transfer");
+                            QDate date = QDate(1, 1, 1).addDays(
+                                1 + SKGServices::stringToInt(getAttribute(transaction, j == 1 ? QStringLiteral("date") : QStringLiteral("nextdate"))));
+                            QString mode = getAttribute(transaction, QStringLiteral("paymode"));
+                            if (mode == QStringLiteral("1")) {
+                                mode = i18nc("Noun: type of payment", "Credit card");
+                            } else if (mode == QStringLiteral("2")) {
+                                mode = i18nc("Noun: type of payment", "Check");
+                            } else if (mode == QStringLiteral("3")) {
+                                mode = i18nc("Noun: type of payment", "Cash");
+                            } else if (mode == QStringLiteral("4") || mode == QStringLiteral("5")) {
+                                mode = i18nc("Noun: type of payment", "Transfer");
                             } else {
-                                mode = i18nc("Noun: type of payement", "Other");
+                                mode = i18nc("Noun: type of payment", "Other");
                             }
-                            QString comment = QString(getAttribute(transaction,  QLatin1String("wording")) % QLatin1Char(' ') % getAttribute(transaction,  QLatin1String("info"))).trimmed();
-                            int flags = SKGServices::stringToInt(getAttribute(transaction,  QLatin1String("flags")));
-                            double amount = SKGServices::stringToDouble(getAttribute(transaction,  QLatin1String("amount")));
-                            SKGOperationObject::OperationStatus status = (flags == 1 ||  flags == 3 ? SKGOperationObject::CHECKED : SKGOperationObject::NONE);
-                            SKGPayeeObject payee = mapIdPayee[ getAttribute(transaction,  QLatin1String("payee"))];
-                            SKGCategoryObject category = mapIdCategory[getAttribute(transaction,  QLatin1String("category"))];
+                            QString comment =
+                                QString(getAttribute(transaction, QStringLiteral("wording")) % u' ' % getAttribute(transaction, QStringLiteral("info")))
+                                    .trimmed();
+                            int flags = SKGServices::stringToInt(getAttribute(transaction, QStringLiteral("flags")));
+                            double amount = SKGServices::stringToDouble(getAttribute(transaction, QStringLiteral("amount")));
+                            SKGOperationObject::OperationStatus status = (flags == 1 || flags == 3 ? SKGOperationObject::CHECKED : SKGOperationObject::NONE);
+                            SKGPayeeObject payee = mapIdPayee[getAttribute(transaction, QStringLiteral("payee"))];
+                            SKGCategoryObject category = mapIdCategory[getAttribute(transaction, QStringLiteral("category"))];
 
                             // Creation of the transaction
                             SKGOperationObject opObj;
@@ -290,7 +302,7 @@ SKGError SKGImportPluginXhb::importFile()
                             IFOKDO(err, subObj.setQuantity(amount))
                             IFOKDO(err, subObj.save())
 
-                            QString tags = getAttribute(transaction,  QLatin1String("tags"));
+                            QString tags = getAttribute(transaction, QStringLiteral("tags"));
                             if (!tags.isEmpty()) {
                                 SKGTrackerObject tracker;
                                 IFOKDO(err, SKGTrackerObject::createTracker(m_importer->getDocument(), tags, tracker))
@@ -331,11 +343,11 @@ SKGError SKGImportPluginXhb::importFile()
                                 // Creation of scheduled transaction
                                 SKGRecurrentOperationObject recu;
                                 IFOKDO(err, opObj.addRecurrentOperation(recu))
-                                int limit = SKGServices::stringToInt(getAttribute(transaction,  QLatin1String("limit")));
+                                int limit = SKGServices::stringToInt(getAttribute(transaction, QStringLiteral("limit")));
                                 IFOKDO(err, recu.timeLimit(flags & (1 << 7)))
                                 IFOKDO(err, recu.setTimeLimit(limit))
-                                int punit = SKGServices::stringToInt(getAttribute(transaction,  QLatin1String("unit")));
-                                int pstep = SKGServices::stringToInt(getAttribute(transaction,  QLatin1String("every")));
+                                int punit = SKGServices::stringToInt(getAttribute(transaction, QStringLiteral("unit")));
+                                int pstep = SKGServices::stringToInt(getAttribute(transaction, QStringLiteral("every")));
                                 SKGRecurrentOperationObject::PeriodUnit p = SKGRecurrentOperationObject::MONTH;
                                 if (punit == 0) {
                                     p = SKGRecurrentOperationObject::DAY;
@@ -361,32 +373,32 @@ SKGError SKGImportPluginXhb::importFile()
                         }
 
                         if (!err && i % 500 == 0) {
-                            err = m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE"));
+                            err = m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE"));
                         }
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                    SKGENDTRANSACTION(m_importer->getDocument(), err)
                     IFOKDO(err, m_importer->getDocument()->stepForward(j))
                 }
 
-                SKGENDTRANSACTION(m_importer->getDocument(),  err)
+                SKGENDTRANSACTION(m_importer->getDocument(), err)
             }
             IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
-            SKGENDTRANSACTION(m_importer->getDocument(),  err)
+            SKGENDTRANSACTION(m_importer->getDocument(), err)
 
-            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE")))
+            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE")))
         }
     }
 
     return err;
 }
 
-QString SKGImportPluginXhb::getAttribute(const QDomElement& iElement, const QString& iAttribute)
+QString SKGImportPluginXhb::getAttribute(const QDomElement &iElement, const QString &iAttribute)
 {
     QString val = iElement.attribute(iAttribute);
-    if (val == QLatin1String("(null)")) {
+    if (val == QStringLiteral("(null)")) {
         val = QString();
     }
     return val;
