@@ -67,7 +67,6 @@ SKGError SKGImportPluginXml::getXMLDocument(const QString &iFileName, QDomElemen
         int errorLine = 0;
         int errorCol = 0;
         bool contentOK = false;
-#ifdef SKG_QT6
         const auto &content = QString::fromUtf8(file.readAll());
         const auto &result = doc.setContent(content);
 
@@ -75,9 +74,6 @@ SKGError SKGImportPluginXml::getXMLDocument(const QString &iFileName, QDomElemen
         errorLine = result.errorLine;
         errorCol = result.errorColumn;
         errorMsg = result.errorMessage;
-#else
-        contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
-#endif
         file.close();
 
         if (!contentOK) {
@@ -111,12 +107,27 @@ SKGError SKGImportPluginXml::importFile()
             // SKROOGE XML FORMAT
             format = QStringLiteral("XML");
         } else if (docElem.tagName() == "Document") {
+            // Check install
+            QString saxonb_bin;
+            if (QStandardPaths::findExecutable(QStringLiteral("saxonb-xslt")).isEmpty()) {
+                if (QStandardPaths::findExecutable(QStringLiteral("saxon-xslt")).isEmpty()) {
+                    err.setReturnCode(ERR_ABORT).setMessage(
+                        i18nc("Error message",
+                              "The saxon-xslt application is not installed. You must manually install it. This could be by the package libsaxonb-java."));
+                    return err;
+                } else {
+                    saxonb_bin = QStringLiteral("saxon-xslt");
+                }
+            } else {
+                saxonb_bin = QStringLiteral("saxonb-xslt");
+            }
+
             // ISO20022 XML FORMAT
             QString uniqueId = QUuid::createUuid().toString();
             QString temporaryPath = QDir::tempPath() % "/" % uniqueId % ".xml";
-            QString cmd = "sed -E 's/ xmlns(:[a-zA-Z0-9]+)?=\"[^\"]+\"//g' \"" % m_importer->getLocalFileName() % "\" > \"" % temporaryPath
-                % "\";saxonb-xslt -xsl:\"" % QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/ISO20022.xslt")) % "\" -s:\""
-                % temporaryPath % "\" -o:\"" % temporaryPath % "\"";
+            QString cmd = "sed -E 's/<Document .*>/<Document>/g' \"" % m_importer->getLocalFileName() % "\" > \"" % temporaryPath % "\";saxonb-xslt -xsl:\""
+                % QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/ISO20022.xslt")) % "\" -s:\"" % temporaryPath % "\" -o:\""
+                % temporaryPath % "\"";
             SKGTRACEL(10) << "Execution of :" << cmd << Qt::endl;
 
             QProcess p;
@@ -204,11 +215,7 @@ SKGError SKGImportPluginXml::exportFile()
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) {
-#ifdef SKG_QT6
                 stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
-#else
-                stream.setCodec(m_importer->getCodec().toLatin1().constData());
-#endif
             }
             stream << doc.toString() << Qt::endl;
 
