@@ -22,8 +22,9 @@
 #include "skgtraces.h"
 #include "skgunitobject.h"
 
-SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDocument)
-    : SKGBoardWidget(iParent, iDocument, i18nc("Title of a dashboard widget", "Accounts")), m_refreshNeeded(true)
+SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget *iParent, SKGDocument *iDocument)
+    : SKGBoardWidget(iParent, iDocument, i18nc("Title of a dashboard widget", "Accounts"))
+    , m_refreshNeeded(true)
 {
     SKGTRACEINFUNC(10)
 
@@ -31,10 +32,10 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
     // menu
-    m_menuFavorite = new QAction(SKGServices::fromTheme(QLatin1String("bookmarks")), i18nc("Display only favorite accounts", "Highlighted only"), this);
+    m_menuFavorite = new QAction(SKGServices::fromTheme(QStringLiteral("bookmarks")), i18nc("Display only favorite accounts", "Highlighted only"), this);
     m_menuFavorite->setCheckable(true);
     m_menuFavorite->setChecked(false);
-    connect(m_menuFavorite, &QAction::triggered, this, [ = ]() {
+    connect(m_menuFavorite, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuFavorite);
@@ -42,7 +43,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     m_menuPastOperations = new QAction(i18nc("Noun, a type of account", "Only past transactions"), this);
     m_menuPastOperations->setCheckable(true);
     m_menuPastOperations->setChecked(false);
-    connect(m_menuPastOperations, &QAction::triggered, this, [ = ]() {
+    connect(m_menuPastOperations, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuPastOperations);
@@ -56,7 +57,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     m_menuCurrent = new QAction(i18nc("Noun, a type of account", "Current"), this);
     m_menuCurrent->setCheckable(true);
     m_menuCurrent->setChecked(true);
-    connect(m_menuCurrent, &QAction::triggered, this, [ = ]() {
+    connect(m_menuCurrent, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuCurrent);
@@ -64,7 +65,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     m_menuCreditCard = new QAction(i18nc("Noun, a type of account", "Credit card"), this);
     m_menuCreditCard->setCheckable(true);
     m_menuCreditCard->setChecked(true);
-    connect(m_menuCreditCard, &QAction::triggered, this, [ = ]() {
+    connect(m_menuCreditCard, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuCreditCard);
@@ -72,7 +73,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     m_menuSaving = new QAction(i18nc("Noun, a type of account", "Saving"), this);
     m_menuSaving->setCheckable(true);
     m_menuSaving->setChecked(true);
-    connect(m_menuSaving, &QAction::triggered, this, [ = ]() {
+    connect(m_menuSaving, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuSaving);
@@ -80,7 +81,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     m_menuInvestment = new QAction(i18nc("Noun, a type of account", "Investment"), this);
     m_menuInvestment->setCheckable(true);
     m_menuInvestment->setChecked(true);
-    connect(m_menuInvestment, &QAction::triggered, this, [ = ]() {
+    connect(m_menuInvestment, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuInvestment);
@@ -88,7 +89,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     m_menuAssets = new QAction(i18nc("Noun, a type of account", "Assets"), this);
     m_menuAssets->setCheckable(true);
     m_menuAssets->setChecked(true);
-    connect(m_menuAssets, &QAction::triggered, this, [ = ]() {
+    connect(m_menuAssets, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuAssets);
@@ -96,7 +97,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     m_menuLoan = new QAction(i18nc("Noun, a type of account", "Loan"), this);
     m_menuLoan->setCheckable(true);
     m_menuLoan->setChecked(true);
-    connect(m_menuLoan, &QAction::triggered, this, [ = ]() {
+    connect(m_menuLoan, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuLoan);
@@ -104,7 +105,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     m_menuPension = new QAction(i18nc("Noun, a type of account", "Pension"), this);
     m_menuPension->setCheckable(true);
     m_menuPension->setChecked(true);
-    connect(m_menuPension, &QAction::triggered, this, [ = ]() {
+    connect(m_menuPension, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuPension);
@@ -112,7 +113,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     m_menuWallet = new QAction(i18nc("Noun, a type of account", "Wallet"), this);
     m_menuWallet->setCheckable(true);
     m_menuWallet->setChecked(true);
-    connect(m_menuWallet, &QAction::triggered, this, [ = ]() {
+    connect(m_menuWallet, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuWallet);
@@ -120,7 +121,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     m_menuOther = new QAction(i18nc("Noun, a type of account", "Other"), this);
     m_menuOther->setCheckable(true);
     m_menuOther->setChecked(true);
-    connect(m_menuOther, &QAction::triggered, this, [ = ]() {
+    connect(m_menuOther, &QAction::triggered, this, [this]() {
         this->dataModified();
     });
     addAction(m_menuOther);
@@ -131,7 +132,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     // Refresh
     connect(getDocument(), &SKGDocument::tableModified, this, &SKGAccountBoardWidget::dataModified, Qt::QueuedConnection);
     connect(SKGMainPanel::getMainPanel(), &SKGMainPanel::currentPageChanged, this, &SKGAccountBoardWidget::pageChanged, Qt::QueuedConnection);
-    connect(m_label, &QLabel::linkActivated, this, [ = ](const QString & val) {
+    connect(m_label, &QLabel::linkActivated, this, [](const QString &val) {
         SKGMainPanel::getMainPanel()->openPage(val);
     });
 }
@@ -154,182 +155,195 @@ SKGAccountBoardWidget::~SKGAccountBoardWidget()
 
 QString SKGAccountBoardWidget::getState()
 {
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(SKGBoardWidget::getState());
     QDomElement root = doc.documentElement();
 
-    root.setAttribute(QLatin1String("menuFavorite"), (m_menuFavorite != nullptr) && m_menuFavorite->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
-    root.setAttribute(QLatin1String("menuAssets"), (m_menuAssets != nullptr) && m_menuAssets->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
-    root.setAttribute(QLatin1String("menuCurrent"), (m_menuCurrent != nullptr) && m_menuCurrent->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
-    root.setAttribute(QLatin1String("menuCreditCard"), (m_menuCreditCard != nullptr) && m_menuCreditCard->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
-    root.setAttribute(QLatin1String("menuSaving"), (m_menuSaving != nullptr) && m_menuSaving->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
-    root.setAttribute(QLatin1String("menuInvestment"), (m_menuInvestment != nullptr) && m_menuInvestment->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
-    root.setAttribute(QLatin1String("menuWallet"), (m_menuWallet != nullptr) && m_menuWallet->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
-    root.setAttribute(QLatin1String("menuLoan"), (m_menuLoan != nullptr) && m_menuLoan->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
-    root.setAttribute(QLatin1String("menuPension"), (m_menuPension != nullptr) && m_menuPension->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
-    root.setAttribute(QLatin1String("menuOther"), (m_menuOther != nullptr) && m_menuOther->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
-    root.setAttribute(QLatin1String("menuPastOperations"), (m_menuPastOperations != nullptr) && m_menuPastOperations->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QStringLiteral("menuFavorite"), (m_menuFavorite != nullptr) && m_menuFavorite->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuAssets"), (m_menuAssets != nullptr) && m_menuAssets->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuCurrent"), (m_menuCurrent != nullptr) && m_menuCurrent->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuCreditCard"),
+                      (m_menuCreditCard != nullptr) && m_menuCreditCard->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuSaving"), (m_menuSaving != nullptr) && m_menuSaving->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuInvestment"),
+                      (m_menuInvestment != nullptr) && m_menuInvestment->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuWallet"), (m_menuWallet != nullptr) && m_menuWallet->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuLoan"), (m_menuLoan != nullptr) && m_menuLoan->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuPension"), (m_menuPension != nullptr) && m_menuPension->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuOther"), (m_menuOther != nullptr) && m_menuOther->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuPastOperations"),
+                      (m_menuPastOperations != nullptr) && m_menuPastOperations->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
 
     return doc.toString();
 }
 
-void SKGAccountBoardWidget::setState(const QString& iState)
+void SKGAccountBoardWidget::setState(const QString &iState)
 {
     SKGBoardWidget::setState(iState);
 
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     if (m_menuFavorite != nullptr) {
-        m_menuFavorite->setChecked(root.attribute(QLatin1String("menuFavorite")) == QLatin1String("Y"));
+        m_menuFavorite->setChecked(root.attribute(QStringLiteral("menuFavorite")) == QStringLiteral("Y"));
     }
     if (m_menuAssets != nullptr) {
-        m_menuAssets->setChecked(root.attribute(QLatin1String("menuAssets")) != QLatin1String("N"));
+        m_menuAssets->setChecked(root.attribute(QStringLiteral("menuAssets")) != QStringLiteral("N"));
     }
     if (m_menuCurrent != nullptr) {
-        m_menuCurrent->setChecked(root.attribute(QLatin1String("menuCurrent")) != QLatin1String("N"));
+        m_menuCurrent->setChecked(root.attribute(QStringLiteral("menuCurrent")) != QStringLiteral("N"));
     }
     if (m_menuCreditCard != nullptr) {
-        m_menuCreditCard->setChecked(root.attribute(QLatin1String("menuCreditCard")) != QLatin1String("N"));
+        m_menuCreditCard->setChecked(root.attribute(QStringLiteral("menuCreditCard")) != QStringLiteral("N"));
     }
     if (m_menuSaving != nullptr) {
-        m_menuSaving->setChecked(root.attribute(QLatin1String("menuSaving")) != QLatin1String("N"));
+        m_menuSaving->setChecked(root.attribute(QStringLiteral("menuSaving")) != QStringLiteral("N"));
     }
     if (m_menuInvestment != nullptr) {
-        m_menuInvestment->setChecked(root.attribute(QLatin1String("menuInvestment")) != QLatin1String("N"));
+        m_menuInvestment->setChecked(root.attribute(QStringLiteral("menuInvestment")) != QStringLiteral("N"));
     }
     if (m_menuWallet != nullptr) {
-        m_menuWallet->setChecked(root.attribute(QLatin1String("menuWallet")) != QLatin1String("N"));
+        m_menuWallet->setChecked(root.attribute(QStringLiteral("menuWallet")) != QStringLiteral("N"));
     }
     if (m_menuLoan != nullptr) {
-        m_menuLoan->setChecked(root.attribute(QLatin1String("menuLoan")) != QLatin1String("N"));
+        m_menuLoan->setChecked(root.attribute(QStringLiteral("menuLoan")) != QStringLiteral("N"));
     }
     if (m_menuPension != nullptr) {
-        m_menuPension->setChecked(root.attribute(QLatin1String("menuPension")) != QLatin1String("N"));
+        m_menuPension->setChecked(root.attribute(QStringLiteral("menuPension")) != QStringLiteral("N"));
     }
     if (m_menuOther != nullptr) {
-        m_menuOther->setChecked(root.attribute(QLatin1String("menuOther")) != QLatin1String("N"));
+        m_menuOther->setChecked(root.attribute(QStringLiteral("menuOther")) != QStringLiteral("N"));
     }
     if (m_menuPastOperations != nullptr) {
-        m_menuPastOperations->setChecked(root.attribute(QLatin1String("menuPastOperations")) == QLatin1String("Y"));
+        m_menuPastOperations->setChecked(root.attribute(QStringLiteral("menuPastOperations")) == QStringLiteral("Y"));
     }
 
-    dataModified(QLatin1String(""), 0);
+    dataModified(QString(), 0);
 }
 
 void SKGAccountBoardWidget::pageChanged()
 {
     if (m_refreshNeeded) {
-        dataModified(QLatin1String(""), 0);
+        dataModified(QString(), 0);
     }
 }
 
-void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
+void SKGAccountBoardWidget::dataModified(const QString &iTableName, int iIdTransaction)
 {
     Q_UNUSED(iIdTransaction)
 
-    if (iTableName == QLatin1String("v_account_display") || iTableName.isEmpty()) {
+    if (iTableName == QStringLiteral("v_account_display") || iTableName.isEmpty()) {
         SKGTRACEINFUNC(10)
-        SKGTabPage* page = SKGTabPage::parentTabPage(this);
+        SKGTabPage *page = SKGTabPage::parentTabPage(this);
         if (page != nullptr && page != SKGMainPanel::getMainPanel()->currentPage()) {
             m_refreshNeeded = true;
             return;
         }
 
         m_refreshNeeded = false;
-        auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+        auto *doc = qobject_cast<SKGDocumentBank *>(getDocument());
         if (doc != nullptr) {
             SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
             bool exist = false;
-            SKGError err = doc->existObjects(QLatin1String("account"), QLatin1String(""), exist);
-            IFOK(err) {
+            SKGError err = doc->existObjects(QStringLiteral("account"), QString(), exist);
+            IFOK(err)
+            {
                 QString html;
                 if (!exist) {
-                    html = "<html><body>" % i18nc("Message, do not translate URL", "First, you have to create at least one account<br>from <a href=\"%1\">\"Bank and Account\"</a> page or <a href=\"%2\">import</a> transactions.", "skg://Skrooge_bank_plugin", "skg://import_operation") % "</body></html>";
+                    html = "<html><body>"
+                        % i18nc("Message, do not translate URL",
+                                "First, you have to create at least one account<br>from <a href=\"%1\">\"Bank and Account\"</a> page or <a "
+                                "href=\"%2\">import</a> transactions.",
+                                "skg://Skrooge_bank_plugin",
+                                "skg://import_operation")
+                        % "</body></html>";
                 } else {
                     // Build where clause
                     QString wc;
                     if ((m_menuAssets != nullptr) && m_menuAssets->isChecked()) {
-                        wc = QLatin1String("t_type='A'");
+                        wc = QStringLiteral("t_type='A'");
                     }
                     if ((m_menuCurrent != nullptr) && m_menuCurrent->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QLatin1String(" OR ");
+                            wc += QStringLiteral(" OR ");
                         }
-                        wc += QLatin1String("t_type='C'");
+                        wc += QStringLiteral("t_type='C'");
                     }
                     if ((m_menuCreditCard != nullptr) && m_menuCreditCard->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QLatin1String(" OR ");
+                            wc += QStringLiteral(" OR ");
                         }
-                        wc += QLatin1String("t_type='D'");
+                        wc += QStringLiteral("t_type='D'");
                     }
                     if ((m_menuSaving != nullptr) && m_menuSaving->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QLatin1String(" OR ");
+                            wc += QStringLiteral(" OR ");
                         }
-                        wc += QLatin1String("t_type='S'");
+                        wc += QStringLiteral("t_type='S'");
                     }
                     if ((m_menuInvestment != nullptr) && m_menuInvestment->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QLatin1String(" OR ");
+                            wc += QStringLiteral(" OR ");
                         }
-                        wc += QLatin1String("t_type='I'");
+                        wc += QStringLiteral("t_type='I'");
                     }
                     if ((m_menuWallet != nullptr) && m_menuWallet->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QLatin1String(" OR ");
+                            wc += QStringLiteral(" OR ");
                         }
-                        wc += QLatin1String("t_type='W'");
+                        wc += QStringLiteral("t_type='W'");
                     }
                     if ((m_menuOther != nullptr) && m_menuOther->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QLatin1String(" OR ");
+                            wc += QStringLiteral(" OR ");
                         }
-                        wc += QLatin1String("t_type='O'");
+                        wc += QStringLiteral("t_type='O'");
                     }
                     if ((m_menuLoan != nullptr) && m_menuLoan->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QLatin1String(" OR ");
+                            wc += QStringLiteral(" OR ");
                         }
-                        wc += QLatin1String("t_type='L'");
+                        wc += QStringLiteral("t_type='L'");
                     }
                     if ((m_menuPension != nullptr) && m_menuPension->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QLatin1String(" OR ");
+                            wc += QStringLiteral(" OR ");
                         }
-                        wc += QLatin1String("t_type='P'");
+                        wc += QStringLiteral("t_type='P'");
                     }
 
                     if (wc.isEmpty()) {
-                        wc = QLatin1String("1=0");
+                        wc = QStringLiteral("1=0");
                     } else if ((m_menuFavorite != nullptr) && m_menuFavorite->isChecked()) {
-                        wc = "t_bookmarked='Y' AND (" % wc % QLatin1Char(')');
+                        wc = "t_bookmarked='Y' AND (" % wc % u')';
                     }
 
                     // Build display
                     SKGStringListList listTmp;
                     err = doc->executeSelectSqliteOrder(
-                              QLatin1String("SELECT t_name, t_TYPENLS, t_UNIT, ") % ((m_menuPastOperations != nullptr) && m_menuPastOperations->isChecked() ? "f_TODAYAMOUNT" : "f_CURRENTAMOUNT") % ", t_close  from v_account_display WHERE (" % wc % ") ORDER BY t_TYPENLS, t_name",
-                              listTmp);
-                    IFOK(err) {
+                        QStringLiteral("SELECT t_name, t_TYPENLS, t_UNIT, ")
+                            % ((m_menuPastOperations != nullptr) && m_menuPastOperations->isChecked() ? "f_TODAYAMOUNT" : "f_CURRENTAMOUNT")
+                            % ", t_close  from v_account_display WHERE (" % wc % ") ORDER BY t_TYPENLS, t_name",
+                        listTmp);
+                    IFOK(err)
+                    {
                         KColorScheme scheme(QPalette::Normal, KColorScheme::Window);
                         auto color = scheme.foreground(KColorScheme::NormalText).color().name().right(6);
 
-                        html += QLatin1String("<html><head><style>a {color: #") + color + ";}</style></head><body><table>";
+                        html += QStringLiteral("<html><head><style>a {color: #") + color + ";}</style></head><body><table>";
                         double sumTypeV1 = 0;
                         double sumV1 = 0;
                         int nbAdded = 0;
                         QString currentType;
                         int nb = listTmp.count();
-                        for (int i = 1; i < nb; ++i) {  // Ignore header
-                            const QStringList& r = listTmp.at(i);
-                            const QString& name = r.at(0);
-                            const QString& type = r.at(1);
-                            const QString& unitAccountSymbol = r.at(2);
+                        for (int i = 1; i < nb; ++i) { // Ignore header
+                            const QStringList &r = listTmp.at(i);
+                            const QString &name = r.at(0);
+                            const QString &type = r.at(1);
+                            const QString &unitAccountSymbol = r.at(2);
                             double v1 = SKGServices::stringToDouble(r.at(3));
-                            bool closed = (r.at(4) == QLatin1String("Y"));
+                            bool closed = (r.at(4) == QStringLiteral("Y"));
 
                             if (type != currentType) {
                                 if (!currentType.isEmpty() && nbAdded > 0) {
@@ -349,7 +363,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                                     unitAccount.setSymbol(unitAccountSymbol);
                                     unitAccount.load();
 
-                                    double unitAccountValue = SKGServices::stringToDouble(unitAccount.getAttribute(QLatin1String("f_CURRENTAMOUNT")));
+                                    double unitAccountValue = SKGServices::stringToDouble(unitAccount.getAttribute(QStringLiteral("f_CURRENTAMOUNT")));
                                     SKGServices::SKGUnitInfo u2 = primary;
                                     u2.Symbol = unitAccountSymbol;
                                     u2.NbDecimal = unitAccount.getNumberDecimal();
@@ -357,7 +371,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                                     html += '=';
                                 }
                                 html += doc->formatMoney(v1, primary);
-                                html += QLatin1String("</td></tr>");
+                                html += QStringLiteral("</td></tr>");
                                 ++nbAdded;
                             }
                             sumTypeV1 += v1;
@@ -372,7 +386,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                         html += "<tr><td><b>" % SKGServices::stringToHtml(i18nc("Noun, the numerical total of a sum of values", "Total")) % "</b></td>"
                                 "<td align=\"right\"><b>" % doc->formatMoney(sumV1, primary) % "</b></td>"
                                 "</tr>";
-                        html += QLatin1String("</table></body></html>");
+                        html += QStringLiteral("</table></body></html>");
                     }
                 }
                 m_label->setText(html);
