@@ -11,9 +11,7 @@
 #include "skgbudgetdelegate.h"
 
 #include <kcolorscheme.h>
-#ifdef SKG_QT6
 #include <kstatefulbrush.h>
-#endif
 
 #include <qpainter.h>
 #include <qsortfilterproxymodel.h>
