@@ -40,17 +40,17 @@ SKGCalculatorPlugin::~SKGCalculatorPlugin()
     m_currentBankDocument = nullptr;
 }
 
-bool SKGCalculatorPlugin::setupActions(SKGDocument* iDocument)
+bool SKGCalculatorPlugin::setupActions(SKGDocument *iDocument)
 {
     SKGTRACEINFUNC(10)
 
-    m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
+    m_currentBankDocument = qobject_cast<SKGDocumentBank *>(iDocument);
     if (m_currentBankDocument == nullptr) {
         return false;
     }
 
-    setComponentName(QLatin1String("skrooge_calculator"), title());
-    setXMLFile(QLatin1String("skrooge_calculator.rc"));
+    setComponentName(QStringLiteral("skrooge_calculator"), title());
+    setXMLFile(QStringLiteral("skrooge_calculator.rc"));
 
     // Create yours actions here
     return true;
@@ -67,29 +67,23 @@ QString SKGCalculatorPlugin::getDashboardWidgetTitle(int iIndex)
     return i18nc("The estimated amount of money earned through interests on a remunerated account", "Estimated interest");
 }
 
-SKGBoardWidget* SKGCalculatorPlugin::getDashboardWidget(int iIndex)
+SKGBoardWidget *SKGCalculatorPlugin::getDashboardWidget(int iIndex)
 {
     Q_UNUSED(iIndex)
-    auto listForFilter = QStringList()
-                         << QLatin1String("t_name")
-                         << QLatin1String("t_number")
-                         << QLatin1String("t_agency_number")
-                         << QLatin1String("t_agency_address")
-                         << QLatin1String("t_comment")
-                         << QLatin1String("t_bookmarked")
-                         << QLatin1String("t_TYPENLS")
-                         << QLatin1String("t_BANK")
-                         << QLatin1String("t_BANK_NUMBER");
+    auto listForFilter = std::move(QStringList() << QStringLiteral("t_name") << QStringLiteral("t_number") << QStringLiteral("t_agency_number")
+                                                 << QStringLiteral("t_agency_address") << QStringLiteral("t_comment") << QStringLiteral("t_bookmarked")
+                                                 << QStringLiteral("t_TYPENLS") << QStringLiteral("t_BANK") << QStringLiteral("t_BANK_NUMBER"));
 
-    return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
+    return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(),
+                                  m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
-                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/interests.qml")),
-                                  QStringList() << QLatin1String("v_account_display") << QLatin1String("interest"),
+                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/interests.qml")),
+                                  QStringList() << QStringLiteral("v_account_display") << QStringLiteral("interest"),
                                   SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_YEARS,
                                   listForFilter);
 }
 
-SKGTabPage* SKGCalculatorPlugin::getWidget()
+SKGTabPage *SKGCalculatorPlugin::getWidget()
 {
     SKGTRACEINFUNC(10)
     return new SKGCalculatorPluginWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
@@ -102,7 +96,7 @@ QString SKGCalculatorPlugin::title() const
 
 QString SKGCalculatorPlugin::icon() const
 {
-    return QLatin1String("accessories-calculator");
+    return QStringLiteral("dialog-scripts");
 }
 
 QString SKGCalculatorPlugin::toolTip() const
@@ -126,15 +120,18 @@ bool SKGCalculatorPlugin::isInPagesChooser() const
 {
     return true;
 }
-SKGAdviceList SKGCalculatorPlugin::advice(const QStringList& iIgnoredAdvice)
+SKGAdviceList SKGCalculatorPlugin::advice(const QStringList &iIgnoredAdvice)
 {
     SKGTRACEINFUNC(10)
     SKGAdviceList output;
 
     // Search investment accounts without interest rate
-    if (!iIgnoredAdvice.contains(QLatin1String("skgcalculatorplugin_nointerest"))) {
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgcalculatorplugin_nointerest"))) {
         SKGObjectBase::SKGListSKGObjectBase accounts;
-        m_currentBankDocument->getObjects(QLatin1String("account"), QLatin1String("t_type='I' AND t_close='N' AND NOT EXISTS (SELECT 1 FROM interest WHERE interest.rd_account_id=account.id)"), accounts);
+        m_currentBankDocument->getObjects(
+            QStringLiteral("account"),
+            QStringLiteral("t_type='I' AND t_close='N' AND NOT EXISTS (SELECT 1 FROM interest WHERE interest.rd_account_id=account.id)"),
+            accounts);
         int nb = accounts.count();
         SKGAdvice::SKGAdviceActionList autoCorrections;
         for (int i = 0; i < nb; ++i) {
@@ -142,13 +139,16 @@ SKGAdviceList SKGCalculatorPlugin::advice(const QStringList& iIgnoredAdvice)
             SKGAdvice ad;
             ad.setUUID("skgcalculatorplugin_nointerest|" % account.getName());
             ad.setPriority(3);
-            ad.setShortMessage(i18nc("User did not define an interest rate on an investment account", "No interest rate defined for account '%1'", account.getName()));
-            ad.setLongMessage(i18nc("User did not define an interest rate on an investment account", "Your investment account '%1' doesn't have interest rate defined", account.getName()));
+            ad.setShortMessage(
+                i18nc("User did not define an interest rate on an investment account", "No interest rate defined for account '%1'", account.getName()));
+            ad.setLongMessage(i18nc("User did not define an interest rate on an investment account",
+                                    "Your investment account '%1' doesn't have interest rate defined",
+                                    account.getName()));
             autoCorrections.resize(0);
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Link allowing user to open a new tab for defining interests parameters", "Open interest page");
-                a.IconName = QLatin1String("quickopen");
+                a.IconName = QStringLiteral("quickopen");
                 a.IsRecommended = false;
                 autoCorrections.push_back(a);
             }
@@ -159,9 +159,9 @@ SKGAdviceList SKGCalculatorPlugin::advice(const QStringList& iIgnoredAdvice)
     return output;
 }
 
-SKGError SKGCalculatorPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
+SKGError SKGCalculatorPlugin::executeAdviceCorrection(const QString &iAdviceIdentifier, int iSolution)
 {
-    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgcalculatorplugin_nointerest|"))) {
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QStringLiteral("skgcalculatorplugin_nointerest|"))) {
         // Get parameters
         QString account = iAdviceIdentifier.right(iAdviceIdentifier.length() - 31);
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_calculator_plugin/?currentPage=0&account=" % SKGServices::encodeForUrl(account));
