@@ -27,7 +27,7 @@
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
 
-SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(QWidget* iParent, SKGDocumentBank* iDocument)
+SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(QWidget *iParent, SKGDocumentBank *iDocument)
     : SKGTabPage(iParent, iDocument)
 {
     SKGTRACEINFUNC(10)
@@ -39,41 +39,77 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(QWidget* iParent, SKGDocume
 
     // Define action
     QStringList overlaycategories;
-    overlaycategories.push_back(QLatin1String("view-categories"));
+    overlaycategories.push_back(QStringLiteral("applications-all-symbolic"));
     if (SKGMainPanel::getMainPanel() != nullptr) {
-        auto addCategoryAction = new QAction(SKGServices::fromTheme(QLatin1String("list-add"), overlaycategories), i18nc("Verb", "Add category"), this);
+        auto addCategoryAction = new QAction(SKGServices::fromTheme(QStringLiteral("list-add"), overlaycategories), i18nc("Verb", "Add category"), this);
         connect(addCategoryAction, &QAction::triggered, this, &SKGCategoriesPluginWidget::onAddCategory);
-        SKGMainPanel::getMainPanel()->registerGlobalAction(QLatin1String("edit_add_category"), addCategoryAction, true, QStringList() << QLatin1String("category"), 1, -1, 450);
+        SKGMainPanel::getMainPanel()
+            ->registerGlobalAction(QStringLiteral("edit_add_category"), addCategoryAction, true, QStringList() << QStringLiteral("category"), 1, -1, 450);
     }
 
     // Set show widget
-    ui.kCategoriesView->getShowWidget()->addGroupedItem(QLatin1String("all"), i18n("All"), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META | Qt::Key_A);
-    ui.kCategoriesView->getShowWidget()->addGroupedItem(QLatin1String("opened"), i18n("Opened"), QLatin1String("vcs-normal"), QLatin1String("t_HASOPENEDCHILD='Y'"), QLatin1String(""), Qt::META | Qt::Key_O);
-    ui.kCategoriesView->getShowWidget()->addGroupedItem(QLatin1String("closed"), i18n("Closed"), QLatin1String("vcs-conflicting"), QLatin1String("t_HASCLOSEDCHILD='Y'"), QLatin1String(""), Qt::META | Qt::Key_C);
-    ui.kCategoriesView->getShowWidget()->addGroupedItem(QLatin1String("income"), i18n("Income"), QLatin1String("list-add"), QLatin1String("f_REALCURRENTAMOUNT>=0"), QLatin1String(""), Qt::META | Qt::Key_Plus);
-    ui.kCategoriesView->getShowWidget()->addGroupedItem(QLatin1String("expenditure"), i18n("Expenditure"), QLatin1String("list-remove"), QLatin1String("f_REALCURRENTAMOUNT<=0"), QLatin1String(""), Qt::META | Qt::Key_Minus);
-    ui.kCategoriesView->getShowWidget()->addGroupedItem(QLatin1String("highlighted"), i18n("Highlighted"), QLatin1String("bookmarks"), QLatin1String("t_HASBOOKMARKEDCHILD<>'N'"), QLatin1String(""), Qt::META | Qt::Key_H);
-    ui.kCategoriesView->getShowWidget()->setDefaultState(QLatin1String("all"));
+    ui.kCategoriesView->getShowWidget()->addGroupedItem(QStringLiteral("all"), i18n("All"), QString(), QString(), QString(), Qt::META | Qt::Key_A);
+    ui.kCategoriesView->getShowWidget()->addGroupedItem(QStringLiteral("opened"),
+                                                        i18n("Opened"),
+                                                        QStringLiteral("vcs-normal"),
+                                                        QStringLiteral("t_HASOPENEDCHILD='Y'"),
+                                                        QString(),
+                                                        Qt::META | Qt::Key_O);
+    ui.kCategoriesView->getShowWidget()->addGroupedItem(QStringLiteral("closed"),
+                                                        i18n("Closed"),
+                                                        QStringLiteral("vcs-conflicting"),
+                                                        QStringLiteral("t_HASCLOSEDCHILD='Y'"),
+                                                        QString(),
+                                                        Qt::META | Qt::Key_C);
+    ui.kCategoriesView->getShowWidget()->addGroupedItem(QStringLiteral("income"),
+                                                        i18n("Income"),
+                                                        QStringLiteral("list-add"),
+                                                        QStringLiteral("f_REALCURRENTAMOUNT>=0"),
+                                                        QString(),
+                                                        Qt::META | Qt::Key_Plus);
+    ui.kCategoriesView->getShowWidget()->addGroupedItem(QStringLiteral("expenditure"),
+                                                        i18n("Expenditure"),
+                                                        QStringLiteral("list-remove"),
+                                                        QStringLiteral("f_REALCURRENTAMOUNT<=0"),
+                                                        QString(),
+                                                        Qt::META | Qt::Key_Minus);
+    ui.kCategoriesView->getShowWidget()->addGroupedItem(QStringLiteral("highlighted"),
+                                                        i18n("Highlighted"),
+                                                        QStringLiteral("bookmarks"),
+                                                        QStringLiteral("t_HASBOOKMARKEDCHILD<>'N'"),
+                                                        QString(),
+                                                        Qt::META | Qt::Key_H);
+    ui.kCategoriesView->getShowWidget()->setDefaultState(QStringLiteral("all"));
 
-    ui.kAdd->setIcon(SKGServices::fromTheme(QLatin1String("list-add"), overlaycategories));
+    ui.kAdd->setIcon(SKGServices::fromTheme(QStringLiteral("list-add"), overlaycategories));
     ui.kAdd->setToolTip(i18nc("An help", "Add a sub category to the selected one"));
     ui.kAdd->setMaximumWidth(ui.kAdd->height());
 
-    ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_name"))));
+    ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_name"))));
 
-    ui.kModifyCategoryButton->setIcon(SKGServices::fromTheme(QLatin1String("dialog-ok")));
-    ui.kDeleteUnusedButton->setIcon(SKGServices::fromTheme(QLatin1String("edit-delete")));
+    ui.kModifyCategoryButton->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
+    ui.kDeleteUnusedButton->setIcon(SKGServices::fromTheme(QStringLiteral("edit-delete")));
 
-    ui.kCategoriesView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QLatin1String("v_category_display"), QLatin1String("1=0"), this, QLatin1String("rd_category_id"), false));
+    ui.kCategoriesView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank *>(getDocument()),
+                                                    QStringLiteral("v_category_display"),
+                                                    QStringLiteral("1=0"),
+                                                    this,
+                                                    QStringLiteral("rd_category_id"),
+                                                    false));
     ui.kCategoriesView->getView()->setRootIsDecorated(true);
-    ui.kCategoriesView->getView()->setAnimated(false);  // Not compatible with double click
+    ui.kCategoriesView->getView()->setAnimated(false); // Not compatible with double click
     ui.kCategoriesView->getView()->resizeColumnToContents(0);
     ui.kCategoriesView->getView()->header()->setStretchLastSection(false);
 
     connect(getDocument(), &SKGDocument::tableModified, this, &SKGCategoriesPluginWidget::dataModified, Qt::QueuedConnection);
     connect(ui.kCategoriesView->getView(), &SKGTreeView::clickEmptyArea, this, &SKGCategoriesPluginWidget::cleanEditor);
-    connect(ui.kCategoriesView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("open")).data(), &QAction::trigger);
-    connect(ui.kCategoriesView->getView(), &SKGTreeView::selectionChangedDelayed, this, [ = ] {this->onSelectionChanged();});
+    connect(ui.kCategoriesView->getView(),
+            &SKGTreeView::doubleClicked,
+            SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("open")).data(),
+            &QAction::trigger);
+    connect(ui.kCategoriesView->getView(), &SKGTreeView::selectionChangedDelayed, this, [this] {
+        this->onSelectionChanged();
+    });
 
     connect(ui.kModifyCategoryButton, &QPushButton::clicked, this, &SKGCategoriesPluginWidget::onUpdateCategory);
     connect(ui.kNameInput1, &QLineEdit::textChanged, this, &SKGCategoriesPluginWidget::onEditorModified);
@@ -84,7 +120,7 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(QWidget* iParent, SKGDocume
     // Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter(this);
 
-    dataModified(QLatin1String(""), 0);
+    dataModified(QString(), 0);
 }
 
 SKGCategoriesPluginWidget::~SKGCategoriesPluginWidget()
@@ -92,14 +128,14 @@ SKGCategoriesPluginWidget::~SKGCategoriesPluginWidget()
     SKGTRACEINFUNC(10)
 }
 
-bool SKGCategoriesPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
+bool SKGCategoriesPluginWidget::eventFilter(QObject *iObject, QEvent *iEvent)
 {
     if ((iEvent != nullptr) && iEvent->type() == QEvent::KeyPress) {
-        auto* keyEvent = dynamic_cast<QKeyEvent*>(iEvent);
+        auto *keyEvent = dynamic_cast<QKeyEvent *>(iEvent);
         if (keyEvent && (keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
             if ((QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u && ui.kAdd->isEnabled()) {
                 ui.kAdd->click();
-            } else if ((QApplication::keyboardModifiers() &Qt::ShiftModifier) != 0u && ui.kModifyCategoryButton->isEnabled()) {
+            } else if ((QApplication::keyboardModifiers() & Qt::ShiftModifier) != 0u && ui.kModifyCategoryButton->isEnabled()) {
                 ui.kModifyCategoryButton->click();
             }
         }
@@ -108,15 +144,20 @@ bool SKGCategoriesPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
     return SKGTabPage::eventFilter(iObject, iEvent);
 }
 
-void SKGCategoriesPluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
+void SKGCategoriesPluginWidget::dataModified(const QString &iTableName, int iIdTransaction, bool iLightTransaction)
 {
     SKGTRACEINFUNC(10)
     Q_UNUSED(iIdTransaction)
 
     if (!iLightTransaction) {
-        if (iTableName == QLatin1String("category") || iTableName.isEmpty()) {
+        if (iTableName == QStringLiteral("category") || iTableName.isEmpty()) {
             // Set completions
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kNameInput1, getDocument(), QLatin1String("category"), QLatin1String("t_name"), QLatin1String(""), true);
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget *>() << ui.kNameInput1,
+                                                getDocument(),
+                                                QStringLiteral("category"),
+                                                QStringLiteral("t_name"),
+                                                QString(),
+                                                true);
 
             onSelectionChanged();
         }
@@ -129,7 +170,7 @@ void SKGCategoriesPluginWidget::onSelectionChanged()
     // Clean widgets
     int nb = ui.kLayout->count();
     for (int i = 0; i < nb; ++i) {
-        QLayoutItem* item = ui.kLayout->itemAt(0);
+        QLayoutItem *item = ui.kLayout->itemAt(0);
         if (item != nullptr) {
             ui.kLayout->removeItem(item);
             delete item->widget();
@@ -137,7 +178,7 @@ void SKGCategoriesPluginWidget::onSelectionChanged()
         }
     }
 
-    ui.kNameInput2->setText(QLatin1String(""));
+    ui.kNameInput2->setText(QString());
 
     int nbSelect = getNbSelectedObjects();
     if (nbSelect == 1) {
@@ -148,7 +189,7 @@ void SKGCategoriesPluginWidget::onSelectionChanged()
         obj.getParentCategory(parentCat);
         QString parentName = parentCat.getFullName();
 
-        QStringList items = SKGServices::splitCSVLine(parentName, QString(OBJECTSEPARATOR).trimmed().at(0));
+        QStringList items = SKGServices::splitCSVLine(parentName, OBJECTSEPARATOR.trimmed().at(0));
         int nbItems = items.count();
         QString fullname;
         for (int i = 0; i < nbItems; ++i) {
@@ -179,7 +220,7 @@ void SKGCategoriesPluginWidget::changeSelection()
 {
     QString fullname = sender()->property("FULLNAME").toString();
     SKGObjectBase::SKGListSKGObjectBase list;
-    getDocument()->getObjects(QLatin1String("v_category"), "t_fullname='" % SKGServices::stringToSqlString(fullname) % QLatin1Char('\''), list);
+    getDocument()->getObjects(QStringLiteral("v_category"), "t_fullname='" % SKGServices::stringToSqlString(fullname) % u'\'', list);
 
     if (!list.isEmpty()) {
         ui.kCategoriesView->getView()->selectObject(list.at(0).getUniqueID());
@@ -190,32 +231,34 @@ void SKGCategoriesPluginWidget::changeSelection()
 QString SKGCategoriesPluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QLatin1String("SKGML"));
-    QDomElement root = doc.createElement(QLatin1String("parameters"));
+    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomElement root = doc.createElement(QStringLiteral("parameters"));
     doc.appendChild(root);
 
     // Memorize table settings
-    root.setAttribute(QLatin1String("view"), ui.kCategoriesView->getState());
+    root.setAttribute(QStringLiteral("view"), ui.kCategoriesView->getState());
     return doc.toString();
 }
 
-void SKGCategoriesPluginWidget::setState(const QString& iState)
+void SKGCategoriesPluginWidget::setState(const QString &iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    ui.kCategoriesView->setFilter(SKGServices::fromTheme(root.attribute(QLatin1String("title_icon"))), root.attribute(QLatin1String("title")), root.attribute(QLatin1String("whereClause")));
-    ui.kCategoriesView->setState(root.attribute(QLatin1String("view")));
+    ui.kCategoriesView->setFilter(SKGServices::fromTheme(root.attribute(QStringLiteral("title_icon"))),
+                                  root.attribute(QStringLiteral("title")),
+                                  root.attribute(QStringLiteral("whereClause")));
+    ui.kCategoriesView->setState(root.attribute(QStringLiteral("view")));
 }
 
 QString SKGCategoriesPluginWidget::getDefaultStateAttribute()
 {
-    return QLatin1String("SKGCATEGORIES_DEFAULT_PARAMETERS");
+    return QStringLiteral("SKGCATEGORIES_DEFAULT_PARAMETERS");
 }
 
-QWidget* SKGCategoriesPluginWidget::mainWidget()
+QWidget *SKGCategoriesPluginWidget::mainWidget()
 {
     return ui.kCategoriesView->getView();
 }
@@ -250,17 +293,21 @@ void SKGCategoriesPluginWidget::onAddCategory()
             SKGCategoryObject parentCat(selection[0]);
             name = parentCat.getFullName() % OBJECTSEPARATOR % name;
         }
-        IFOKDO(err, SKGCategoryObject::createPathCategory(qobject_cast<SKGDocumentBank*>(getDocument()), name, cat, false, true))
+        IFOKDO(err, SKGCategoryObject::createPathCategory(qobject_cast<SKGDocumentBank *>(getDocument()), name, cat, false, true))
 
         // Send message
-        IFOKDO(err, cat.getDocument()->sendMessage(i18nc("An information message", "The category '%1' has been created", cat.getDisplayName()), SKGDocument::Hidden))
+        IFOKDO(err,
+               cat.getDocument()->sendMessage(i18nc("An information message", "The category '%1' has been created", cat.getDisplayName()), SKGDocument::Hidden))
     }
 
     // status bar
-    IFOK(err) {
+    IFOK(err)
+    {
         ui.kCategoriesView->getView()->selectObject(cat.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Category '%1' created", name));
-    } else {
+    }
+    else
+    {
         err.addError(ERR_FAIL, i18nc("Error message", "Category creation failed"));
     }
 
@@ -279,7 +326,7 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
     {
         QString name = ui.kNameInput1->text();
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Category update"), err, nb)
-        if (nb > 1 && name != NOUPDATE && !name.startsWith(QLatin1String("="))) {
+        if (nb > 1 && name != NOUPDATE && !name.startsWith(QStringLiteral("="))) {
             getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected categories. Categories have been merged."));
 
             // Do the merge
@@ -288,7 +335,12 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
                 SKGCategoryObject catObj(selection.at(i));
 
                 // Send message
-                IFOKDO(err, catObj.getDocument()->sendMessage(i18nc("An information message", "The category '%1' has been merged with category '%2'", catObj1.getDisplayName(), catObj.getDisplayName()), SKGDocument::Hidden))
+                IFOKDO(err,
+                       catObj.getDocument()->sendMessage(i18nc("An information message",
+                                                               "The category '%1' has been merged with category '%2'",
+                                                               catObj1.getDisplayName(),
+                                                               catObj.getDisplayName()),
+                                                         SKGDocument::Hidden))
 
                 IFOKDO(err, catObj1.merge(catObj))
 
@@ -308,12 +360,15 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
             IFOKDO(err, cat.save())
 
             // Send message
-            IFOKDO(err, cat.getDocument()->sendMessage(i18nc("An information message", "The category '%1' has been updated", cat.getDisplayName()), SKGDocument::Hidden))
+            IFOKDO(err,
+                   cat.getDocument()->sendMessage(i18nc("An information message", "The category '%1' has been updated", cat.getDisplayName()),
+                                                  SKGDocument::Hidden))
         }
     }
     // status bar
     IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Category updated")))
-    else {
+    else
+    {
         err.addError(ERR_FAIL, i18nc("Error message", "Category update failed"));
     }
 
@@ -326,7 +381,7 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
 
 void SKGCategoriesPluginWidget::onDeleteUnused()
 {
-    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("clean_delete_unused_categories"));
+    QAction *act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("clean_delete_unused_categories"));
     if (act != nullptr) {
         act->trigger();
     }
@@ -335,8 +390,8 @@ void SKGCategoriesPluginWidget::onDeleteUnused()
 void SKGCategoriesPluginWidget::cleanEditor()
 {
     if (getNbSelectedObjects() == 0) {
-        ui.kNameInput1->setText(QLatin1String(""));
-        ui.kNameInput2->setText(QLatin1String(""));
+        ui.kNameInput1->setText(QString());
+        ui.kNameInput2->setText(QString());
     }
 }
 void SKGCategoriesPluginWidget::activateEditor()
@@ -348,5 +403,3 @@ bool SKGCategoriesPluginWidget::isEditor()
 {
     return true;
 }
-
-
