@@ -83,7 +83,7 @@ bool SKGReportPlugin::setupActions(SKGDocument *iDocument)
         auto act = new QAction(SKGServices::fromTheme(QStringLiteral("security-low"), overlayopen), i18nc("Verb", "Open very old transactions…"), this);
         act->setData(QString("skg://skrooge_operation_plugin/?title_icon=security-low&title="
                              % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Very old transactions")) % "&operationWhereClause="
-                             % SKGServices::encodeForUrl(QStringLiteral("d_date<=(SELECT date('now', 'localtime', '-50 year')) AND d_date<>'0000-00-00'"))));
+                             % SKGServices::encodeForUrl(QStringLiteral("d_date<=(date('now', 'localtime', '-50 year')) AND d_date<>'0000-00-00'"))));
         connect(act, &QAction::triggered, SKGMainPanel::getMainPanel(), []() {
             SKGMainPanel::getMainPanel()->openPage();
         });
@@ -96,7 +96,7 @@ bool SKGReportPlugin::setupActions(SKGDocument *iDocument)
             new QAction(SKGServices::fromTheme(QStringLiteral("security-low"), overlayopen), i18nc("Verb", "Open very far transactions in the future…"), this);
         act->setData(QString("skg://skrooge_operation_plugin/?title_icon=security-low&title="
                              % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Very far transactions in the future")) % "&operationWhereClause="
-                             % SKGServices::encodeForUrl(QStringLiteral("d_date>=(SELECT date('now', 'localtime', '+50 year'))"))));
+                             % SKGServices::encodeForUrl(QStringLiteral("d_date>=(date('now', 'localtime', '+50 year'))"))));
         connect(act, &QAction::triggered, SKGMainPanel::getMainPanel(), []() {
             SKGMainPanel::getMainPanel()->openPage();
         });
@@ -366,7 +366,7 @@ SKGAdviceList SKGReportPlugin::advice(const QStringList &iIgnoredAdvice)
     if (!iIgnoredAdvice.contains(QStringLiteral("skgreportplugin_veryold"))) {
         bool exist = false;
         m_currentBankDocument->existObjects(QStringLiteral("operation"),
-                                            QStringLiteral("d_date<=(SELECT date('now', 'localtime', '-50 year')) AND d_date<>'0000-00-00'"),
+                                            QStringLiteral("d_date<=(date('now', 'localtime', '-50 year')) AND d_date<>'0000-00-00'"),
                                             exist);
         if (exist) {
             SKGAdvice ad;
@@ -386,7 +386,7 @@ SKGAdviceList SKGReportPlugin::advice(const QStringList &iIgnoredAdvice)
     // Very far operation
     if (!iIgnoredAdvice.contains(QStringLiteral("skgreportplugin_veryfar"))) {
         bool exist = false;
-        m_currentBankDocument->existObjects(QStringLiteral("operation"), QStringLiteral("d_date>=(SELECT date('now', 'localtime', '+50 year'))"), exist);
+        m_currentBankDocument->existObjects(QStringLiteral("operation"), QStringLiteral("d_date>=(date('now', 'localtime', '+50 year'))"), exist);
         if (exist) {
             SKGAdvice ad;
             ad.setUUID(QStringLiteral("skgreportplugin_veryfar"));
