@@ -269,11 +269,11 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget *iParent, SKGDocumentBank *
             this,
             &SKGReportPluginWidget::refresh,
             Qt::QueuedConnection);
-    connect(ui.kIncomes, &QCheckBox::stateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
-    connect(ui.kExpenses, &QCheckBox::stateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
-    connect(ui.kTransfers, &QCheckBox::stateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
-    connect(ui.kGrouped, &QCheckBox::stateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
-    connect(ui.kTracked, &QCheckBox::stateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
+    connect(ui.kIncomes, &QCheckBox::checkStateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
+    connect(ui.kExpenses, &QCheckBox::checkStateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
+    connect(ui.kTransfers, &QCheckBox::checkStateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
+    connect(ui.kGrouped, &QCheckBox::checkStateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
+    connect(ui.kTracked, &QCheckBox::checkStateChanged, this, &SKGReportPluginWidget::refresh, Qt::QueuedConnection);
     connect(ui.kForecastCmb,
             static_cast<void (SKGComboBox::*)(const QString &)>(&SKGComboBox::currentTextChanged),
             this,
@@ -1196,7 +1196,7 @@ void SKGReportPluginWidget::dataModified(const QString &iTableName, int iIdTrans
 
                 // Limit size of the result
                 condition = u'(' % condition
-                    % ") AND (d_date>(SELECT date('now', 'localtime', '-50 year')) OR d_date='0000') AND d_date<(SELECT date('now', 'localtime', '+50 year'))";
+                    % ") AND (d_date>(date('now', 'localtime', '-50 year')) OR d_date='0000') AND d_date<(date('now', 'localtime', '+50 year'))";
 
                 QString coef;
                 if (ui.kCorrectedBy->currentIndex() > 0 && mode != 3) {
