@@ -84,11 +84,6 @@ bool SKGScheduledPlugin::setupActions(SKGDocument *iDocument)
         new KToolBarPopupAction(SKGServices::fromTheme(QStringLiteral("edit-guides")), i18nc("Verb, action to assign a schedule", "Assign schedule"), this);
     m_assignScheduleMenu = actAssignScheduleAction->popupMenu();
     connect(m_assignScheduleMenu, &QMenu::aboutToShow, this, &SKGScheduledPlugin::onShowAssignScheduleMenu);
-#ifdef SKG_QT6
-
-#else
-    actAssignScheduleAction->setStickyMenu(false);
-#endif
     actAssignScheduleAction->setData(1);
     registerGlobalAction(QStringLiteral("edit_assign_schedule"), actAssignScheduleAction, listOperation, 1, -1, 412);
 
@@ -117,7 +112,7 @@ void SKGScheduledPlugin::onShowAssignScheduleMenu()
                 SKGOperationObject operationObj(selection.at(i));
                 if (operationObj.isTemplate()) {
                     QAction *act = m->addAction(
-                        i18nc("A message that is shown in assign schedule menu for a tempate operation", "Cannot assign a schedule to a template"));
+                        i18nc("A message that is shown in assign schedule menu for a template operation", "Cannot assign a schedule to a template"));
                     if (act != nullptr) {
                         act->setEnabled(false);
                     }
@@ -592,7 +587,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList &iIgnoredAdvice)
                            "op1.id||'#'||op2.f_QUANTITY FROM operation op1, v_operation_tmp1 op2 "
                            "WHERE op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.rc_unit_id=op2.rc_unit_id "
                            "AND op1.r_recurrentoperation_id=0 AND op1.d_date<>'0000-00-00' AND op1.d_date=date(op2.d_date, '+1 month') "
-                           "AND op1.d_date>(SELECT date('now', 'localtime','-2 month')) AND op2.d_date>(SELECT date('now', 'localtime','-3 month'))) "
+                           "AND op1.d_date>(date('now', 'localtime','-2 month')) AND op2.d_date>(date('now', 'localtime','-3 month'))) "
                            "AND op1.t_TRANSFER='N' "
                            "AND NOT EXISTS (SELECT 1 FROM recurrentoperation ro, v_operation_tmp1 rop  WHERE ro.rd_operation_id=rop.id AND "
                            "ro.i_period_increment=1 AND ro.t_period_unit='M' AND op1.rd_account_id=rop.rd_account_id AND op1.r_payee_id=rop.r_payee_id AND "
