@@ -34,6 +34,26 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(QWidget *iParent, SKGDocument
 
     ui.setupUi(this);
 
+    // Add options to adapter
+    ui.kAdapter->addItem(i18n("None"), static_cast<int>(SKGRecurrentOperationObject::NONE));
+    ui.kAdapter->addItem(i18n("First open day of the month"), static_cast<int>(SKGRecurrentOperationObject::FIRST_OPEN_DAY_OF_MONTH));
+    ui.kAdapter->addItem(i18n("Previous open day"), static_cast<int>(SKGRecurrentOperationObject::PREVIOUS_OPEN_DAY));
+    ui.kAdapter->addItem(i18n("Closest open day"), static_cast<int>(SKGRecurrentOperationObject::CLOSEST_OPEN_DAY));
+    ui.kAdapter->addItem(i18n("Next open day"), static_cast<int>(SKGRecurrentOperationObject::NEXT_OPEN_DAY));
+    for (int day = Qt::Monday; day <= Qt::Sunday; ++day) {
+        ui.kAdapter->addItem(i18nc("The parameter is a day of the week (monday to sunday)", "Previous %1", QLocale().dayName(day)),
+                             SKGRecurrentOperationObject::PREVIOUS_MONDAY + (day - 1));
+    }
+    for (int day = Qt::Monday; day <= Qt::Sunday; ++day) {
+        ui.kAdapter->addItem(i18nc("The parameter is a day of the week (monday to sunday)", "Closest %1", QLocale().dayName(day)),
+                             SKGRecurrentOperationObject::CLOSEST_MONDAY + (day - 1));
+    }
+    for (int day = Qt::Monday; day <= Qt::Sunday; ++day) {
+        ui.kAdapter->addItem(i18nc("The parameter is a day of the week (monday to sunday)", "Next %1", QLocale().dayName(day)),
+                             SKGRecurrentOperationObject::NEXT_MONDAY + (day - 1));
+    }
+    ui.kAdapter->setCurrentIndex(0);
+
     // Define action
     if (SKGMainPanel::getMainPanel() != nullptr) {
         auto actJumpToOperation = new QAction(SKGServices::fromTheme(QStringLiteral("quickopen")), ui.kJumpBtn->text(), this);
@@ -108,6 +128,10 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(QWidget *iParent, SKGDocument
             static_cast<void (KComboBox::*)(const QString &)>(&KComboBox::currentTextChanged),
             this,
             &SKGScheduledPluginWidget::onNbOccurrenceChanged);
+    connect(ui.kAdapter,
+            static_cast<void (KComboBox::*)(const QString &)>(&KComboBox::currentTextChanged),
+            this,
+            &SKGScheduledPluginWidget::onNbOccurrenceChanged);
     connect(ui.kLastOccurenceDate, &SKGDateEdit::dateChanged, this, &SKGScheduledPluginWidget::onNbOccurrenceChanged);
     connect(ui.kNbTimesVal, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SKGScheduledPluginWidget::onNbOccurrenceChanged);
     connect(ui.kOnceEveryVal, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SKGScheduledPluginWidget::onNbOccurrenceChanged);
@@ -228,6 +252,7 @@ void SKGScheduledPluginWidget::onSelectionChanged()
         ui.kFirstOccurenceDate->setDate(recOp.getDate());
         ui.kOnceEveryVal->setValue(recOp.getPeriodIncrement());
         ui.kOnceEveryUnit->setCurrentIndex(static_cast<int>(recOp.getPeriodUnit()));
+        ui.kAdapter->setCurrentIndex(ui.kAdapter->findData(recOp.getAdapter()));
 
         ui.kRemindMeVal->setValue(recOp.getWarnDays());
         ui.kRemindMe->setCheckState(recOp.isWarnEnabled() ? Qt::Checked : Qt::Unchecked);
@@ -321,6 +346,7 @@ void SKGScheduledPluginWidget::onUpdate()
             }
             IFOKDO(err, recOp.setPeriodIncrement(ui.kOnceEveryVal->value()))
             IFOKDO(err, recOp.setPeriodUnit(static_cast<SKGRecurrentOperationObject::PeriodUnit>(ui.kOnceEveryUnit->currentIndex())))
+            IFOKDO(err, recOp.setAdapter(static_cast<SKGRecurrentOperationObject::Adapter>((ui.kAdapter->currentData()).toInt())))
             IFOKDO(err, recOp.setWarnDays(ui.kRemindMeVal->value()))
             IFOKDO(err, recOp.warnEnabled(ui.kRemindMe->checkState() == Qt::Checked))
             IFOKDO(err, recOp.setAutoWriteDays(ui.kAutoWriteVal->value()))
