@@ -22,6 +22,7 @@
 #include "skgerror.h"
 #include "skghtmlboardwidget.h"
 #include "skgmainpanel.h"
+#include "skgquerycreator.h"
 #include "skgruleobject.h"
 #include "skgsearch_settings.h"
 #include "skgsearchpluginwidget.h"
@@ -143,9 +144,78 @@ bool SKGSearchPlugin::setupActions(SKGDocument *iDocument)
                          -1,
                          130); // For contextual menus
 
+    // Search field
+    QStringList attributeForQuery;
+    attributeForQuery.reserve(40);
+    attributeForQuery << QStringLiteral("d_DATEOP") << QStringLiteral("t_number") << QStringLiteral("t_mode") << QStringLiteral("t_PAYEE")
+                      << QStringLiteral("t_comment") << QStringLiteral("t_REALCOMMENT") << QStringLiteral("t_REALCATEGORY") << QStringLiteral("t_status")
+                      << QStringLiteral("t_bookmarked") << QStringLiteral("t_imported") << QStringLiteral("t_TRANSFER") << QStringLiteral("t_UNIT")
+                      << QStringLiteral("t_ACCOUNT") << QStringLiteral("t_BANK") << QStringLiteral("t_TOACCOUNT") << QStringLiteral("f_REALCURRENTAMOUNT")
+                      << QStringLiteral("t_REALREFUND") << QStringLiteral("f_BALANCE") << QStringLiteral("i_NBSUBOPERATIONS");
+
+    // Adding properties
+    QStringList properties;
+    m_currentBankDocument->getDistinctValues(
+        QStringLiteral("parameters"),
+        QStringLiteral("t_name"),
+        QStringLiteral("(t_uuid_parent like '%-operation' OR t_uuid_parent like '%-suboperation') AND t_name NOT LIKE 'SKG_%'"),
+        properties);
+    int nb = properties.count();
+    for (int i = 0; i < nb; ++i) {
+        attributeForQuery.push_back("p_" % properties.at(i));
+    }
+
+    m_searchField = new SKGQueryCreator(SKGMainPanel::getMainPanel(), true);
+    m_searchField->setParameters(m_currentBankDocument, QStringLiteral("v_suboperation_consolidated"), attributeForQuery, false);
+    connect(m_searchField, &SKGQueryCreator::search, this, &SKGSearchPlugin::onOpen);
+
+    auto *m_searchFieldAct = new QWidgetAction(this);
+    m_searchFieldAct->setDefaultWidget(m_searchField);
+    registerGlobalAction(QStringLiteral("edit_search"), m_searchFieldAct); // Global
+
     return true;
 }
 
+void SKGSearchPlugin::onOpen()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(1, err)
+    SKGRuleObject rule;
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    rule = SKGRuleObject(m_currentBankDocument);
+    IFOKDO(err, rule.setXMLSearchDefinition(m_searchField->getXMLCondition()))
+    IFOKDO(err, rule.setOrder(-1))
+    IFOKDO(err, rule.setActionType(SKGRuleObject::SEARCH))
+
+    QString wc = "i_SUBOPID in (SELECT i_SUBOPID FROM v_operation_prop WHERE " % rule.getSelectSqlOrder() % u')';
+    QString title = i18nc("Noun, a list of items", "Sub transactions corresponding to rule '%1'", rule.getSearchDescription());
+
+    // Call transaction plugin
+    QDomDocument doc(QStringLiteral("SKGML"));
+    doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(QStringLiteral("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS")));
+    QDomElement root = doc.documentElement();
+    if (root.isNull()) {
+        root = doc.createElement(QStringLiteral("parameters"));
+        doc.appendChild(root);
+    }
+
+    root.setAttribute(QStringLiteral("operationWhereClause"), wc);
+    root.setAttribute(QStringLiteral("title"), title);
+    root.setAttribute(QStringLiteral("title_icon"), QStringLiteral("system-search"));
+
+    root.setAttribute(QStringLiteral("operationTable"), QStringLiteral("v_suboperation_consolidated"));
+    root.setAttribute(QStringLiteral("currentPage"), QStringLiteral("-1"));
+    SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge operation plugin")),
+                                           -1,
+                                           doc.toString(),
+                                           i18nc("Noun, a list of items", "Sub transactions"));
+
+    QApplication::restoreOverrideCursor();
+
+    // Display error
+    SKGMainPanel::displayErrorMessage(err);
+}
+
 void SKGSearchPlugin::refresh()
 {
     SKGTRACEINFUNC(10)
