@@ -17,6 +17,7 @@
 #include "ui_skgsearchpluginwidget_pref.h"
 
 class SKGDocumentBank;
+class SKGQueryCreator;
 class QAction;
 
 /**
@@ -143,6 +144,7 @@ private Q_SLOTS:
     void raiseAlarms();
     void execute(SKGRuleObject::ProcessMode iMode);
     void find();
+    void onOpen();
 
 private:
     Q_DISABLE_COPY(SKGSearchPlugin)
@@ -152,6 +154,7 @@ private:
     Ui::skgsearchplugin_pref ui{};
     QString m_docUniqueIdentifier;
     QTimer m_timer;
+    SKGQueryCreator *m_searchField;
 };
 
 #endif // SKGSEARCHPLUGIN_H
