@@ -146,11 +146,11 @@ void SKGObjectModel::buidCache()
             m_iconImportedChecked = SKGServices::fromTheme(QStringLiteral("utilities-file-archiver"), overlay);
         }
 
-        m_iconRecurrent = SKGServices::fromTheme(QStringLiteral("chronometer"));
+        m_iconRecurrent = SKGServices::fromTheme(QStringLiteral("view-calendar-day"));
         {
             QStringList overlay;
             overlay.push_back(QStringLiteral("bookmarks"));
-            m_iconRecurrentMaster = SKGServices::fromTheme(QStringLiteral("chronometer"), overlay);
+            m_iconRecurrentMaster = SKGServices::fromTheme(QStringLiteral("view-calendar-day"), overlay);
         }
     }
 
@@ -168,7 +168,7 @@ void SKGObjectModel::buidCache()
     }
 
     if (m_ruleTable) {
-        m_iconSearch = SKGServices::fromTheme(QStringLiteral("edit-find"));
+        m_iconSearch = SKGServices::fromTheme(QStringLiteral("system-search"));
         m_iconUpdate = SKGServices::fromTheme(QStringLiteral("view-refresh"));
         m_iconAlarm = SKGServices::fromTheme(QStringLiteral("dialog-warning"));
         m_iconTemplate = SKGServices::fromTheme(QStringLiteral("edit-guides"));
