@@ -6,10 +6,10 @@
 #ifndef SKGQUERYDELEGATE_H
 #define SKGQUERYDELEGATE_H
 /** @file
-* This is a delegate for query creator.
-*
-* @author Stephane MANKOWSKI / Guillaume DE BURE
-*/
+ * This is a delegate for query creator.
+ *
+ * @author Stephane MANKOWSKI / Guillaume DE BURE
+ */
 #include <qitemdelegate.h>
 
 #include "skgbankgui_export.h"
@@ -26,7 +26,7 @@ public:
     /**
      * Default Constructor
      */
-    explicit SKGQueryDelegate(QObject* iParent, SKGDocument* iDoc, bool iModeUpdate = false, QStringList  iListAtt = QStringList());
+    explicit SKGQueryDelegate(QObject *iParent, SKGDocument *iDoc, bool iModeUpdate = false, QStringList iListAtt = QStringList());
 
     /**
      * Default Destructor
@@ -41,16 +41,14 @@ public:
      * @param index index
      * @return the widget
      */
-    QWidget* createEditor(QWidget* iParent,
-                          const QStyleOptionViewItem& option,
-                          const QModelIndex& index) const override;
+    QWidget *createEditor(QWidget *iParent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
     /**
      * Sets the data to be displayed and edited by the editor from the data model item specified by the model index.
      * @param editor the editor
      * @param index the index
      */
-    void setEditorData(QWidget* editor, const QModelIndex& index) const override;
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
 
     /**
      * Gets data from the editor widget and stores it in the specified model at the item inde
@@ -58,7 +56,7 @@ public:
      * @param model the model
      * @param index the index
      */
-    void setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
 
 private Q_SLOTS:
     void commitAndCloseEditor();
@@ -66,9 +64,9 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGQueryDelegate)
 
-    SKGDocument* m_document;
+    SKGDocument *m_document;
     bool m_updateMode;
     QStringList m_listAtt;
 };
 
-#endif  // SKGQUERYDELEGATE_H
+#endif // SKGQUERYDELEGATE_H
