@@ -16,7 +16,10 @@
 #include "skgmainpanel.h"
 #include "skgunitvalueobject.h"
 
-SKGUnitComboBox::SKGUnitComboBox(QWidget* iParent): SKGComboBox(iParent), m_document(nullptr), m_fillWhereClause(QLatin1String("t_type!='I'"))
+SKGUnitComboBox::SKGUnitComboBox(QWidget *iParent)
+    : SKGComboBox(iParent)
+    , m_document(nullptr)
+    , m_fillWhereClause(QStringLiteral("t_type!='I'"))
 {
 }
 
@@ -25,17 +28,17 @@ SKGUnitComboBox::~SKGUnitComboBox()
     m_document = nullptr;
 }
 
-void SKGUnitComboBox::setDocument(SKGDocumentBank* iDocument)
+void SKGUnitComboBox::setDocument(SKGDocumentBank *iDocument)
 {
     m_document = iDocument;
     connect(m_document, &SKGDocument::tableModified, this, &SKGUnitComboBox::dataModified);
-    dataModified(QLatin1String(""), 0);
+    dataModified(QString(), 0);
 }
 
-void SKGUnitComboBox::setWhereClauseCondition(const QString& iCondition)
+void SKGUnitComboBox::setWhereClauseCondition(const QString &iCondition)
 {
     m_fillWhereClause = iCondition;
-    dataModified(QLatin1String(""), 0);
+    dataModified(QString(), 0);
 }
 
 SKGUnitObject SKGUnitComboBox::getUnit()
@@ -55,7 +58,7 @@ SKGUnitObject SKGUnitComboBox::getUnit()
             IFOKDO(err, unitVal.setQuantity(1))
             IFOKDO(err, unitVal.save())
 
-            IFOK(err) m_document->sendMessage(i18nc("An information message",  "Unit '%1' has been created", text()), SKGDocument::Positive);
+            IFOK(err) m_document->sendMessage(i18nc("An information message", "Unit '%1' has been created", text()), SKGDocument::Positive);
         } else {
             err = unit.load();
         }
@@ -63,7 +66,7 @@ SKGUnitObject SKGUnitComboBox::getUnit()
     return unit;
 }
 
-void SKGUnitComboBox::setUnit(const SKGUnitObject& iUnit)
+void SKGUnitComboBox::setUnit(const SKGUnitObject &iUnit)
 {
     if (text() != iUnit.getSymbol()) {
         setText(iUnit.getSymbol());
@@ -76,7 +79,11 @@ void SKGUnitComboBox::refershList()
 {
     // Fill comboboxes
     if (m_document != nullptr) {
-        SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << this, m_document, QLatin1String("unit"), QLatin1String("ifnull(t_symbol,t_name)"), m_fillWhereClause);
+        SKGMainPanel::fillWithDistinctValue(QList<QWidget *>() << this,
+                                            m_document,
+                                            QStringLiteral("unit"),
+                                            QStringLiteral("ifnull(t_symbol,t_name)"),
+                                            m_fillWhereClause);
         SKGServices::SKGUnitInfo primary = m_document->getPrimaryUnit();
         if (!primary.Symbol.isEmpty()) {
             this->setCurrentIndex(this->findText(primary.Symbol));
@@ -84,18 +91,16 @@ void SKGUnitComboBox::refershList()
     }
 }
 
-void SKGUnitComboBox::dataModified(const QString& iTableName, int iIdTransaction)
+void SKGUnitComboBox::dataModified(const QString &iTableName, int iIdTransaction)
 {
     Q_UNUSED(iIdTransaction)
 
     // Refresh widgets
     if (m_document != nullptr) {
-        QSqlDatabase* db = m_document->getMainDatabase();
+        QSqlDatabase *db = m_document->getMainDatabase();
         setEnabled(db != nullptr);
-        if (db != nullptr && (iTableName == QLatin1String("unit") || iTableName.isEmpty())) {
+        if (db != nullptr && (iTableName == QStringLiteral("unit") || iTableName.isEmpty())) {
             refershList();
         }
     }
 }
-
-
