@@ -4,10 +4,10 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
-* This file defines classes SKGBudgetObject.
-*
-* @author Stephane MANKOWSKI / Guillaume DE BURE
-*/
+ * This file defines classes SKGBudgetObject.
+ *
+ * @author Stephane MANKOWSKI / Guillaume DE BURE
+ */
 #include "skgbudgetobject.h"
 
 #include <klocalizedstring.h>
@@ -19,29 +19,30 @@
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
 
-SKGBudgetObject::SKGBudgetObject() : SKGBudgetObject(nullptr)
-{}
-
-SKGBudgetObject::SKGBudgetObject(SKGDocument* iDocument, int iID)
-    : SKGObjectBase(iDocument, QLatin1String("v_budget"), iID)
-{}
-
-SKGBudgetObject::~SKGBudgetObject()
-    = default;
-
-SKGBudgetObject::SKGBudgetObject(const SKGBudgetObject& iObject)
-    = default;
-
-SKGBudgetObject::SKGBudgetObject(const SKGObjectBase& iObject)
+SKGBudgetObject::SKGBudgetObject()
+    : SKGBudgetObject(nullptr)
 {
-    if (iObject.getRealTable() == QLatin1String("budget")) {
+}
+
+SKGBudgetObject::SKGBudgetObject(SKGDocument *iDocument, int iID)
+    : SKGObjectBase(iDocument, QStringLiteral("v_budget"), iID)
+{
+}
+
+SKGBudgetObject::~SKGBudgetObject() = default;
+
+SKGBudgetObject::SKGBudgetObject(const SKGBudgetObject &iObject) = default;
+
+SKGBudgetObject::SKGBudgetObject(const SKGObjectBase &iObject)
+{
+    if (iObject.getRealTable() == QStringLiteral("budget")) {
         copyFrom(iObject);
     } else {
-        *this = SKGObjectBase(iObject.getDocument(), QLatin1String("v_budget"), iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), QStringLiteral("v_budget"), iObject.getID());
     }
 }
 
-SKGBudgetObject& SKGBudgetObject::operator= (const SKGObjectBase& iObject)
+SKGBudgetObject &SKGBudgetObject::operator=(const SKGObjectBase &iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -52,12 +53,12 @@ QString SKGBudgetObject::getWhereclauseId() const
     // Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();
     if (output.isEmpty()) {
-        QString y = getAttribute(QLatin1String("i_year"));
+        QString y = getAttribute(QStringLiteral("i_year"));
         if (!y.isEmpty()) {
             output = "i_year=" % y;
         }
 
-        QString m = getAttribute(QLatin1String("i_month"));
+        QString m = getAttribute(QStringLiteral("i_month"));
         if (!m.isEmpty()) {
             if (!output.isEmpty()) {
                 output = output % " AND ";
@@ -65,86 +66,86 @@ QString SKGBudgetObject::getWhereclauseId() const
             output = output % "i_month=" % m;
         }
 
-        QString r = getAttribute(QLatin1String("rc_category_id"));
+        QString r = getAttribute(QStringLiteral("rc_category_id"));
         if (!output.isEmpty()) {
             output = output % " AND ";
         }
-        output = output % "rc_category_id=" % (r.isEmpty() ? QLatin1String("0") : std::move(r));
+        output = output % "rc_category_id=" % (r.isEmpty() ? QStringLiteral("0") : std::move(r));
     }
     return output;
 }
 
 SKGError SKGBudgetObject::setBudgetedAmount(double iAmount)
 {
-    SKGError err = setAttribute(QLatin1String("f_budgeted"), SKGServices::doubleToString(iAmount));
-    IFOKDO(err, setAttribute(QLatin1String("f_budgeted_modified"), SKGServices::doubleToString(iAmount)))
-    IFOKDO(err, setAttribute(QLatin1String("t_modification_reasons"), QLatin1String("")))
+    SKGError err = setAttribute(QStringLiteral("f_budgeted"), SKGServices::doubleToString(iAmount));
+    IFOKDO(err, setAttribute(QStringLiteral("f_budgeted_modified"), SKGServices::doubleToString(iAmount)))
+    IFOKDO(err, setAttribute(QStringLiteral("t_modification_reasons"), QString()))
     return err;
 }
 
 double SKGBudgetObject::getBudgetedAmount() const
 {
-    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_budgeted")));
+    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_budgeted")));
 }
 
 double SKGBudgetObject::getBudgetedModifiedAmount() const
 {
-    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_budgeted_modified")));
+    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_budgeted_modified")));
 }
 
 QString SKGBudgetObject::getModificationReasons() const
 {
-    return getAttribute(QLatin1String("t_modification_reasons"));
+    return getAttribute(QStringLiteral("t_modification_reasons"));
 }
 
 double SKGBudgetObject::getDelta() const
 {
-    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_DELTABEFORETRANSFER")));
+    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_DELTABEFORETRANSFER")));
 }
 
 SKGError SKGBudgetObject::setYear(int iYear)
 {
-    return setAttribute(QLatin1String("i_year"), SKGServices::intToString(iYear));
+    return setAttribute(QStringLiteral("i_year"), SKGServices::intToString(iYear));
 }
 
 int SKGBudgetObject::getYear() const
 {
-    return SKGServices::stringToInt(getAttribute(QLatin1String("i_year")));
+    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_year")));
 }
 
 SKGError SKGBudgetObject::setMonth(int iMonth)
 {
-    return setAttribute(QLatin1String("i_month"), SKGServices::intToString(iMonth));
+    return setAttribute(QStringLiteral("i_month"), SKGServices::intToString(iMonth));
 }
 
 int SKGBudgetObject::getMonth() const
 {
-    return SKGServices::stringToInt(getAttribute(QLatin1String("i_month")));
+    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_month")));
 }
 
-SKGError SKGBudgetObject::setCategory(const SKGCategoryObject& iCategory)
+SKGError SKGBudgetObject::setCategory(const SKGCategoryObject &iCategory)
 {
-    return setAttribute(QLatin1String("rc_category_id"), SKGServices::intToString(iCategory.getID()));
+    return setAttribute(QStringLiteral("rc_category_id"), SKGServices::intToString(iCategory.getID()));
 }
 
-SKGError SKGBudgetObject::getCategory(SKGCategoryObject& oCategory) const
+SKGError SKGBudgetObject::getCategory(SKGCategoryObject &oCategory) const
 {
-    return getDocument()->getObject(QLatin1String("v_category"), "id=" % getAttribute(QLatin1String("rc_category_id")), oCategory);
+    return getDocument()->getObject(QStringLiteral("v_category"), "id=" % getAttribute(QStringLiteral("rc_category_id")), oCategory);
 }
 
 SKGError SKGBudgetObject::enableSubCategoriesInclusion(bool iEnable)
 {
-    return setAttribute(QLatin1String("t_including_subcategories"), iEnable ? QLatin1String("Y") : QLatin1String("N"));
+    return setAttribute(QStringLiteral("t_including_subcategories"), iEnable ? QStringLiteral("Y") : QStringLiteral("N"));
 }
 
 bool SKGBudgetObject::isSubCategoriesInclusionEnabled() const
 {
-    return (getAttribute(QLatin1String("t_including_subcategories")) == QLatin1String("Y"));
+    return (getAttribute(QStringLiteral("t_including_subcategories")) == QStringLiteral("Y"));
 }
 
 SKGError SKGBudgetObject::removeCategory()
 {
-    return setAttribute(QLatin1String("rc_category_id"), QLatin1String("0"));
+    return setAttribute(QStringLiteral("rc_category_id"), QStringLiteral("0"));
 }
 
 SKGError SKGBudgetObject::process()
@@ -154,15 +155,15 @@ SKGError SKGBudgetObject::process()
     // Main values
     int m = getMonth();
     int y = getYear();
-    double transferred = SKGServices::stringToDouble(getAttribute(QLatin1String("f_transferred")));
+    double transferred = SKGServices::stringToDouble(getAttribute(QStringLiteral("f_transferred")));
 
     // Get budgets rules ordered
     SKGObjectBase::SKGListSKGObjectBase budgetsRules;
     QString sql = "(t_year_condition='N' OR i_year=" % SKGServices::intToString(y) % ") AND "
                   "(t_month_condition='N' OR i_month=" % SKGServices::intToString(m) % ") AND "
-                  "(t_category_condition='N' OR rc_category_id=" % getAttribute(QLatin1String("rc_category_id")) % ") "
+                  "(t_category_condition='N' OR rc_category_id=" % getAttribute(QStringLiteral("rc_category_id")) % ") "
                   "ORDER BY i_ORDER ASC";
-    err = getDocument()->getObjects(QLatin1String("v_budgetrule"), sql, budgetsRules);
+    err = getDocument()->getObjects(QStringLiteral("v_budgetrule"), sql, budgetsRules);
 
     int nb = budgetsRules.count();
     if (!err && (nb != 0)) {
@@ -175,9 +176,11 @@ SKGError SKGBudgetObject::process()
             double delta = getDelta();
             double quantity = rule.getQuantity();
             if (delta != 0.0) {
-                if (cond == SKGBudgetRuleObject::ALL || (delta < 0 && cond == SKGBudgetRuleObject::NEGATIVE) || (delta > 0 && cond == SKGBudgetRuleObject::POSITIVE)) {
+                if (cond == SKGBudgetRuleObject::ALL || (delta < 0 && cond == SKGBudgetRuleObject::NEGATIVE)
+                    || (delta > 0 && cond == SKGBudgetRuleObject::POSITIVE)) {
                     // Compute value to transfer
-                    double value = (rule.isAbolute() ? (cond == SKGBudgetRuleObject::NEGATIVE ? qMax(delta, quantity) : qMin(delta, quantity)) : quantity * (delta - transferred) / 100.0);
+                    double value = (rule.isAbolute() ? (cond == SKGBudgetRuleObject::NEGATIVE ? qMax(delta, quantity) : qMin(delta, quantity))
+                                                     : quantity * (delta - transferred) / 100.0);
 
                     // Get impacted budget
                     SKGBudgetObject impactedBudget = *this;
@@ -214,24 +217,34 @@ SKGError SKGBudgetObject::process()
                         err = impactedBudget.setCategory(transferCategory);
                     }
 
-                    IFOK(err) {
+                    IFOK(err)
+                    {
                         if (impactedBudget.exist()) {
                             err = impactedBudget.load();
                             QString newBudget = SKGServices::doubleToString(impactedBudget.getBudgetedModifiedAmount() - value);
-                            IFOKDO(err, impactedBudget.setAttribute(QLatin1String("f_budgeted_modified"), newBudget))
-                            QString reasons = impactedBudget.getAttribute(QLatin1String("t_modification_reasons"));
+                            IFOKDO(err, impactedBudget.setAttribute(QStringLiteral("f_budgeted_modified"), newBudget))
+                            QString reasons = impactedBudget.getAttribute(QStringLiteral("t_modification_reasons"));
                             if (!reasons.isEmpty()) {
                                 reasons += '\n';
                             }
-                            reasons += i18nc("Message", "Transfer of %1 from '%2' to '%3' due to the rule '%4'", value, getDisplayName(), impactedBudget.getDisplayName(), rule.getDisplayName());
-                            IFOKDO(err, impactedBudget.setAttribute(QLatin1String("t_modification_reasons"), reasons))
+                            reasons += i18nc("Message",
+                                             "Transfer of %1 from '%2' to '%3' due to the rule '%4'",
+                                             value,
+                                             getDisplayName(),
+                                             impactedBudget.getDisplayName(),
+                                             rule.getDisplayName());
+                            IFOKDO(err, impactedBudget.setAttribute(QStringLiteral("t_modification_reasons"), reasons))
                             IFOKDO(err, impactedBudget.save())
 
                             transferred += value;
-                            IFOKDO(err, setAttribute(QLatin1String("f_transferred"), SKGServices::doubleToString(transferred)))
+                            IFOKDO(err, setAttribute(QStringLiteral("f_transferred"), SKGServices::doubleToString(transferred)))
                             IFOKDO(err, save())
                         } else {
-                            getDocument()->sendMessage(i18nc("", "Impossible to apply the rule '%1' for budget '%2' because the impacted budget does not exist", rule.getDisplayName(), this->getDisplayName()), SKGDocument::Warning);
+                            getDocument()->sendMessage(i18nc("",
+                                                             "Impossible to apply the rule '%1' for budget '%2' because the impacted budget does not exist",
+                                                             rule.getDisplayName(),
+                                                             this->getDisplayName()),
+                                                       SKGDocument::Warning);
                         }
                     }
                 }
@@ -239,13 +252,13 @@ SKGError SKGBudgetObject::process()
             IFOKDO(err, getDocument()->stepForward(i + 1))
         }
 
-        SKGENDTRANSACTION(getDocument(),  err)
+        SKGENDTRANSACTION(getDocument(), err)
     }
 
     return err;
 }
 
-SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int iYear, int iBaseYear, bool iUseScheduledOperation, bool iRemovePreviousBudget)
+SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank *iDocument, int iYear, int iBaseYear, bool iUseScheduledOperation, bool iRemovePreviousBudget)
 {
     Q_UNUSED(iUseScheduledOperation)
     SKGError err;
@@ -254,10 +267,9 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
     int fistMonth = 0;
     if (iDocument != nullptr) {
         SKGStringListList listTmp;
-        err = iDocument->executeSelectSqliteOrder(
-                  "SELECT MIN(STRFTIME('%m', d_date)) FROM operation WHERE i_group_id = 0 AND STRFTIME('%Y', d_date) = '" % baseYear %
-                  "' AND t_template='N'",
-                  listTmp);
+        err = iDocument->executeSelectSqliteOrder("SELECT MIN(STRFTIME('%m', d_date)) FROM operation WHERE i_group_id = 0 AND STRFTIME('%Y', d_date) = '"
+                                                      % baseYear % "' AND t_template='N'",
+                                                  listTmp);
         if (listTmp.count() == 2) {
             fistMonth = SKGServices::stringToInt(listTmp.at(1).at(0));
         }
@@ -274,8 +286,8 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
                       ") GROUP BY t_REALCATEGORY ORDER BY COUNT(TOT) DESC, (MAX(TOT)-MIN(TOT))/ABS(ROUND(TOTAL(TOT)/COUNT(TOT))) ASC, ROUND(TOTAL(TOT)/COUNT(TOT)) ASC";
         err = iDocument->executeSelectSqliteOrder(sql, listTmp);
 
-
-        // SELECT r.d_date,r.i_period_increment,r.t_period_unit, r.i_nb_times, r. t_times, r.t_CATEGORY, r.f_CURRENTAMOUNT  FROM v_recurrentoperation_display r WHERE r.t_TRANSFER='N'
+        // SELECT r.d_date,r.i_period_increment,r.t_period_unit, r.i_nb_times, r. t_times, r.t_CATEGORY, r.f_CURRENTAMOUNT  FROM v_recurrentoperation_display r
+        // WHERE r.t_TRANSFER='N'
 
         /*double sumBudgeted = 0;
         double sumOps = 0;*/
@@ -283,7 +295,8 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
         int nbval = listTmp.count();
         if (!err) {
             int step = 0;
-            err = iDocument->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create automatic budget"), nbval - 1 + 1 + (iRemovePreviousBudget ? 1 : 0));
+            err = iDocument->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create automatic budget"),
+                                              nbval - 1 + 1 + (iRemovePreviousBudget ? 1 : 0));
 
             // Remove previous budgets
             if (iRemovePreviousBudget) {
@@ -293,7 +306,7 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
             }
 
             // Create budgets
-            for (int i = 1; !err && i < nbval; ++i) {  // Ignore header
+            for (int i = 1; !err && i < nbval; ++i) { // Ignore header
                 // Get values
                 QString catName = listTmp.at(i).at(0);
                 int count = SKGServices::stringToInt(listTmp.at(i).at(1));
@@ -304,7 +317,7 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
 
                 if (!catName.isEmpty() && (countPercent > 85 || count == 1)) {
                     SKGCategoryObject cat;
-                    err = iDocument->getObject(QLatin1String("v_category"), "t_fullname = '" % SKGServices::stringToSqlString(catName) % QLatin1Char('\''), cat);
+                    err = iDocument->getObject(QStringLiteral("v_category"), "t_fullname = '" % SKGServices::stringToSqlString(catName) % u'\'', cat);
                     for (int m = fistMonth; !err && m <= (count == 1 ? fistMonth : 12); ++m) {
                         SKGBudgetObject budget(iDocument);
                         err = budget.setBudgetedAmount(amount);
@@ -321,17 +334,17 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
             }
 
             // Analyze
-            IFOKDO(err, iDocument->executeSqliteOrder(QLatin1String("ANALYZE")))
+            IFOKDO(err, iDocument->executeSqliteOrder(QStringLiteral("ANALYZE")))
             ++step;
             IFOKDO(err, iDocument->stepForward(step))
 
-            SKGENDTRANSACTION(iDocument,  err)
+            SKGENDTRANSACTION(iDocument, err)
         }
     }
     return err;
 }
 
-SKGError SKGBudgetObject::balanceBudget(SKGDocumentBank* iDocument, int iYear, int iMonth, bool iBalanceYear)
+SKGError SKGBudgetObject::balanceBudget(SKGDocumentBank *iDocument, int iYear, int iMonth, bool iBalanceYear)
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err)
@@ -342,7 +355,9 @@ SKGError SKGBudgetObject::balanceBudget(SKGDocumentBank* iDocument, int iYear, i
         if (!err && iMonth != -1) {
             for (int m = (iMonth == 0 ? 1 : std::as_const(iMonth)); !err && m <= (iMonth == 0 ? 12 : iMonth); ++m) {
                 SKGStringListList listTmp;
-                err = iDocument->executeSelectSqliteOrder("SELECT TOTAL(f_budgeted) FROM budget WHERE i_year=" % SKGServices::intToString(iYear) % " AND i_month=" % SKGServices::intToString(m) % " AND rc_category_id<>0", listTmp);
+                err = iDocument->executeSelectSqliteOrder("SELECT TOTAL(f_budgeted) FROM budget WHERE i_year=" % SKGServices::intToString(iYear)
+                                                              % " AND i_month=" % SKGServices::intToString(m) % " AND rc_category_id<>0",
+                                                          listTmp);
                 if (!err && listTmp.count() == 2) {
                     SKGBudgetObject budget(iDocument);
                     double amount = -SKGServices::stringToDouble(listTmp.at(1).at(0));
@@ -358,7 +373,9 @@ SKGError SKGBudgetObject::balanceBudget(SKGDocumentBank* iDocument, int iYear, i
         // Annual balancing
         if (!err && iBalanceYear) {
             SKGStringListList listTmp;
-            err = iDocument->executeSelectSqliteOrder("SELECT TOTAL(f_budgeted) FROM budget WHERE i_year=" % SKGServices::intToString(iYear) % " AND (i_month<>0 OR rc_category_id<>0)", listTmp);
+            err = iDocument->executeSelectSqliteOrder("SELECT TOTAL(f_budgeted) FROM budget WHERE i_year=" % SKGServices::intToString(iYear)
+                                                          % " AND (i_month<>0 OR rc_category_id<>0)",
+                                                      listTmp);
             if (!err && listTmp.count() == 2) {
                 SKGBudgetObject budget(iDocument);
                 double amount = -SKGServices::stringToDouble(listTmp.at(1).at(0));
@@ -370,9 +387,7 @@ SKGError SKGBudgetObject::balanceBudget(SKGDocumentBank* iDocument, int iYear, i
         }
         IFOKDO(err, iDocument->stepForward(2))
 
-        SKGENDTRANSACTION(iDocument,  err)
+        SKGENDTRANSACTION(iDocument, err)
     }
     return err;
 }
-
-
