@@ -16,44 +16,47 @@
 #include "skgsuboperationobject.h"
 #include "skgtraces.h"
 
-SKGCategoryObject::SKGCategoryObject() : SKGCategoryObject(nullptr)
-{}
+SKGCategoryObject::SKGCategoryObject()
+    : SKGCategoryObject(nullptr)
+{
+}
 
-SKGCategoryObject::SKGCategoryObject(SKGDocument* iDocument, int iID) : SKGNamedObject(iDocument, QLatin1String("v_category"), iID)
-{}
+SKGCategoryObject::SKGCategoryObject(SKGDocument *iDocument, int iID)
+    : SKGNamedObject(iDocument, QStringLiteral("v_category"), iID)
+{
+}
 
-SKGCategoryObject::~SKGCategoryObject()
-    = default;
+SKGCategoryObject::~SKGCategoryObject() = default;
 
-SKGCategoryObject::SKGCategoryObject(const SKGCategoryObject& iObject) = default;
+SKGCategoryObject::SKGCategoryObject(const SKGCategoryObject &iObject) = default;
 
-SKGCategoryObject::SKGCategoryObject(const SKGObjectBase& iObject)
+SKGCategoryObject::SKGCategoryObject(const SKGObjectBase &iObject)
 
 {
-    if (iObject.getRealTable() == QLatin1String("category")) {
+    if (iObject.getRealTable() == QStringLiteral("category")) {
         copyFrom(iObject);
     } else {
-        *this = SKGNamedObject(iObject.getDocument(), QLatin1String("v_category"), iObject.getID());
+        *this = SKGNamedObject(iObject.getDocument(), QStringLiteral("v_category"), iObject.getID());
     }
 }
 
-SKGCategoryObject& SKGCategoryObject::operator= (const SKGObjectBase& iObject)
+SKGCategoryObject &SKGCategoryObject::operator=(const SKGObjectBase &iObject)
 {
     copyFrom(iObject);
     return *this;
 }
 
-SKGCategoryObject& SKGCategoryObject::operator= (const SKGCategoryObject& iObject)
+SKGCategoryObject &SKGCategoryObject::operator=(const SKGCategoryObject &iObject)
 {
     copyFrom(iObject);
     return *this;
 }
 
-SKGError SKGCategoryObject::setName(const QString& iName)
+SKGError SKGCategoryObject::setName(const QString &iName)
 {
     SKGError err;
     if (iName.contains(OBJECTSEPARATOR)) {
-        err = SKGError(ERR_FAIL,  i18nc("Error message", "Invalid name '%1' because of the name cannot contain '%2'", iName, QString(OBJECTSEPARATOR)));
+        err = SKGError(ERR_FAIL, i18nc("Error message", "Invalid name '%1' because of the name cannot contain '%2'", iName, OBJECTSEPARATOR));
     } else {
         err = SKGNamedObject::setName(iName);
     }
@@ -63,17 +66,17 @@ SKGError SKGCategoryObject::setName(const QString& iName)
 QString SKGCategoryObject::getWhereclauseId() const
 {
     // Could we use the id
-    QString output = SKGObjectBase::getWhereclauseId();  // clazy:exclude=skipped-base-method
+    QString output = SKGObjectBase::getWhereclauseId(); // clazy:exclude=skipped-base-method
     if (output.isEmpty()) {
-        if (!(getAttribute(QLatin1String("t_name")).isEmpty())) {
-            output = "t_name='" % SKGServices::stringToSqlString(getAttribute(QLatin1String("t_name"))) % QLatin1Char('\'');
+        if (!(getAttribute(QStringLiteral("t_name")).isEmpty())) {
+            output = "t_name='" % SKGServices::stringToSqlString(getAttribute(QStringLiteral("t_name"))) % u'\'';
         }
-        QString rd_category_id = getAttribute(QLatin1String("rd_category_id"));
+        QString rd_category_id = getAttribute(QStringLiteral("rd_category_id"));
         if (!output.isEmpty()) {
-            output += QLatin1String(" AND ");
+            output += QStringLiteral(" AND ");
         }
         if (rd_category_id.isEmpty()) {
-            output += QLatin1String("(rd_category_id=0 OR rd_category_id IS NULL OR rd_category_id='')");
+            output += QStringLiteral("(rd_category_id=0 OR rd_category_id IS NULL OR rd_category_id='')");
         } else {
             output += "rd_category_id=" % rd_category_id;
         }
@@ -83,14 +86,14 @@ QString SKGCategoryObject::getWhereclauseId() const
 
 QString SKGCategoryObject::getFullName() const
 {
-    return getAttribute(QLatin1String("t_fullname"));
+    return getAttribute(QStringLiteral("t_fullname"));
 }
 
-SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
-        const QString& iFullPath,
-        SKGCategoryObject& oCategory,
-        bool iSendPopupMessageOnCreation,
-        bool iRenameIfAlreadyExist)
+SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank *iDocument,
+                                               const QString &iFullPath,
+                                               SKGCategoryObject &oCategory,
+                                               bool iSendPopupMessageOnCreation,
+                                               bool iRenameIfAlreadyExist)
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err)
@@ -100,7 +103,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
         oCategory = SKGCategoryObject(nullptr, 0);
     } else if (iDocument != nullptr) {
         if (!iRenameIfAlreadyExist) {
-            iDocument->getObject(QLatin1String("v_category"), "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % QLatin1Char('\''), oCategory);
+            iDocument->getObject(QStringLiteral("v_category"), "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % u'\'', oCategory);
         } else {
             oCategory.resetID();
         }
@@ -117,7 +120,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
                     int index = 1;
                     while (!err && oCategory.exist()) {
                         index++;
-                        err = oCategory.setName(iFullPath % " (" % SKGServices::intToString(index) % QLatin1Char(')'));
+                        err = oCategory.setName(iFullPath % " (" % SKGServices::intToString(index) % u')');
                     }
                 }
 
@@ -125,13 +128,14 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
             } else {
                 // Get first and second parts of the branch
                 QString first = iFullPath.mid(0, posSeparator);
-                QString second = iFullPath.mid(posSeparator + QString(OBJECTSEPARATOR).length(), iFullPath.length() - posSeparator - QString(OBJECTSEPARATOR).length());
+                QString second = iFullPath.mid(posSeparator + OBJECTSEPARATOR.length(), iFullPath.length() - posSeparator - OBJECTSEPARATOR.length());
 
                 // Get first category
                 SKGCategoryObject FirstCategory;
                 err = SKGCategoryObject::createPathCategory(iDocument, first, FirstCategory);
 
-                IFOK(err) {
+                IFOK(err)
+                {
                     // Get second category
                     err = FirstCategory.addCategory(oCategory);
 
@@ -142,7 +146,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
                     if (!err && iRenameIfAlreadyExist) {
                         int index = 2;
                         while (!err && oCategory.exist()) {
-                            err = oCategory.setName(second % " (" % SKGServices::intToString(index) % QLatin1Char(')'));
+                            err = oCategory.setName(second % " (" % SKGServices::intToString(index) % u')');
                             ++index;
                         }
                     }
@@ -161,31 +165,36 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
     return err;
 }
 
-SKGError SKGCategoryObject::addCategory(SKGCategoryObject& oCategory)
+SKGError SKGCategoryObject::addCategory(SKGCategoryObject &oCategory)
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err)
     if (getID() == 0) {
-        err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGCategoryObject::addCategory")));
+        err = SKGError(
+            ERR_FAIL,
+            i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGCategoryObject::addCategory")));
     } else {
-        oCategory = SKGCategoryObject(qobject_cast<SKGDocumentBank*>(getDocument()));
-        err = oCategory.setAttribute(QLatin1String("rd_category_id"), SKGServices::intToString(getID()));
+        oCategory = SKGCategoryObject(qobject_cast<SKGDocumentBank *>(getDocument()));
+        err = oCategory.setAttribute(QStringLiteral("rd_category_id"), SKGServices::intToString(getID()));
     }
     return err;
 }
 
-SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject& iCategory)
+SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject &iCategory)
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err)
     if (iCategory.getID() == 0) {
-        err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGCategoryObject::setParentCategory")));
+        err = SKGError(ERR_FAIL,
+                       i18nc("Error message",
+                             "%1 failed because linked object is not yet saved in the database.",
+                             QStringLiteral("SKGCategoryObject::setParentCategory")));
     } else {
         // Check if it is a loop
         SKGCategoryObject current = iCategory;
         do {
             if (current == *this) {
-                err = SKGError(ERR_FAIL,  i18nc("Error message", "You cannot create a loop."));
+                err = SKGError(ERR_FAIL, i18nc("Error message", "You cannot create a loop."));
             } else {
                 SKGCategoryObject parent2;
                 current.getParentCategory(parent2);
@@ -193,32 +202,33 @@ SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject& iCategory
             }
         } while (!err && current.getID() != 0);
 
-        IFOKDO(err, setAttribute(QLatin1String("rd_category_id"), SKGServices::intToString(iCategory.getID())))
+        IFOKDO(err, setAttribute(QStringLiteral("rd_category_id"), SKGServices::intToString(iCategory.getID())))
     }
     return err;
 }
 
 SKGError SKGCategoryObject::removeParentCategory()
 {
-    return setAttribute(QLatin1String("rd_category_id"), QLatin1String("0"));
+    return setAttribute(QStringLiteral("rd_category_id"), QStringLiteral("0"));
 }
 
-SKGError SKGCategoryObject::getParentCategory(SKGCategoryObject& oCategory) const
+SKGError SKGCategoryObject::getParentCategory(SKGCategoryObject &oCategory) const
 {
     SKGError err;
-    QString parent_id = getAttribute(QLatin1String("rd_category_id"));
-    if (!parent_id.isEmpty() && parent_id != QLatin1String("0")) {
-        err = getDocument()->getObject(QLatin1String("v_category"), "id=" % parent_id, oCategory);
+    QString parent_id = getAttribute(QStringLiteral("rd_category_id"));
+    if (!parent_id.isEmpty() && parent_id != QStringLiteral("0")) {
+        err = getDocument()->getObject(QStringLiteral("v_category"), "id=" % parent_id, oCategory);
     }
     return err;
 }
 
-SKGError SKGCategoryObject::getRootCategory(SKGCategoryObject& oCategory) const
+SKGError SKGCategoryObject::getRootCategory(SKGCategoryObject &oCategory) const
 {
     SKGError err;
     SKGCategoryObject parent2;
     err = getParentCategory(parent2);
-    IFOK(err) {
+    IFOK(err)
+    {
         if (!parent2.exist()) {
             // No parent
             oCategory = *this;
@@ -230,53 +240,48 @@ SKGError SKGCategoryObject::getRootCategory(SKGCategoryObject& oCategory) const
     return err;
 }
 
-
-SKGError SKGCategoryObject::getCategories(SKGListSKGObjectBase& oCategoryList) const
+SKGError SKGCategoryObject::getCategories(SKGListSKGObjectBase &oCategoryList) const
 {
-    return getDocument()->getObjects(QLatin1String("v_category"),
-                                     "rd_category_id=" % SKGServices::intToString(getID()),
-                                     oCategoryList);
+    return getDocument()->getObjects(QStringLiteral("v_category"), "rd_category_id=" % SKGServices::intToString(getID()), oCategoryList);
 }
 
 double SKGCategoryObject::getCurrentAmount() const
 {
-    QString v = getAttribute(QLatin1String("f_SUMCURRENTAMOUNT"));
+    QString v = getAttribute(QStringLiteral("f_SUMCURRENTAMOUNT"));
     if (v.isEmpty()) {
-        SKGNamedObject cat(getDocument(), QLatin1String("v_category_display"), getID());
-        v = cat.getAttribute(QLatin1String("f_SUMCURRENTAMOUNT"));
+        SKGNamedObject cat(getDocument(), QStringLiteral("v_category_display"), getID());
+        v = cat.getAttribute(QStringLiteral("f_SUMCURRENTAMOUNT"));
     }
     return SKGServices::stringToDouble(v);
 }
 
-SKGError SKGCategoryObject::getSubOperations(SKGListSKGObjectBase& oSubOperations) const
+SKGError SKGCategoryObject::getSubOperations(SKGListSKGObjectBase &oSubOperations) const
 {
-    SKGError err = getDocument()->getObjects(QLatin1String("v_suboperation"),
-                   "r_category_id=" % SKGServices::intToString(getID()),
-                   oSubOperations);
+    SKGError err = getDocument()->getObjects(QStringLiteral("v_suboperation"), "r_category_id=" % SKGServices::intToString(getID()), oSubOperations);
     return err;
 }
 
 SKGError SKGCategoryObject::bookmark(bool iBookmark)
 {
-    return setAttribute(QLatin1String("t_bookmarked"), iBookmark ? QLatin1String("Y") : QLatin1String("N"));
+    return setAttribute(QStringLiteral("t_bookmarked"), iBookmark ? QStringLiteral("Y") : QStringLiteral("N"));
 }
 
 bool SKGCategoryObject::isBookmarked() const
 {
-    return (getAttribute(QLatin1String("t_bookmarked")) == QLatin1String("Y"));
+    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y"));
 }
 
 SKGError SKGCategoryObject::setClosed(bool iClosed)
 {
-    return setAttribute(QLatin1String("t_close"), iClosed ? QLatin1String("Y") : QLatin1String("N"));
+    return setAttribute(QStringLiteral("t_close"), iClosed ? QStringLiteral("Y") : QStringLiteral("N"));
 }
 
 bool SKGCategoryObject::isClosed() const
 {
-    return (getAttribute(QLatin1String("t_close")) == QLatin1String("Y"));
+    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y"));
 }
 
-SKGError SKGCategoryObject::merge(const SKGCategoryObject& iCategory)
+SKGError SKGCategoryObject::merge(const SKGCategoryObject &iCategory)
 {
     SKGError err;
 
@@ -301,5 +306,3 @@ SKGError SKGCategoryObject::merge(const SKGCategoryObject& iCategory)
     IFOKDO(err, iCategory.remove(false))
     return err;
 }
-
-
