@@ -644,12 +644,20 @@ SKGError SKGImportExportManager::importFile()
     SKGError err;
     SKGTRACEINFUNCRC(2, err)
     if (m_document != nullptr) {
-        SKGBEGINPROGRESSTRANSACTION(*m_document, i18nc("Noun, name of the user action", "Import with codec %1", m_codec), err, 3)
+        SKGBEGINPROGRESSTRANSACTION(*m_document, i18nc("Noun, name of the user action", "Import with codec %1", m_codec), err, 4)
 
         err = m_document->executeSqliteOrder(QStringLiteral("ANALYZE"));
 
         IFOKDO(err, m_document->stepForward(1))
 
+        // Get list of banks
+        SKGStringListList listBanks;
+        IFOKDO(err, m_document->executeSelectSqliteOrder(QStringLiteral("SELECT group_concat(id) FROM bank"), listBanks));
+
+        // Get list of accounts
+        SKGStringListList listAccounts;
+        IFOKDO(err, m_document->executeSelectSqliteOrder(QStringLiteral("SELECT group_concat(id) FROM account"), listAccounts));
+
         IFOK(err)
         {
             // Search plugins
@@ -660,7 +668,7 @@ SKGError SKGImportExportManager::importFile()
                 fileTreated = true;
                 m_AccountToCheck.clear();
                 SKGTRACEL(2) << "Input filename=" << m_fileName.toDisplayString() << Qt::endl;
-                err = pluginInterface->importFile();
+                IFOKDO(err, pluginInterface->importFile());
             }
 
             if (!err && !fileTreated) {
@@ -671,6 +679,22 @@ SKGError SKGImportExportManager::importFile()
 
         IFOKDO(err, finalizeImportation())
         IFOKDO(err, m_document->stepForward(3))
+
+        // Delete empty new accounts
+        if (listAccounts.length() == 2 && listAccounts.at(1).at(0).length() > 0) {
+            IFOKDO(err,
+                   m_document->executeSqliteOrder(QStringLiteral("DELETE FROM account where id in (select id from v_account_amount where id not in (")
+                                                  % listAccounts.at(1).at(0) % QStringLiteral(") and f_CURRENTAMOUNT=0)")));
+        }
+
+        // Delete empty new banks
+        if (listBanks.length() == 2 && listBanks.at(1).at(0).length() > 0) {
+            IFOKDO(err,
+                   m_document->executeSqliteOrder(QStringLiteral("DELETE FROM bank where id in (select id from v_bank_amount where id not in (")
+                                                  % listBanks.at(1).at(0) % QStringLiteral(") and f_CURRENTAMOUNT=0)")));
+        }
+
+        IFOKDO(err, m_document->stepForward(4))
     }
 
     return err;
@@ -890,7 +914,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int &oNbOperationsMerged,
 
     // Begin transaction
     if (m_document != nullptr) {
-        err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Find and group transfers"), 3);
+        err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Find and group transfers"), 4);
         IFOK(err)
         {
             IFOKDO(err, m_document->executeSqliteOrder(QStringLiteral("ANALYZE")))
@@ -937,6 +961,24 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int &oNbOperationsMerged,
                 listTmp += listTmp2;
             }
 
+            {
+                SKGTRACEIN(2, "SKGImportExportManager::findAndGroupTransfers-step 3")
+                // +A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
+                IFOKDO(
+                    err,
+                    m_document->executeSelectSqliteOrder("SELECT A.id, B.id FROM v_operation A, operation B "
+                                                         "WHERE A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND A.rc_unit_id!=B.rc_unit_id AND "
+                                                         "A.t_comment!='' AND A.t_comment=B.t_comment AND "
+                                                         "+A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0"
+                                                             % (iAdditionnalCondition.isEmpty() ? QString() : QStringLiteral(" AND ") % iAdditionnalCondition),
+                                                         listTmp2));
+
+                // Step 3 done
+                IFOKDO(err, m_document->stepForward(3))
+                listTmp2.removeAt(0); // Remove header
+                listTmp += listTmp2;
+            }
+
             // Group
             {
                 SKGTRACEIN(2, "SKGImportExportManager::findAndGroupTransfers-group")
@@ -957,7 +999,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int &oNbOperationsMerged,
             oNbOperationsMerged = (oNbOperationsMerged - 1) * 2;
 
             // Step 3 done
-            IFOKDO(err, m_document->stepForward(3))
+            IFOKDO(err, m_document->stepForward(4))
         }
         SKGENDTRANSACTION(m_document, err)
     }
