@@ -4,16 +4,15 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
-* This file is a plugin interface default implementation.
-*
-* @author Stephane MANKOWSKI / Guillaume DE BURE
+ * This file is a plugin interface default implementation.
+ *
+ * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportplugin.h"
 
-SKGImportPlugin::SKGImportPlugin(QObject* iImporter)
-    : QObject(), m_importer(qobject_cast< SKGImportExportManager * >(iImporter))
-{}
-SKGImportPlugin::~SKGImportPlugin()
-    = default;
-
-
+SKGImportPlugin::SKGImportPlugin(QObject *iImporter)
+    : QObject()
+    , m_importer(qobject_cast<SKGImportExportManager *>(iImporter))
+{
+}
+SKGImportPlugin::~SKGImportPlugin() = default;
