@@ -27,14 +27,15 @@ public:
     /**
      * This enumerate defines how to compute value date
      */
-    enum ValueDateMode {FIFTEEN = 0,
-                        J0,
-                        J1,
-                        J2,
-                        J3,
-                        J4,
-                        J5
-                       };
+    enum ValueDateMode {
+        FIFTEEN = 0,
+        J0,
+        J1,
+        J2,
+        J3,
+        J4,
+        J5
+    };
     /**
      * This enumerate defines how to compute value date
      */
@@ -43,10 +44,11 @@ public:
     /**
      * This enumerate defines how to compute interest
      */
-    enum InterestMode {FIFTEEN24 = 0,
-                       DAYS360,
-                       DAYS365
-                      };
+    enum InterestMode {
+        FIFTEEN24 = 0,
+        DAYS360,
+        DAYS365
+    };
     /**
      * This enumerate defines how to compute interest
      */
@@ -62,31 +64,31 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGInterestObject(SKGDocument* iDocument, int iID = 0);
+    explicit SKGInterestObject(SKGDocument *iDocument, int iID = 0);
 
     /**
      * Copy constructor
      * @param iObject the object to copy
      */
-    SKGInterestObject(const SKGInterestObject& iObject);
+    SKGInterestObject(const SKGInterestObject &iObject);
 
     /**
      * Copy constructor
      * @param iObject the object to copy
      */
-    explicit SKGInterestObject(const SKGObjectBase& iObject);
+    explicit SKGInterestObject(const SKGObjectBase &iObject);
 
     /**
      * Operator affectation
      * @param iObject the object to copy
      */
-    SKGInterestObject& operator= (const SKGObjectBase& iObject);
+    SKGInterestObject &operator=(const SKGObjectBase &iObject);
 
     /**
      * Operator affectation
      * @param iObject the object to copy
      */
-    SKGInterestObject& operator= (const SKGInterestObject& iObject);
+    SKGInterestObject &operator=(const SKGInterestObject &iObject);
 
     /**
      * Destructor
@@ -99,7 +101,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError getAccount(SKGAccountObject& oAccount) const;
+    SKGError getAccount(SKGAccountObject &oAccount) const;
 
     /**
      * Set the parent account
@@ -107,7 +109,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setAccount(const SKGAccountObject& iAccount);
+    SKGError setAccount(const SKGAccountObject &iAccount);
 
     /**
      * Set the quantity for the date of this unit
