@@ -432,7 +432,7 @@ SKGError SKGOperationObject::getSubOperations(SKGListSKGObjectBase &oSubOperatio
                              QStringLiteral("SKGOperationObject::getSubOperations")));
     } else {
         err = getDocument()->getObjects(QStringLiteral("v_suboperation"),
-                                        "rd_operation_id=" % SKGServices::intToString(getID()) % " ORDER BY i_order",
+                                        "rd_operation_id=" % SKGServices::intToString(getID()) % " ORDER BY i_order, id",
                                         oSubOperations);
     }
     return err;
