@@ -32,31 +32,31 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGPayeeObject(SKGDocument* iDocument, int iID = 0);
+    explicit SKGPayeeObject(SKGDocument *iDocument, int iID = 0);
 
     /**
      * Copy constructor
      * @param iObject the object to copy
      */
-    SKGPayeeObject(const SKGPayeeObject& iObject);
+    SKGPayeeObject(const SKGPayeeObject &iObject);
 
     /**
      * Copy constructor
      * @param iObject the object to copy
      */
-    explicit SKGPayeeObject(const SKGObjectBase& iObject);
+    explicit SKGPayeeObject(const SKGObjectBase &iObject);
 
     /**
      * Operator affectation
      * @param iObject the object to copy
      */
-    SKGPayeeObject& operator= (const SKGObjectBase& iObject);
+    SKGPayeeObject &operator=(const SKGObjectBase &iObject);
 
     /**
      * Operator affectation
      * @param iObject the object to copy
      */
-    SKGPayeeObject& operator= (const SKGPayeeObject& iObject);
+    SKGPayeeObject &operator=(const SKGPayeeObject &iObject);
 
     /**
      * Destructor
@@ -72,17 +72,14 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    static SKGError createPayee(SKGDocumentBank* iDocument,
-                                const QString& iName,
-                                SKGPayeeObject& oPayee,
-                                bool iSendPopupMessageOnCreation = false);
+    static SKGError createPayee(SKGDocumentBank *iDocument, const QString &iName, SKGPayeeObject &oPayee, bool iSendPopupMessageOnCreation = false);
     /**
      * Get all transactions of this payee
      * @param oOperations all transactions of this payee
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError getOperations(SKGListSKGObjectBase& oOperations) const;
+    SKGError getOperations(SKGListSKGObjectBase &oOperations) const;
 
     /**
      * Set the address of payee
@@ -90,7 +87,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setAddress(const QString& iAddress);
+    SKGError setAddress(const QString &iAddress);
 
     /**
      * Get the address of this payee
@@ -134,7 +131,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setCategory(const SKGCategoryObject& iCategory);
+    SKGError setCategory(const SKGCategoryObject &iCategory);
 
     /**
      * Get the category
@@ -142,7 +139,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError getCategory(SKGCategoryObject& oCategory) const;
+    SKGError getCategory(SKGCategoryObject &oCategory) const;
 
     /**
      * Merge iPayee in current payee
@@ -150,7 +147,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError merge(const SKGPayeeObject& iPayee);
+    SKGError merge(const SKGPayeeObject &iPayee);
 };
 /**
  * Declare the class
