@@ -29,13 +29,14 @@ public:
     /**
      * This enumerate defines type of units
      */
-    enum UnitType {PRIMARY,     /**< to define the main currency (only one)*/
-                   SECONDARY,   /**< to define the secondary currency (only one)*/
-                   CURRENCY,    /**< for currency: dollar, euro, yen, … */
-                   SHARE,       /**< for stock: Google, EDF, … */
-                   INDEX,       /**< for index: CAC 40, … */
-                   OBJECT       /**< for objects: cars, houses, … */
-                  };
+    enum UnitType {
+        PRIMARY, /**< to define the main currency (only one)*/
+        SECONDARY, /**< to define the secondary currency (only one)*/
+        CURRENCY, /**< for currency: dollar, euro, yen, … */
+        SHARE, /**< for stock: Google, EDF, … */
+        INDEX, /**< for index: CAC 40, … */
+        OBJECT /**< for objects: cars, houses, … */
+    };
     /**
      * This enumerate defines type of units
      */
@@ -44,30 +45,31 @@ public:
     /**
      * This enumerate defines the mode of download
      */
-    enum UnitDownloadMode {LAST,        /**< last value only*/
-                           LAST_MONTHLY,    /**< one value par month since last download*/
-                           LAST_WEEKLY,     /**< one value par week since last download*/
-                           LAST_DAILY,      /**< one value par day since last download*/
-                           ALL_MONTHLY,     /**< one value par month*/
-                           ALL_WEEKLY,      /**< one value par week*/
-                           ALL_DAILY        /**< one value par day*/
-                          };
+    enum UnitDownloadMode {
+        LAST, /**< last value only*/
+        LAST_MONTHLY, /**< one value par month since last download*/
+        LAST_WEEKLY, /**< one value par week since last download*/
+        LAST_DAILY, /**< one value par day since last download*/
+        ALL_MONTHLY, /**< one value par month*/
+        ALL_WEEKLY, /**< one value par week*/
+        ALL_DAILY /**< one value par day*/
+    };
     /**
      * This enumerate defines the mode of download
      */
     Q_ENUM(UnitDownloadMode)
 
     /**
-    * Default constructor
-    */
+     * Default constructor
+     */
     explicit SKGUnitObject();
 
     /**
-    * Constructor
-    * @param iDocument the document containing the object
-    * @param iID the identifier in @p iTable of the object
-    */
-    explicit SKGUnitObject(SKGDocument* iDocument, int iID = 0);
+     * Constructor
+     * @param iDocument the document containing the object
+     * @param iID the identifier in @p iTable of the object
+     */
+    explicit SKGUnitObject(SKGDocument *iDocument, int iID = 0);
 
     /**
      * Destructor
@@ -78,31 +80,31 @@ public:
      * Copy constructor
      * @param iObject the object to copy
      */
-    SKGUnitObject(const SKGUnitObject& iObject);
+    SKGUnitObject(const SKGUnitObject &iObject);
 
     /**
      * Copy constructor
      * @param iObject the object to copy
      */
-    explicit SKGUnitObject(const SKGNamedObject& iObject);
+    explicit SKGUnitObject(const SKGNamedObject &iObject);
 
     /**
      * Copy constructor
      * @param iObject the object to copy
      */
-    explicit SKGUnitObject(const SKGObjectBase& iObject);
+    explicit SKGUnitObject(const SKGObjectBase &iObject);
 
     /**
      * Operator affectation
      * @param iObject the object to copy
      */
-    SKGUnitObject& operator= (const SKGObjectBase& iObject);
+    SKGUnitObject &operator=(const SKGObjectBase &iObject);
 
     /**
      * Operator affectation
      * @param iObject the object to copy
      */
-    SKGUnitObject& operator= (const SKGUnitObject& iObject);
+    SKGUnitObject &operator=(const SKGUnitObject &iObject);
 
     /**
      * Get unit information
@@ -117,7 +119,7 @@ public:
      * @return the unit information
      *   @see SKGUnitInfo
      */
-    static SKGServices::SKGUnitInfo getUnitInfo(const QString& iUnitName);
+    static SKGServices::SKGUnitInfo getUnitInfo(const QString &iUnitName);
 
     /**
      * Create an existing currency unit
@@ -127,7 +129,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    static SKGError createCurrencyUnit(SKGDocumentBank* iDocument, const QString& iUnitName, SKGUnitObject& oUnit);
+    static SKGError createCurrencyUnit(SKGDocumentBank *iDocument, const QString &iUnitName, SKGUnitObject &oUnit);
 
     /**
      * Return the list of known currencies.
@@ -141,7 +143,7 @@ public:
      * @param iUnitName the currency unit name (nls)
      * @return the International code
      */
-    static QString getInternationalCode(const QString& iUnitName);
+    static QString getInternationalCode(const QString &iUnitName);
 
     /**
      * Convert a value from one unit to another one
@@ -152,7 +154,7 @@ public:
      * @return Value in target unit
      */
     // cppcheck-suppress passedByValue
-    static double convert(double iValue, const SKGUnitObject& iUnitFrom, const SKGUnitObject& iUnitTo, QDate iDate = QDate::currentDate());
+    static double convert(double iValue, const SKGUnitObject &iUnitFrom, const SKGUnitObject &iUnitTo, QDate iDate = QDate::currentDate());
 
     /**
      * Set the symbol of this unit
@@ -160,7 +162,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setSymbol(const QString& iSymbol);
+    SKGError setSymbol(const QString &iSymbol);
 
     /**
      * Get the symbol of this unit
@@ -174,7 +176,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setDownloadSource(const QString& iSource);
+    SKGError setDownloadSource(const QString &iSource);
 
     /**
      * Get the download source of this unit
@@ -202,7 +204,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setCountry(const QString& iCountry);
+    SKGError setCountry(const QString &iCountry);
 
     /**
      * Get the country of this unit
@@ -216,7 +218,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setInternetCode(const QString& iCode);
+    SKGError setInternetCode(const QString &iCode);
 
     /**
      * Get the Internet code of this unit
@@ -244,7 +246,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError addUnitValue(SKGUnitValueObject& oUnitValue);
+    SKGError addUnitValue(SKGUnitValueObject &oUnitValue);
 
     /**
      * Get unit values
@@ -252,7 +254,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError getUnitValues(SKGListSKGObjectBase& oUnitValueList) const;
+    SKGError getUnitValues(SKGListSKGObjectBase &oUnitValueList) const;
 
     /**
      * Get last unit value
@@ -260,7 +262,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError getLastUnitValue(SKGUnitValueObject& oUnitValue) const;
+    SKGError getLastUnitValue(SKGUnitValueObject &oUnitValue) const;
 
     /**
      * Get unit value at a date
@@ -270,7 +272,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    SKGError getUnitValue(QDate iDate, SKGUnitValueObject& oUnitValue) const;
+    SKGError getUnitValue(QDate iDate, SKGUnitValueObject &oUnitValue) const;
 
     /**
      * Download values
@@ -281,7 +283,6 @@ public:
      */
     SKGError downloadUnitValue(UnitDownloadMode iMode = LAST, int iNbMaxValues = 50);
 
-
     /**
      * Open the URL where the values are downloaded
      * @return an object managing the error
@@ -295,7 +296,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError getUrl(QUrl& oUrl) const;
+    SKGError getUrl(QUrl &oUrl) const;
 
     /**
      * Get the list of sources for the download
@@ -308,7 +309,7 @@ public:
      * @param iSource the source name (@see  downloadSources)
      * @return the comment/help
      */
-    static QString getCommentFromSource(const QString& iSource);
+    static QString getCommentFromSource(const QString &iSource);
 
     /**
      * Create a new source
@@ -317,14 +318,14 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    static SKGError addSource(const QString& iNewSource, bool iOpenSource = true);
+    static SKGError addSource(const QString &iNewSource, bool iOpenSource = true);
 
     /**
      * To know if a source can be modified or deleted
      * @param iSource the name of the source to modified or deleted
      * @return true or false
      */
-    static bool isWritable(const QString& iSource);
+    static bool isWritable(const QString &iSource);
 
     /**
      * Delete a new source
@@ -332,7 +333,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    static SKGError deleteSource(const QString& iSource);
+    static SKGError deleteSource(const QString &iSource);
 
     /**
      * Get amount of the unit at a date
@@ -356,7 +357,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setUnit(const SKGUnitObject& iUnit);
+    SKGError setUnit(const SKGUnitObject &iUnit);
 
     /**
      * Remove the unit
@@ -371,7 +372,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError getUnit(SKGUnitObject& oUnit) const;
+    SKGError getUnit(SKGUnitObject &oUnit) const;
 
     /**
      * Split unit.
@@ -389,7 +390,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError getOperations(SKGListSKGObjectBase& oOperations) const;
+    SKGError getOperations(SKGListSKGObjectBase &oOperations) const;
 
     /**
      * Merge iUnit in current unit
@@ -397,7 +398,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError merge(const SKGUnitObject& iUnit);
+    SKGError merge(const SKGUnitObject &iUnit);
 
     /**
      * Remove all unit values not relevant.
