@@ -14,11 +14,7 @@
 
 #include <qcompleter.h>
 #include <qevent.h>
-#ifdef SKG_QT6
 #include <qjsengine.h>
-#else
-#include <qscriptengine.h>
-#endif
 #include <qstringlistmodel.h>
 #include <qvalidator.h>
 
@@ -26,15 +22,17 @@
 #include "skgtraces.h"
 #include <utility>
 
-SKGCalculatorEdit::SKGCalculatorEdit(QWidget* iParent)
-    : QLineEdit(iParent), m_lastValue(0), m_lastOperator(0), m_currentMode(EXPRESSION)
+SKGCalculatorEdit::SKGCalculatorEdit(QWidget *iParent)
+    : QLineEdit(iParent)
+    , m_lastValue(0)
+    , m_lastOperator(0)
+    , m_currentMode(EXPRESSION)
 {
     setMode(CALCULATOR);
     m_fontColor = palette().color(QPalette::Text);
 }
 
-SKGCalculatorEdit::~SKGCalculatorEdit()
-    = default;
+SKGCalculatorEdit::~SKGCalculatorEdit() = default;
 
 double SKGCalculatorEdit::value()
 {
@@ -79,7 +77,7 @@ void SKGCalculatorEdit::setValue(double iValue)
     setText(SKGServices::doubleToString(iValue));
 }
 
-void SKGCalculatorEdit::setText(const QString& iText)
+void SKGCalculatorEdit::setText(const QString &iText)
 {
     // Set default color
     QPalette field_palette = palette();
@@ -115,14 +113,14 @@ QString SKGCalculatorEdit::formula()
     return m_formula;
 }
 
-void SKGCalculatorEdit::addParameterValue(const QString& iParameter, double iValue)
+void SKGCalculatorEdit::addParameterValue(const QString &iParameter, double iValue)
 {
     m_parameters.insert(iParameter, iValue);
     QStringList list;
     auto keys = m_parameters.keys();
     list.reserve(keys.count());
-    for (const auto& a : std::as_const(keys)) {
-        list.append(QLatin1Char('=') % a);
+    for (const auto &a : std::as_const(keys)) {
+        list.append(u'=' % a);
     }
 
     // Refresh completion
@@ -132,14 +130,16 @@ void SKGCalculatorEdit::addParameterValue(const QString& iParameter, double iVal
     setCompleter(comp);
 }
 
-void SKGCalculatorEdit::keyPressEvent(QKeyEvent* iEvent)
+void SKGCalculatorEdit::keyPressEvent(QKeyEvent *iEvent)
 {
     if (iEvent != nullptr) {
         int key = iEvent->key();
         if (mode() == CALCULATOR) {
             bool hasText = !text().isEmpty() && selectedText() != text();
 
-            if (iEvent->count() == 1 && ((key == Qt::Key_Plus && hasText) || (key == Qt::Key_Minus && hasText) || key == Qt::Key_Asterisk || key == Qt::Key_Slash || key == Qt::Key_Return || key == Qt::Key_Enter)) {
+            if (iEvent->count() == 1
+                && ((key == Qt::Key_Plus && hasText) || (key == Qt::Key_Minus && hasText) || key == Qt::Key_Asterisk || key == Qt::Key_Slash
+                    || key == Qt::Key_Return || key == Qt::Key_Enter)) {
                 keyPressEvent(key);
                 iEvent->accept();
             } else {
@@ -157,7 +157,7 @@ void SKGCalculatorEdit::keyPressEvent(QKeyEvent* iEvent)
     }
 }
 
-void SKGCalculatorEdit::focusOutEvent(QFocusEvent* iEvent)
+void SKGCalculatorEdit::focusOutEvent(QFocusEvent *iEvent)
 {
     if (iEvent->reason() != Qt::ActiveWindowFocusReason) {
         keyPressEvent(Qt::Key_Return);
@@ -192,7 +192,7 @@ void SKGCalculatorEdit::keyPressEvent(int key)
             m_lastValue = 0;
         } else {
             m_lastOperator = key;
-            QLineEdit::setText(QLatin1String(""));
+            QLineEdit::setText(QString());
         }
     } else {
         if (key == Qt::Key_Return || key == Qt::Key_Enter) {
@@ -211,7 +211,7 @@ void SKGCalculatorEdit::keyPressEvent(int key)
     }
 }
 
-double SKGCalculatorEdit::getEvaluatedValue(bool& iOk)
+double SKGCalculatorEdit::getEvaluatedValue(bool &iOk)
 {
     double output = 0;
     iOk = false;
@@ -219,10 +219,10 @@ double SKGCalculatorEdit::getEvaluatedValue(bool& iOk)
     QString t = text().trimmed();
     if (!t.isEmpty()) {
         m_formula = t;
-        t = t.replace(',', QLatin1Char('.'));  // Replace comma by a point in case of typo
-        t = t.remove(' ');  // Remove space to support this kind of values 3 024,25
+        t = t.replace(',', u'.'); // Replace comma by a point in case of typo
+        t = t.remove(' '); // Remove space to support this kind of values 3 024,25
         if (!QLocale().groupSeparator().isNull()) {
-            t = t.replace(QLocale().groupSeparator(), QLatin1String("."));
+            t = t.replace(QLocale().groupSeparator(), QStringLiteral("."));
         }
 
         // Remove double . in numbers
@@ -242,7 +242,7 @@ double SKGCalculatorEdit::getEvaluatedValue(bool& iOk)
                 toRemoveIndex = -1;
             }
         }
-        if (t.startsWith(QLatin1String("="))) {
+        if (t.startsWith(QStringLiteral("="))) {
             t = t.right(t.length() - 1);
             QMapIterator<QString, double> i(m_parameters);
             while (i.hasNext()) {
@@ -251,14 +251,10 @@ double SKGCalculatorEdit::getEvaluatedValue(bool& iOk)
             }
 
         } else {
-            m_formula = QLatin1String("");
+            m_formula = QString();
         }
 
-#ifdef SKG_QT6
         QJSEngine myEngine;
-#else
-        QScriptEngine myEngine;
-#endif
         const auto result = myEngine.evaluate(t);
         if (result.isNumber()) {
             output = result.toNumber();
@@ -267,6 +263,3 @@ double SKGCalculatorEdit::getEvaluatedValue(bool& iOk)
     }
     return output;
 }
-
-
-
