@@ -12,20 +12,19 @@
 
 #include <qlineedit.h>
 
-SKGComboBox::SKGComboBox(QWidget* iParent)
+SKGComboBox::SKGComboBox(QWidget *iParent)
     : KComboBox(iParent)
 {
 }
 
-SKGComboBox::~SKGComboBox()
-    = default;
+SKGComboBox::~SKGComboBox() = default;
 
 QString SKGComboBox::text() const
 {
     return currentText();
 }
 
-void SKGComboBox::setText(const QString& iText)
+void SKGComboBox::setText(const QString &iText)
 {
     int pos2 = findText(iText);
     if (pos2 == -1) {
@@ -35,9 +34,8 @@ void SKGComboBox::setText(const QString& iText)
     setCurrentIndex(pos2);
 }
 
-void SKGComboBox::setPalette(const QPalette& iPalette)
+void SKGComboBox::setPalette(const QPalette &iPalette)
 {
     KComboBox::setPalette(iPalette);
     lineEdit()->setPalette(iPalette);
 }
-
