@@ -28,10 +28,11 @@ public:
     /**
      * Mode of the editor
      */
-    enum Mode {PREVIOUS,   /**< if date is incompleted, the previous one is selected */
-               CURRENT,    /**< if date is incomplete, the current month is selected */
-               NEXT        /**< if date is incomplete, the next one is selected */
-              };
+    enum Mode {
+        PREVIOUS, /**< if date is incompleted, the previous one is selected */
+        CURRENT, /**< if date is incomplete, the current month is selected */
+        NEXT /**< if date is incomplete, the next one is selected */
+    };
     /**
      * Mode of the editor
      */
@@ -42,7 +43,7 @@ public:
      * @param iParent the parent
      * @param name name
      */
-    explicit SKGDateEdit(QWidget* iParent, const char* name = nullptr);
+    explicit SKGDateEdit(QWidget *iParent, const char *name = nullptr);
 
     /**
      * Destructor
