@@ -55,11 +55,7 @@ public:
      * Set horizontal and vertical spacing
      * @param space the space
      */
-#ifdef SKG_QT6
     virtual void setSpacing(int space) override;
-#else
-    virtual void setSpacing(int space);
-#endif
 
     /**
      * Get horizontal spacing
