@@ -28,8 +28,10 @@
 #include "skgservices.h"
 #include "skgtraces.h"
 
-SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
-    : QWidget(iParent), m_oscale(1), m_toolBarVisible(true)
+SKGGraphicsView::SKGGraphicsView(QWidget *iParent)
+    : QWidget(iParent)
+    , m_oscale(1)
+    , m_toolBarVisible(true)
 {
     ui.setupUi(this);
     setAntialiasing(true);
@@ -40,8 +42,8 @@ SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
     graphicsView()->installEventFilter(this);
 
     // Set icons
-    ui.kPrint->setIcon(SKGServices::fromTheme(QLatin1String("printer")));
-    ui.kCopy->setIcon(SKGServices::fromTheme(QLatin1String("edit-copy")));
+    ui.kPrint->setIcon(SKGServices::fromTheme(QStringLiteral("printer")));
+    ui.kCopy->setIcon(SKGServices::fromTheme(QStringLiteral("edit-copy")));
 
     // Build contextual menu
     graphicsView()->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -57,14 +59,14 @@ SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
     zoomWidget->setDefaultWidget(zoomMenu);
     m_mainMenu->addAction(zoomWidget);
 
-    connect(zoomMenu, &SKGZoomSelector::changed, this, [ = ](int val) {
+    connect(zoomMenu, &SKGZoomSelector::changed, this, [this](int val) {
         ui.kZoom->setValue(val);
     });
-    connect(ui.kZoom, &SKGZoomSelector::changed, this, [ = ](int val) {
+    connect(ui.kZoom, &SKGZoomSelector::changed, this, [zoomMenu](int val) {
         zoomMenu->setValue(val);
     });
 
-    m_actShowToolBar = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("show-menu")), i18nc("Noun, user action", "Show tool bar"));
+    m_actShowToolBar = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("show-menu")), i18nc("Noun, user action", "Show tool bar"));
     if (m_actShowToolBar != nullptr) {
         m_actShowToolBar->setCheckable(true);
         m_actShowToolBar->setChecked(true);
@@ -73,13 +75,13 @@ SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
 
     m_mainMenu->addSeparator();
 
-    QAction* actCopy = m_mainMenu->addAction(ui.kCopy->icon(), ui.kCopy->toolTip());
+    QAction *actCopy = m_mainMenu->addAction(ui.kCopy->icon(), ui.kCopy->toolTip());
     connect(actCopy, &QAction::triggered, this, &SKGGraphicsView::onCopy);
 
-    QAction* actPrint = m_mainMenu->addAction(ui.kPrint->icon(), ui.kPrint->toolTip());
+    QAction *actPrint = m_mainMenu->addAction(ui.kPrint->icon(), ui.kPrint->toolTip());
     connect(actPrint, &QAction::triggered, this, &SKGGraphicsView::onPrint);
 
-    QAction* actExport = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("document-export")), i18nc("Noun, user action", "Export…"));
+    QAction *actExport = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Noun, user action", "Export…"));
     connect(actExport, &QAction::triggered, this, &SKGGraphicsView::onExport);
 
     connect(graphicsView(), &QHeaderView::customContextMenuRequested, this, &SKGGraphicsView::showMenu);
@@ -101,7 +103,7 @@ SKGGraphicsView::~SKGGraphicsView()
     m_actAntialiasing = nullptr;
 }
 
-void SKGGraphicsView::setScene(QGraphicsScene* iScene)
+void SKGGraphicsView::setScene(QGraphicsScene *iScene)
 {
     graphicsView()->setScene(iScene);
     if (iScene != nullptr) {
@@ -110,7 +112,7 @@ void SKGGraphicsView::setScene(QGraphicsScene* iScene)
     onZoom();
 }
 
-QGraphicsView* SKGGraphicsView::graphicsView()
+QGraphicsView *SKGGraphicsView::graphicsView()
 {
     return ui.kGraphicsView;
 }
@@ -118,25 +120,25 @@ QGraphicsView* SKGGraphicsView::graphicsView()
 QString SKGGraphicsView::getState() const
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QLatin1String("SKGML"));
-    QDomElement root = doc.createElement(QLatin1String("parameters"));
+    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomElement root = doc.createElement(QStringLiteral("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QLatin1String("isToolBarVisible"), isToolBarVisible() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QStringLiteral("isToolBarVisible"), isToolBarVisible() ? QStringLiteral("Y") : QStringLiteral("N"));
 
     return doc.toString();
 }
 
-void SKGGraphicsView::setState(const QString& iState)
+void SKGGraphicsView::setState(const QString &iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QLatin1String("SKGML"));
+    QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
-    setToolBarVisible(root.attribute(QLatin1String("isToolBarVisible")) != QLatin1String("N"));
+    setToolBarVisible(root.attribute(QStringLiteral("isToolBarVisible")) != QStringLiteral("N"));
 }
 
-QMenu* SKGGraphicsView::getContextualMenu() const
+QMenu *SKGGraphicsView::getContextualMenu() const
 {
     return m_mainMenu;
 }
@@ -165,7 +167,7 @@ bool SKGGraphicsView::isToolBarVisible() const
     return m_toolBarVisible;
 }
 
-void SKGGraphicsView::addToolbarWidget(QWidget* iWidget)
+void SKGGraphicsView::addToolbarWidget(QWidget *iWidget)
 {
     ui.layout->insertWidget(3, iWidget);
 }
@@ -180,11 +182,11 @@ void SKGGraphicsView::setAntialiasing(bool iAntialiasing)
     graphicsView()->setRenderHint(QPainter::Antialiasing, iAntialiasing);
 }
 
-bool SKGGraphicsView::eventFilter(QObject* iObject, QEvent* iEvent)
+bool SKGGraphicsView::eventFilter(QObject *iObject, QEvent *iEvent)
 {
     if (iObject == graphicsView()->scene() && (iEvent != nullptr) && iEvent->type() == QEvent::GraphicsSceneWheel) {
-        auto* e = dynamic_cast<QGraphicsSceneWheelEvent*>(iEvent);
-        if ((e != nullptr) && e->orientation() == Qt::Vertical && ((QApplication::keyboardModifiers() &Qt::ControlModifier) != 0u)) {
+        auto *e = dynamic_cast<QGraphicsSceneWheelEvent *>(iEvent);
+        if ((e != nullptr) && e->orientation() == Qt::Vertical && ((QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u)) {
             int numDegrees = e->delta() / 8;
             int numTicks = numDegrees / 15;
 
@@ -241,7 +243,10 @@ void SKGGraphicsView::onPrint()
 void SKGGraphicsView::onExport()
 {
     _SKGTRACEINFUNC(10)
-    QString fileName = SKGMainPanel::getSaveFileName(QLatin1String("kfiledialog:///IMPEXP"), QLatin1String("application/pdf image/svg+xml image/png image/jpeg image/gif image/tiff"), this, nullptr);
+    QString fileName = SKGMainPanel::getSaveFileName(QStringLiteral("kfiledialog:///IMPEXP"),
+                                                     QStringLiteral("application/pdf image/svg+xml image/png image/jpeg image/gif image/tiff"),
+                                                     this,
+                                                     nullptr);
     if (fileName.isEmpty()) {
         return;
     }
@@ -251,17 +256,17 @@ void SKGGraphicsView::onExport()
     QDesktopServices::openUrl(QUrl(fileName));
 }
 
-void SKGGraphicsView::exportInFile(const QString& iFileName)
+void SKGGraphicsView::exportInFile(const QString &iFileName)
 {
     _SKGTRACEINFUNC(10)
     QString extension = QFileInfo(iFileName).suffix().toUpper();
-    if (extension == QLatin1String("PDF")) {
+    if (extension == QStringLiteral("PDF")) {
         QPrinter printer;
         printer.setOutputFileName(iFileName);
         QPainter painter(&printer);
         graphicsView()->render(&painter);
         painter.end();
-    } else if (extension == QLatin1String("SVG")) {
+    } else if (extension == QStringLiteral("SVG")) {
         QSvgGenerator generator;
         generator.setFileName(iFileName);
         generator.setSize(QSize(200, 200));
@@ -284,7 +289,7 @@ void SKGGraphicsView::exportInFile(const QString& iFileName)
 void SKGGraphicsView::onCopy()
 {
     _SKGTRACEINFUNC(10)
-    QClipboard* clipboard = QApplication::clipboard();
+    QClipboard *clipboard = QApplication::clipboard();
     if (clipboard != nullptr) {
         QImage image(graphicsView()->size(), QImage::Format_ARGB32);
         QPainter painter(&image);
@@ -293,5 +298,3 @@ void SKGGraphicsView::onCopy()
         clipboard->setImage(image);
     }
 }
-
-
