@@ -15,7 +15,7 @@
 
 #include "skgtraces.h"
 
-SKGMenuitem::SKGMenuitem(QWidget* iParent)
+SKGMenuitem::SKGMenuitem(QWidget *iParent)
     : QWidget(iParent)
 {
     SKGTRACEINFUNC(5);
@@ -23,17 +23,14 @@ SKGMenuitem::SKGMenuitem(QWidget* iParent)
     setMouseTracking(true);
 }
 
-SKGMenuitem::~SKGMenuitem()
-{
-    SKGTRACEINFUNC(5)
-}
+SKGMenuitem::~SKGMenuitem(){SKGTRACEINFUNC(5)}
 
 QString SKGMenuitem::getText() const
 {
     return m_text;
 }
 
-void SKGMenuitem::setText(const QString& iText)
+void SKGMenuitem::setText(const QString &iText)
 {
     if (m_text == iText) {
         return;
@@ -51,7 +48,7 @@ QIcon SKGMenuitem::getIcon() const
     return m_icon;
 }
 
-void SKGMenuitem::setIcon(const QIcon& iIcon)
+void SKGMenuitem::setIcon(const QIcon &iIcon)
 {
     m_icon = iIcon;
 
@@ -65,7 +62,7 @@ QColor SKGMenuitem::getColor() const
     return m_color;
 }
 
-void SKGMenuitem::setColor(const QColor& iColor)
+void SKGMenuitem::setColor(const QColor &iColor)
 {
     if (m_color == iColor) {
         return;
@@ -101,11 +98,11 @@ QSize SKGMenuitem::minimumSizeHint() const
     QStyleOptionMenuItem opt;
     initStyleOption(&opt);
 
-    QSize contentSize = fontMetrics().size(Qt::TextSingleLine/* | Qt::TextShowMnemonic*/, m_text);
+    QSize contentSize = fontMetrics().size(Qt::TextSingleLine /* | Qt::TextShowMnemonic*/, m_text);
     return style()->sizeFromContents(QStyle::CT_MenuItem, &opt, contentSize, this);
 }
 
-void SKGMenuitem::paintEvent(QPaintEvent* /*e*/)
+void SKGMenuitem::paintEvent(QPaintEvent * /*e*/)
 {
     QPainter p(this);
     QStyleOptionMenuItem opt;
@@ -114,13 +111,13 @@ void SKGMenuitem::paintEvent(QPaintEvent* /*e*/)
     style()->drawControl(QStyle::CE_MenuItem, &opt, &p, this);
 }
 
-void SKGMenuitem::initStyleOption(QStyleOptionMenuItem* option) const
+void SKGMenuitem::initStyleOption(QStyleOptionMenuItem *option) const
 {
     option->initFrom(this);
     option->text = m_text;
     option->menuHasCheckableItems = false;
     option->icon = m_icon;
-    option->maxIconWidth = style()->pixelMetric(QStyle::PM_SmallIconSize, option, this) + 4;    // Same as in QMenuPrivate
+    option->maxIconWidth = style()->pixelMetric(QStyle::PM_SmallIconSize, option, this) + 4; // Same as in QMenuPrivate
     option->menuItemType = QStyleOptionMenuItem::Normal;
     if (m_color.isValid()) {
         option->palette.setColor(QPalette::WindowText, m_color);
