@@ -338,71 +338,71 @@ void SKGObjectModelBase::refresh()
                     if (groupByDate) {
                         QDate date = SKGServices::stringToDate(att);
                         if (date == QDate::currentDate()) {
-                            att = i18nc("A group name for grouping by date attibute", "Today");
+                            att = i18nc("A group name for grouping by date attribute", "Today");
                         } else if (date > QDate::currentDate()) {
                             // In future
                             if (date < QDate::currentDate().addDays(7)) {
-                                att = i18nc("A group name for grouping by date attibute", "Next 7 days");
+                                att = i18nc("A group name for grouping by date attribute", "Next 7 days");
                             } else if (date < QDate::currentDate().addDays(15)) {
-                                att = i18nc("A group name for grouping by date attibute", "Next 15 days");
+                                att = i18nc("A group name for grouping by date attribute", "Next 15 days");
                             } else if (date < QDate::currentDate().addMonths(1)) {
-                                att = i18nc("A group name for grouping by date attibute", "Next month");
+                                att = i18nc("A group name for grouping by date attribute", "Next month");
                             } else if (date < QDate::currentDate().addMonths(3)) {
-                                att = i18nc("A group name for grouping by date attibute", "Next 3 months");
+                                att = i18nc("A group name for grouping by date attribute", "Next 3 months");
                             } else if (date < QDate::currentDate().addMonths(6)) {
-                                att = i18nc("A group name for grouping by date attibute", "Next 6 months");
+                                att = i18nc("A group name for grouping by date attribute", "Next 6 months");
                             } else if (date < QDate::currentDate().addYears(1)) {
-                                att = i18nc("A group name for grouping by date attibute", "Next year");
+                                att = i18nc("A group name for grouping by date attribute", "Next year");
                             } else if (date < QDate::currentDate().addYears(3)) {
-                                att = i18nc("A group name for grouping by date attibute", "Next 3 years");
+                                att = i18nc("A group name for grouping by date attribute", "Next 3 years");
                             } else {
-                                att = i18nc("A group name for grouping by date attibute", "Far away in the future");
+                                att = i18nc("A group name for grouping by date attribute", "Far away in the future");
                             }
                         } else {
                             // In the past
                             if (date > QDate::currentDate().addDays(-7)) {
-                                att = i18nc("A group name for grouping by date attibute", "Last 7 days");
+                                att = i18nc("A group name for grouping by date attribute", "Last 7 days");
                             } else if (date > QDate::currentDate().addDays(-15)) {
-                                att = i18nc("A group name for grouping by date attibute", "Last 15 days");
+                                att = i18nc("A group name for grouping by date attribute", "Last 15 days");
                             } else if (date > QDate::currentDate().addMonths(-1)) {
-                                att = i18nc("A group name for grouping by date attibute", "Last month");
+                                att = i18nc("A group name for grouping by date attribute", "Last month");
                             } else if (date > QDate::currentDate().addMonths(-3)) {
-                                att = i18nc("A group name for grouping by date attibute", "Last 3 months");
+                                att = i18nc("A group name for grouping by date attribute", "Last 3 months");
                             } else if (date > QDate::currentDate().addMonths(-6)) {
-                                att = i18nc("A group name for grouping by date attibute", "Last 6 months");
+                                att = i18nc("A group name for grouping by date attribute", "Last 6 months");
                             } else if (date > QDate::currentDate().addYears(-1)) {
-                                att = i18nc("A group name for grouping by date attibute", "Last year");
+                                att = i18nc("A group name for grouping by date attribute", "Last year");
                             } else if (date > QDate::currentDate().addYears(-3)) {
-                                att = i18nc("A group name for grouping by date attibute", "Last 3 years");
+                                att = i18nc("A group name for grouping by date attribute", "Last 3 years");
                             } else {
-                                att = i18nc("A group name for grouping by date attibute", "Far away in the past");
+                                att = i18nc("A group name for grouping by date attribute", "Far away in the past");
                             }
                         }
                     } else if (groupByNum) {
                         if (att != QChar(8734)) {
                             double d = SKGServices::stringToDouble(att);
                             if (d > 10000.0) {
-                                att = i18nc("A group name for grouping by numerical attibute", "> 10000");
+                                att = i18nc("A group name for grouping by numerical attribute", "> 10000");
                             } else if (d > 1000.0) {
-                                att = i18nc("A group name for grouping by numerical attibute", "> 1000");
+                                att = i18nc("A group name for grouping by numerical attribute", "> 1000");
                             } else if (d > 100.0) {
-                                att = i18nc("A group name for grouping by numerical attibute", "> 100");
+                                att = i18nc("A group name for grouping by numerical attribute", "> 100");
                             } else if (d > 10.0) {
-                                att = i18nc("A group name for grouping by numerical attibute", "> 10");
+                                att = i18nc("A group name for grouping by numerical attribute", "> 10");
                             } else if (d > 0.0) {
-                                att = i18nc("A group name for grouping by numerical attibute", "> 0");
+                                att = i18nc("A group name for grouping by numerical attribute", "> 0");
                             } else if (d < -10000.0) {
-                                att = i18nc("A group name for grouping by numerical attibute", "< -10000");
+                                att = i18nc("A group name for grouping by numerical attribute", "< -10000");
                             } else if (d < -1000.0) {
-                                att = i18nc("A group name for grouping by numerical attibute", "< -1000");
+                                att = i18nc("A group name for grouping by numerical attribute", "< -1000");
                             } else if (d < -100.0) {
-                                att = i18nc("A group name for grouping by numerical attibute", "< -100");
+                                att = i18nc("A group name for grouping by numerical attribute", "< -100");
                             } else if (d < -10.0) {
-                                att = i18nc("A group name for grouping by numerical attibute", "< -10");
+                                att = i18nc("A group name for grouping by numerical attribute", "< -10");
                             } else if (d < 0.0) {
-                                att = i18nc("A group name for grouping by numerical attibute", "< 0");
+                                att = i18nc("A group name for grouping by numerical attribute", "< 0");
                             } else {
-                                att = i18nc("A group name for grouping by numerical attibute", "= 0");
+                                att = i18nc("A group name for grouping by numerical attribute", "= 0");
                             }
                         }
                     }
