@@ -35,11 +35,11 @@ public:
      * @param iParentAttribute the attribute to find the parent of an object clause to find children
      * @param iResetOnCreation to reset data during creation
      */
-    SKGObjectModelBase(SKGDocument* iDocument,
-                       const QString& iTable,
-                       QString  iWhereClause,
-                       QWidget* iParent,
-                       QString  iParentAttribute = QString(),
+    SKGObjectModelBase(SKGDocument *iDocument,
+                       const QString &iTable,
+                       QString iWhereClause,
+                       QWidget *iParent,
+                       QString iParentAttribute = QString(),
                        bool iResetOnCreation = true);
 
     /**
@@ -65,14 +65,14 @@ public:
      * @param iParent the parent
      * @return true or false
      */
-    bool hasChildren(const QModelIndex& iParent = QModelIndex()) const override;
+    bool hasChildren(const QModelIndex &iParent = QModelIndex()) const override;
 
     /**
      * Returns the number of row for the given parent.
      * @param iParent the parent
      * @return the number of row
      */
-    int rowCount(const QModelIndex& iParent = QModelIndex()) const override;
+    int rowCount(const QModelIndex &iParent = QModelIndex()) const override;
 
     /**
      * Returns the index of the item in the model specified by the given row, column and parent index.
@@ -81,21 +81,21 @@ public:
      * @param iParent parent
      * @return the index
      */
-    QModelIndex index(int row, int column, const QModelIndex& iParent = QModelIndex()) const override;
+    QModelIndex index(int row, int column, const QModelIndex &iParent = QModelIndex()) const override;
 
     /**
      * Returns the parent of the model item with the given index, or QModelIndex() if it has no parent.
      * @param iIndex index
      * @return the parent
      */
-    QModelIndex parent(const QModelIndex& iIndex) const override;
+    QModelIndex parent(const QModelIndex &iIndex) const override;
 
     /**
      * Returns the number of columns for the given parent.
      * @param iParent the parent
      * @return the number of column
      */
-    int columnCount(const QModelIndex& iParent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &iParent = QModelIndex()) const override;
 
     /**
      * Returns the data stored under the given role for the item referred to by the index.
@@ -103,7 +103,7 @@ public:
      * @param iRole the role
      * @return the returned value
      */
-    QVariant data(const QModelIndex& iIndex, int iRole = Qt::DisplayRole) const override;
+    QVariant data(const QModelIndex &iIndex, int iRole = Qt::DisplayRole) const override;
 
     /**
      * Returns the data stored under the given role for the item referred to by the index.
@@ -111,21 +111,21 @@ public:
      * @param iRole the role
      * @return the returned value
      */
-    virtual QVariant computeData(const QModelIndex& iIndex, int iRole = Qt::DisplayRole) const;
+    virtual QVariant computeData(const QModelIndex &iIndex, int iRole = Qt::DisplayRole) const;
 
     /**
      * Returns the SKGObjectBase for the item referred to by the index.
      * @param iIndex the index
      * @return the returned SKGObjectBase
      */
-    virtual SKGObjectBase getObject(const QModelIndex& iIndex) const;
+    virtual SKGObjectBase getObject(const QModelIndex &iIndex) const;
 
     /**
      * Returns the SKGObjectBase for the item referred to by the index.
      * @param iIndex the index
      * @return the returned SKGObjectBase. Do not delete it !
      */
-    virtual SKGObjectBase* getObjectPointer(const QModelIndex& iIndex) const;
+    virtual SKGObjectBase *getObjectPointer(const QModelIndex &iIndex) const;
 
     /**
      * Returns the data for the given role and section in the header with the specified orientation.
@@ -141,7 +141,7 @@ public:
      * @param iIndex index of the object
      * @return flags of the given index
      */
-    Qt::ItemFlags flags(const QModelIndex& iIndex) const override;
+    Qt::ItemFlags flags(const QModelIndex &iIndex) const override;
 
     /**
      * Sets the role data for the item at index to value. Returns true if successful; otherwise returns false.
@@ -150,14 +150,14 @@ public:
      * @param iRole role
      * @return
      */
-    bool setData(const QModelIndex& iIndex, const QVariant& iValue, int iRole = Qt::EditRole) override;
+    bool setData(const QModelIndex &iIndex, const QVariant &iValue, int iRole = Qt::EditRole) override;
 
     /**
      * Return the index of the attribute, -1 if not found
      * @param iAttributeName the attribute name
      * @return index of this attribute
      */
-    virtual int getIndexAttribute(const QString& iAttributeName) const;
+    virtual int getIndexAttribute(const QString &iAttributeName) const;
 
     /**
      * Return the attribute for an index
@@ -177,7 +177,7 @@ public:
      * Set the table. Do not forget to do a reset after that.
      * @param iTable the table name
      */
-    void setTable(const QString& iTable);
+    void setTable(const QString &iTable);
 
     /**
      * Get table name
@@ -189,7 +189,7 @@ public:
      * Set the attribute used for grouping
      * @param iAttribute the attribute name
      */
-    virtual void setGroupBy(const QString& iAttribute = QString());
+    virtual void setGroupBy(const QString &iAttribute = QString());
 
     /**
      * Get the attribute used for grouping
@@ -219,21 +219,21 @@ public:
      * Get document
      * @return document
      */
-    virtual SKGDocument* getDocument() const;
+    virtual SKGDocument *getDocument() const;
 
     /**
      * Set the list of supported attributes. Do not forget to do a reset after that.
      * @param iListAttribute the list of attributes. If the list is empty then the default list is set.
      * The format of this string is the following one: attribute name[|visibility Y or N[|size]];attribute name[|visibility Y or N[|size]];…
      */
-    virtual void setSupportedAttributes(const QStringList& iListAttribute);
+    virtual void setSupportedAttributes(const QStringList &iListAttribute);
 
     /**
      * Set the filter. Do not forget to do a reset after that.
      * @param iWhereClause the where clause
      * @return true is the filter is really changed
      */
-    virtual bool setFilter(const QString& iWhereClause);
+    virtual bool setFilter(const QString &iWhereClause);
 
     /**
      * Returns the actions supported by the data in this model.
@@ -251,7 +251,7 @@ public:
      * Get list of supported schemas
      * @return list of schemas @see SKGModelTemplate
      */
-    virtual  SKGDocument::SKGModelTemplateList getSchemas() const;
+    virtual SKGDocument::SKGModelTemplateList getSchemas() const;
 
     /**
      * Returns a list of MIME types that can be used to describe a list of model indexes.
@@ -266,7 +266,7 @@ public:
      * @param iIndexes the index object
      * @return the mime data
      */
-    QMimeData* mimeData(const QModelIndexList& iIndexes) const override;
+    QMimeData *mimeData(const QModelIndexList &iIndexes) const override;
 
     /**
      * Handles the data supplied by a drag and drop transaction that ended with the given action.
@@ -280,10 +280,7 @@ public:
      * @param iParent parent
      * @return true if the dropping was successful otherwise false.
      */
-    bool dropMimeData(const QMimeData* iData,
-                      Qt::DropAction iAction,
-                      int iRow, int iColumn,
-                      const QModelIndex& iParent) override;
+    bool dropMimeData(const QMimeData *iData, Qt::DropAction iAction, int iRow, int iColumn, const QModelIndex &iParent) override;
 Q_SIGNALS:
     /**
      * Emitted before reset
@@ -307,7 +304,7 @@ public Q_SLOTS:
      * @param iIdTransaction the id of the transaction for direct modifications of the table (update of modify objects is enough)
      *or 0 in case of modifications by impact (full table must be refreshed)
      */
-    virtual void dataModified(const QString& iTableName = QString(), int iIdTransaction = 0);
+    virtual void dataModified(const QString &iTableName = QString(), int iIdTransaction = 0);
 
 protected Q_SLOTS:
     /**
@@ -339,7 +336,7 @@ protected:
     /**
      *A cache for value computed in data
      */
-    QMap<QString, QVariant>* m_cache;
+    QMap<QString, QVariant> *m_cache;
 
     /**
      * Get the attribute value for grouping
@@ -347,7 +344,7 @@ protected:
      * @param iAttribute the attribute name
      * @return the value of the attribute
      */
-    virtual QString getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const;
+    virtual QString getAttributeForGrouping(const SKGObjectBase &iObject, const QString &iAttribute) const;
 
     /**
      *The negative color
@@ -368,7 +365,7 @@ private:
     Q_DISABLE_COPY(SKGObjectModelBase)
     void clear();
 
-    SKGDocument* m_document;
+    SKGDocument *m_document;
     QString m_table;
     QString m_realTable;
     QString m_whereClause;
@@ -378,7 +375,7 @@ private:
     SKGObjectBase::SKGListSKGObjectBase m_listObjects;
     QHash<int, SKGIntList> m_parentChildRelations;
     QHash<int, int> m_childParentRelations;
-    QHash<int, SKGObjectBase*> m_objectsHashTable;
+    QHash<int, SKGObjectBase *> m_objectsHashTable;
     QHash<int, int> m_objectsHashTableRows;
 
     QStringList m_listSupported;
