@@ -48,7 +48,7 @@ SKGPeriodEdit::SKGPeriodEdit(QWidget *iParent, bool iModeEnabled)
     connect(ui.kDateEnd, &SKGDateEdit::dateEntered, this, &SKGPeriodEdit::refresh);
     connect(ui.kNbIntervals, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SKGPeriodEdit::refresh);
     connect(ui.kTimeline, &QSlider::valueChanged, this, &SKGPeriodEdit::refresh);
-    connect(ui.kFuture, &QCheckBox::stateChanged, this, &SKGPeriodEdit::refresh);
+    connect(ui.kFuture, &QCheckBox::checkStateChanged, this, &SKGPeriodEdit::refresh);
 }
 
 SKGPeriodEdit::~SKGPeriodEdit() = default;
@@ -466,13 +466,13 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString *oWhereClausForPre
         ui.kDateEnd->setDate(b);
         wc = sqlAttribute % " = (SELECT period(date('now', 'localtime'), " % strfFormat % "))";
         if (ui.kFuture->isChecked()) {
-            wc += QStringLiteral(" OR d_date > (SELECT date('now', 'localtime'))");
+            wc += QStringLiteral(" OR d_date > (date('now', 'localtime'))");
         }
         if (oWhereClausForPreviousData != nullptr) {
             *oWhereClausForPreviousData = sqlAttribute % " < (SELECT period(date('now', 'localtime'), " % strfFormat % "))";
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
+            *oWhereClausForForecastData = QStringLiteral("d_date > (date('now', 'localtime'))");
         }
         break;
     case PREVIOUS:
@@ -503,19 +503,19 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString *oWhereClausForPre
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
 
-        wc = "d_date >= (SELECT date('now', 'localtime','-" % SKGServices::intToString(val) % u' ' % sqlInterval % "', '+1 DAY'))";
+        wc = "d_date >= (date('now', 'localtime','-" % SKGServices::intToString(val) % u' ' % sqlInterval % "', '+1 DAY'))";
         if (iForecast) {
-            wc += QStringLiteral(" AND d_date<=(SELECT date('now', 'localtime'))"); // For forecast based on scheduled transactions
+            wc += QStringLiteral(" AND d_date<=(date('now', 'localtime'))"); // For forecast based on scheduled transactions
         }
 
         if (ui.kFuture->isChecked()) {
-            wc += QStringLiteral(" OR d_date > (SELECT date('now', 'localtime'))");
+            wc += QStringLiteral(" OR d_date > (date('now', 'localtime'))");
         }
         if (oWhereClausForPreviousData != nullptr) {
-            *oWhereClausForPreviousData = "d_date <= (SELECT date('now', 'localtime','-" % SKGServices::intToString(val) % u' ' % sqlInterval % "'))";
+            *oWhereClausForPreviousData = "d_date <= (date('now', 'localtime','-" % SKGServices::intToString(val) % u' ' % sqlInterval % "'))";
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
+            *oWhereClausForForecastData = QStringLiteral("d_date > (date('now', 'localtime'))");
         }
         break;
     case CUSTOM:
@@ -528,7 +528,7 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString *oWhereClausForPre
             *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % u'\'';
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
+            *oWhereClausForForecastData = QStringLiteral("d_date > (date('now', 'localtime'))");
         }
         break;
     case TIMELINE:
@@ -556,7 +556,7 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString *oWhereClausForPre
             *oWhereClausForPreviousData = QStringLiteral("1=0");
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
+            *oWhereClausForForecastData = QStringLiteral("d_date > (date('now', 'localtime'))");
         }
         break;
     }
