@@ -11,7 +11,7 @@
 #include "skgtableview.h"
 #include <qheaderview.h>
 
-SKGTableView::SKGTableView(QWidget* iParent)
+SKGTableView::SKGTableView(QWidget *iParent)
     : SKGTreeView(iParent)
 {
     this->setAllColumnsShowFocus(true);
@@ -20,7 +20,4 @@ SKGTableView::SKGTableView(QWidget* iParent)
     header()->setStretchLastSection(false);
 }
 
-SKGTableView::~SKGTableView()
-    = default;
-
-
+SKGTableView::~SKGTableView() = default;
