@@ -12,8 +12,6 @@
  */
 #include <qwidget.h>
 
-
-
 #include "skgbasegui_export.h"
 #include "skgcombobox.h"
 #include "skgservices.h"
@@ -36,17 +34,18 @@ public:
     /**
      * Graph type
      */
-    enum GraphType {STACK,
-                    HISTOGRAM,
-                    PIE,
-                    CONCENTRICPIE,
-                    POINT,
-                    LINE,
-                    STACKAREA,
-                    BUBBLE,
-                    STACKCOLUMNS,
-                    TREEMAP
-                   };
+    enum GraphType {
+        STACK,
+        HISTOGRAM,
+        PIE,
+        CONCENTRICPIE,
+        POINT,
+        LINE,
+        STACKAREA,
+        BUBBLE,
+        STACKCOLUMNS,
+        TREEMAP
+    };
     /**
      * Graph type
      */
@@ -55,12 +54,13 @@ public:
     /**
      * Additional information to display
      */
-    enum DisplayAdditional {NONE      = 0x0,
-                            SUM       = 0x1,
-                            AVERAGE   = 0x2,
-                            LIMITS    = 0x4,
-                            ALL       = 255
-                           };
+    enum DisplayAdditional {
+        NONE = 0x0,
+        SUM = 0x1,
+        AVERAGE = 0x2,
+        LIMITS = 0x4,
+        ALL = 255
+    };
     /**
      * Additional information to display
      */
@@ -96,7 +96,7 @@ public:
      * Constructor
      * @param iParent the parent
      */
-    explicit SKGTableWithGraph(QWidget* iParent);
+    explicit SKGTableWithGraph(QWidget *iParent);
 
     /**
      * Default Destructor
@@ -104,10 +104,10 @@ public:
     ~SKGTableWithGraph() override;
 
     /**
-    * Get the current state
-    * MUST BE OVERWRITTEN
-    * @return a string containing all information needed to set the same state.
-    * Could be an XML stream
+     * Get the current state
+     * MUST BE OVERWRITTEN
+     * @return a string containing all information needed to set the same state.
+     * Could be an XML stream
      */
     QString getState();
 
@@ -115,19 +115,19 @@ public:
      * Returns the table.
      * @return table
      */
-    QTableWidget* table() const;
+    QTableWidget *table() const;
 
     /**
      * Returns the graph.
      * @return graph
      */
-    SKGGraphicsView* graph() const;
+    SKGGraphicsView *graph() const;
 
     /**
      * Returns the text report.
      * @return text report
      */
-    SKGWebView* textReport() const;
+    SKGWebView *textReport() const;
 
     /**
      * Get the mode for the additional display
@@ -145,13 +145,13 @@ public:
      * Get a pointer on the contextual menu of the table
      * @return contextual menu
      */
-    QMenu* getTableContextualMenu() const;
+    QMenu *getTableContextualMenu() const;
 
     /**
      * Get a pointer on the contextual menu of the graph
      * @return contextual menu
      */
-    QMenu* getGraphContextualMenu() const;
+    QMenu *getGraphContextualMenu() const;
 
     /**
      * Get the visibility of the graph type selector zone
@@ -189,7 +189,7 @@ public:
      *
      * @return SKGShow*
      **/
-    SKGShow* getShowWidget() const;
+    SKGShow *getShowWidget() const;
 
     /**
      * To know if the table is visible
@@ -216,7 +216,7 @@ public Q_SLOTS:
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    void setState(const QString& iState);
+    void setState(const QString &iState);
 
     /**
      * Set Data
@@ -226,13 +226,12 @@ public Q_SLOTS:
      * @param iAdditionalInformation show sum and average columns
      * @param iNbVirtualColumn number of columns
      */
-    void setData(const SKGStringListList& iData,
-                 const SKGServices::SKGUnitInfo& iPrimaryUnit,
-                 const SKGServices::SKGUnitInfo& iSecondaryUnit,
+    void setData(const SKGStringListList &iData,
+                 const SKGServices::SKGUnitInfo &iPrimaryUnit,
+                 const SKGServices::SKGUnitInfo &iSecondaryUnit,
                  SKGTableWithGraph::DisplayAdditionalFlag iAdditionalInformation = SKGTableWithGraph::ALL,
                  int iNbVirtualColumn = 0);
 
-
     /**
      * Set the visibility of the graph type selector zone
      * @param iVisible the visibility
@@ -267,61 +266,61 @@ public Q_SLOTS:
      * Set the axis color
      * @param iColor the color
      */
-    void setAxisColor(const QColor& iColor = Qt::gray);
+    void setAxisColor(const QColor &iColor = Qt::gray);
 
     /**
      * Set the grid color
      * @param iColor the color
      */
-    void setGridColor(const QColor& iColor = Qt::lightGray);
+    void setGridColor(const QColor &iColor = Qt::lightGray);
 
     /**
      * Set the min color
      * @param iColor the color
      */
-    void setMinColor(const QColor& iColor = Qt::red);
+    void setMinColor(const QColor &iColor = Qt::red);
 
     /**
      * Set the max color
      * @param iColor the color
      */
-    void setMaxColor(const QColor& iColor = Qt::green);
+    void setMaxColor(const QColor &iColor = Qt::green);
 
     /**
      * Set the pareto color
      * @param iColor the color
      */
-    void setParetoColor(const QColor& iColor = Qt::darkRed);
+    void setParetoColor(const QColor &iColor = Qt::darkRed);
 
     /**
      * Set the average color
      * @param iColor the color
      */
-    void setAverageColor(const QColor& iColor = Qt::blue);
+    void setAverageColor(const QColor &iColor = Qt::blue);
 
     /**
      * Set the tendency color
      * @param iColor the color
      */
-    void setTendencyColor(const QColor& iColor = Qt::darkYellow);
+    void setTendencyColor(const QColor &iColor = Qt::darkYellow);
 
     /**
      * Set the outline color
      * @param iColor the color
      */
-    void setOutlineColor(const QColor& iColor = Qt::black);
+    void setOutlineColor(const QColor &iColor = Qt::black);
 
     /**
      * Set the background color
      * @param iColor the color
      */
-    void setBackgroundColor(const QColor& iColor = Qt::white);
+    void setBackgroundColor(const QColor &iColor = Qt::white);
 
     /**
      * Set the text color
      * @param iColor the color
      */
-    void setTextColor(const QColor& iColor = Qt::black);
+    void setTextColor(const QColor &iColor = Qt::black);
 
     /**
      * Set antialiasing
@@ -387,7 +386,7 @@ public Q_SLOTS:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError exportInFile(const QString& iFileName);
+    SKGError exportInFile(const QString &iFileName);
 
 Q_SIGNALS:
     /**
@@ -413,7 +412,7 @@ private Q_SLOTS:
     void onSelectionChangedInGraph();
     void onDoubleClick(int row, int column);
     void onDoubleClickGraph();
-    void onLinkClicked(const QUrl& url);
+    void onLinkClicked(const QUrl &url);
     void onFilterModified();
     void onDisplayModeChanged();
     void onChangeColor();
@@ -429,15 +428,15 @@ private:
     double computeStepSize(double iRange, double iTargetSteps);
     void addArrow(QPointF iPeak, double iSize, double iArrowAngle = 45, double iDegree = 90);
     void addLegend(QPointF iPosition, double iSize, double iScaleText, double iMaxY);
-    QGraphicsItem* drawPoint(qreal iX, qreal iY, qreal iRadius, int iMode, const QBrush& iBrush);
+    QGraphicsItem *drawPoint(qreal iX, qreal iY, qreal iRadius, int iMode, const QBrush &iBrush);
     int getAverageColumnIndex() const;
     int getMinColumnIndex() const;
 
-    QStringList getSumItems(const QString& iString) const;
-    void addSums(SKGStringListList& ioTable, int& iNblines);
+    QStringList getSumItems(const QString &iString) const;
+    void addSums(SKGStringListList &ioTable, int &iNblines);
 
     Ui::skgtablewithgraph_base ui{};
-    SKGGraphicsScene* m_scene;
+    SKGGraphicsScene *m_scene;
 
     SKGStringListList m_data;
     QList<bool> m_sumRows;
@@ -460,25 +459,25 @@ private:
     bool m_decimalsVisible;
     bool m_shadow;
 
-    QMenu* m_mainMenu;
+    QMenu *m_mainMenu;
     QTimer m_timer;
     QTimer m_timerRedraw;
-    QAction* m_actShowLimits;
-    QAction* m_actShowAverage;
-    QAction* m_actShowLinearRegression;
-    QAction* m_actShowPareto;
-    QAction* m_actShowLegend;
-    QAction* m_actShowZero;
-    QAction* m_actShowDecimal;
-    QAction* m_allPositiveMenu;
-    QWidgetAction* m_displayModeWidget{};
+    QAction *m_actShowLimits;
+    QAction *m_actShowAverage;
+    QAction *m_actShowLinearRegression;
+    QAction *m_actShowPareto;
+    QAction *m_actShowLegend;
+    QAction *m_actShowZero;
+    QAction *m_actShowDecimal;
+    QAction *m_allPositiveMenu;
+    QWidgetAction *m_displayModeWidget{};
 
     int m_indexSum;
     int m_indexAverage;
     int m_indexMin;
     int m_indexLinearRegression;
     QMap<QString, QColor> m_mapTitleColor;
-    QMap<QTableWidgetItem*, QGraphicsItem*> m_mapItemGraphic{};
+    QMap<QTableWidgetItem *, QGraphicsItem *> m_mapItemGraphic{};
 
     QColor m_axisColor;
     QColor m_backgroundColor;
@@ -493,7 +492,7 @@ private:
     QBrush m_NegativeColor;
     QBrush m_WhiteColor;
 
-    SKGComboBox* m_displayMode{};
+    SKGComboBox *m_displayMode{};
 
     Qt::SortOrder m_sortOrder;
     int m_sortColumn;
@@ -501,4 +500,4 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(SKGTableWithGraph::DisplayAdditionalFlag)
 
-#endif  // SKGTABLEWITHGRAPH_H
+#endif // SKGTABLEWITHGRAPH_H
