@@ -21,10 +21,8 @@
 #include <qtextdocumentwriter.h>
 #ifdef SKG_WEBENGINE
 #include <qwebenginepage.h>
-#ifdef SKG_QT6
 #include <qwebenginesettings.h>
 #endif
-#endif
 #include <qfileinfo.h>
 #include <qmath.h>
 #include <qpainter.h>
@@ -77,10 +75,8 @@ SKGWebView::SKGWebView(QWidget *iParent, const char *name, bool iWithContextualM
 {
     setObjectName(name);
     const auto &p = new SKGWebEnginePage(this);
-#ifdef SKG_QT6
     p->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, true);
     p->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, true);
-#endif
     setPage(p);
     if (m_ContextualMenu) {
         this->installEventFilter(this);
@@ -282,11 +278,7 @@ void SKGWebView::onPrintPreview()
 #ifdef SKG_WEBENGINE
     // TODO(SMI): QWebEngine
     connect(dialog.data(), &QPrintPreviewDialog::paintRequested, page(), [&](QPrinter *printer) {
-#ifdef SKG_QT6
         print(printer);
-#else
-        page()->print(printer, [](bool) {});
-#endif
     });
 #endif
     dialog->exec();
@@ -299,11 +291,7 @@ void SKGWebView::onPrint()
     if (dialog->exec() == QDialog::Accepted) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 #ifdef SKG_WEBENGINE
-#ifdef SKG_QT6
         print(&m_printer);
-#else
-        page()->print(&m_printer, [](bool) {});
-#endif
 #endif
         QApplication::restoreOverrideCursor();
     }
