@@ -10,18 +10,16 @@
  */
 #include "skgdateeditdesignerplugin.h"
 
-
-
 #include "skgdateedit.h"
 #include "skgservices.h"
 
-SKGDateEditDesignerPlugin::SKGDateEditDesignerPlugin(QObject* iParent)
+SKGDateEditDesignerPlugin::SKGDateEditDesignerPlugin(QObject *iParent)
     : QObject(iParent)
 {
     m_initialized = false;
 }
 
-void SKGDateEditDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
+void SKGDateEditDesignerPlugin::initialize(QDesignerFormEditorInterface *iCore)
 {
     Q_UNUSED(iCore)
     if (m_initialized) {
@@ -36,34 +34,34 @@ bool SKGDateEditDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGDateEditDesignerPlugin::createWidget(QWidget* iParent)
+QWidget *SKGDateEditDesignerPlugin::createWidget(QWidget *iParent)
 {
     return new SKGDateEdit(iParent);
 }
 
 QString SKGDateEditDesignerPlugin::name() const
 {
-    return QLatin1String("SKGDateEdit");
+    return QStringLiteral("SKGDateEdit");
 }
 
 QString SKGDateEditDesignerPlugin::group() const
 {
-    return QLatin1String("SKG Widgets");
+    return QStringLiteral("SKG Widgets");
 }
 
 QIcon SKGDateEditDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QLatin1String("quickopen"));
+    return SKGServices::fromTheme(QStringLiteral("quickopen"));
 }
 
 QString SKGDateEditDesignerPlugin::toolTip() const
 {
-    return QLatin1String("A date editor with more features");
+    return QStringLiteral("A date editor with more features");
 }
 
 QString SKGDateEditDesignerPlugin::whatsThis() const
 {
-    return QLatin1String("A date editor with more features");
+    return QStringLiteral("A date editor with more features");
 }
 
 bool SKGDateEditDesignerPlugin::isContainer() const
@@ -73,20 +71,20 @@ bool SKGDateEditDesignerPlugin::isContainer() const
 
 QString SKGDateEditDesignerPlugin::domXml() const
 {
-    return QLatin1String("<widget class=\"SKGDateEdit\" name=\"SKGDateEdit\">\n"
-                         " <property name=\"geometry\">\n"
-                         "  <rect>\n"
-                         "   <x>0</x>\n"
-                         "   <y>0</y>\n"
-                         "   <width>100</width>\n"
-                         "   <height>10</height>\n"
-                         "  </rect>\n"
-                         " </property>\n"
-                         "</widget>\n");
+    return QStringLiteral(
+        "<widget class=\"SKGDateEdit\" name=\"SKGDateEdit\">\n"
+        " <property name=\"geometry\">\n"
+        "  <rect>\n"
+        "   <x>0</x>\n"
+        "   <y>0</y>\n"
+        "   <width>100</width>\n"
+        "   <height>10</height>\n"
+        "  </rect>\n"
+        " </property>\n"
+        "</widget>\n");
 }
 
 QString SKGDateEditDesignerPlugin::includeFile() const
 {
-    return QLatin1String("skgdateedit.h");
+    return QStringLiteral("skgdateedit.h");
 }
-
