@@ -4,7 +4,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
- * A filetered SKGTableView (qt designer plugin).
+ * A filtered SKGTableView (qt designer plugin).
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -59,12 +59,12 @@ QIcon SKGFilteredTableViewDesignerPlugin::icon() const
 
 QString SKGFilteredTableViewDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A filetered SKGTableView");
+    return QStringLiteral("A filtered SKGTableView");
 }
 
 QString SKGFilteredTableViewDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A filetered SKGTableView");
+    return QStringLiteral("A filtered SKGTableView");
 }
 
 bool SKGFilteredTableViewDesignerPlugin::isContainer() const
