@@ -15,13 +15,13 @@
 #include "skgservices.h"
 #include "skgshow.h"
 
-SKGShowDesignerPlugin::SKGShowDesignerPlugin(QObject* iParent)
+SKGShowDesignerPlugin::SKGShowDesignerPlugin(QObject *iParent)
     : QObject(iParent)
 {
     m_initialized = false;
 }
 
-void SKGShowDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
+void SKGShowDesignerPlugin::initialize(QDesignerFormEditorInterface *iCore)
 {
     Q_UNUSED(iCore)
     if (m_initialized) {
@@ -36,34 +36,34 @@ bool SKGShowDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGShowDesignerPlugin::createWidget(QWidget* iParent)
+QWidget *SKGShowDesignerPlugin::createWidget(QWidget *iParent)
 {
     return new SKGShow(iParent);
 }
 
 QString SKGShowDesignerPlugin::name() const
 {
-    return QLatin1String("SKGShow");
+    return QStringLiteral("SKGShow");
 }
 
 QString SKGShowDesignerPlugin::group() const
 {
-    return QLatin1String("SKG Widgets");
+    return QStringLiteral("SKG Widgets");
 }
 
 QIcon SKGShowDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QLatin1String("quickopen"));
+    return SKGServices::fromTheme(QStringLiteral("quickopen"));
 }
 
 QString SKGShowDesignerPlugin::toolTip() const
 {
-    return QLatin1String("A widget to select what to show");
+    return QStringLiteral("A widget to select what to show");
 }
 
 QString SKGShowDesignerPlugin::whatsThis() const
 {
-    return QLatin1String("A widget to select what to show");
+    return QStringLiteral("A widget to select what to show");
 }
 
 bool SKGShowDesignerPlugin::isContainer() const
@@ -73,20 +73,20 @@ bool SKGShowDesignerPlugin::isContainer() const
 
 QString SKGShowDesignerPlugin::domXml() const
 {
-    return QLatin1String("<widget class=\"SKGShow\" name=\"SKGShow\">\n"
-                         " <property name=\"geometry\">\n"
-                         "  <rect>\n"
-                         "   <x>0</x>\n"
-                         "   <y>0</y>\n"
-                         "   <width>100</width>\n"
-                         "   <height>10</height>\n"
-                         "  </rect>\n"
-                         " </property>\n"
-                         "</widget>\n");
+    return QStringLiteral(
+        "<widget class=\"SKGShow\" name=\"SKGShow\">\n"
+        " <property name=\"geometry\">\n"
+        "  <rect>\n"
+        "   <x>0</x>\n"
+        "   <y>0</y>\n"
+        "   <width>100</width>\n"
+        "   <height>10</height>\n"
+        "  </rect>\n"
+        " </property>\n"
+        "</widget>\n");
 }
 
 QString SKGShowDesignerPlugin::includeFile() const
 {
-    return QLatin1String("skgshow.h");
+    return QStringLiteral("skgshow.h");
 }
-
