@@ -13,13 +13,13 @@
 #include "skgservices.h"
 #include "skgtablewidget.h"
 
-SKGTableWidgetDesignerPlugin::SKGTableWidgetDesignerPlugin(QObject* iParent)
+SKGTableWidgetDesignerPlugin::SKGTableWidgetDesignerPlugin(QObject *iParent)
     : QObject(iParent)
 {
     m_initialized = false;
 }
 
-void SKGTableWidgetDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
+void SKGTableWidgetDesignerPlugin::initialize(QDesignerFormEditorInterface *iCore)
 {
     Q_UNUSED(iCore)
     if (m_initialized) {
@@ -34,34 +34,34 @@ bool SKGTableWidgetDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGTableWidgetDesignerPlugin::createWidget(QWidget* iParent)
+QWidget *SKGTableWidgetDesignerPlugin::createWidget(QWidget *iParent)
 {
     return new SKGTableWidget(iParent);
 }
 
 QString SKGTableWidgetDesignerPlugin::name() const
 {
-    return QLatin1String("SKGTableWidget");
+    return QStringLiteral("SKGTableWidget");
 }
 
 QString SKGTableWidgetDesignerPlugin::group() const
 {
-    return QLatin1String("SKG Widgets");
+    return QStringLiteral("SKG Widgets");
 }
 
 QIcon SKGTableWidgetDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QLatin1String("quickopen"));
+    return SKGServices::fromTheme(QStringLiteral("quickopen"));
 }
 
 QString SKGTableWidgetDesignerPlugin::toolTip() const
 {
-    return QLatin1String("A table widget with more features");
+    return QStringLiteral("A table widget with more features");
 }
 
 QString SKGTableWidgetDesignerPlugin::whatsThis() const
 {
-    return QLatin1String("A table widget with more features");
+    return QStringLiteral("A table widget with more features");
 }
 
 bool SKGTableWidgetDesignerPlugin::isContainer() const
@@ -71,20 +71,20 @@ bool SKGTableWidgetDesignerPlugin::isContainer() const
 
 QString SKGTableWidgetDesignerPlugin::domXml() const
 {
-    return QLatin1String("<widget class=\"SKGTableWidget\" name=\"SKGTableWidget\">\n"
-                         " <property name=\"geometry\">\n"
-                         "  <rect>\n"
-                         "   <x>0</x>\n"
-                         "   <y>0</y>\n"
-                         "   <width>100</width>\n"
-                         "   <height>10</height>\n"
-                         "  </rect>\n"
-                         " </property>\n"
-                         "</widget>\n");
+    return QStringLiteral(
+        "<widget class=\"SKGTableWidget\" name=\"SKGTableWidget\">\n"
+        " <property name=\"geometry\">\n"
+        "  <rect>\n"
+        "   <x>0</x>\n"
+        "   <y>0</y>\n"
+        "   <width>100</width>\n"
+        "   <height>10</height>\n"
+        "  </rect>\n"
+        " </property>\n"
+        "</widget>\n");
 }
 
 QString SKGTableWidgetDesignerPlugin::includeFile() const
 {
-    return QLatin1String("skgtablewidget.h");
+    return QStringLiteral("skgtablewidget.h");
 }
-
