@@ -4,21 +4,28 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
-* This file implements classes SKGError.
-*
-* @author Stephane MANKOWSKI / Guillaume DE BURE
-*/
+ * This file implements classes SKGError.
+ *
+ * @author Stephane MANKOWSKI / Guillaume DE BURE
+ */
 #include "skgerror.h"
 
 SKGError::SKGError()
-    : m_message(QLatin1String("")), m_property(QLatin1String(""))
-{}
+    : m_message(QString())
+    , m_property(QString())
+{
+}
 
-SKGError::SKGError(int iRc, QString  iMessage, QString  iAction)
-    : m_rc(iRc), m_message(std::move(iMessage)),  m_property(QLatin1String("")), m_action(std::move(iAction)), m_previousError(nullptr)
-{}
+SKGError::SKGError(int iRc, QString iMessage, QString iAction)
+    : m_rc(iRc)
+    , m_message(std::move(iMessage))
+    , m_property(QString())
+    , m_action(std::move(iAction))
+    , m_previousError(nullptr)
+{
+}
 
-SKGError::SKGError(const SKGError& iError)
+SKGError::SKGError(const SKGError &iError)
 {
     m_rc = iError.m_rc;
     m_message = iError.m_message;
@@ -31,7 +38,7 @@ SKGError::SKGError(const SKGError& iError)
     }
 }
 
-SKGError::SKGError(SKGError&& iError) noexcept
+SKGError::SKGError(SKGError &&iError) noexcept
 {
     m_rc = iError.m_rc;
     m_message = iError.m_message;
@@ -47,7 +54,7 @@ SKGError::~SKGError()
     m_previousError = nullptr;
 }
 
-SKGError& SKGError::operator= (const SKGError& iError)
+SKGError &SKGError::operator=(const SKGError &iError)
 {
     if (Q_LIKELY(&iError != this)) {
         delete m_previousError;
@@ -94,13 +101,13 @@ int SKGError::getReturnCode() const
     return m_rc;
 }
 
-SKGError& SKGError::setReturnCode(int iReturnCode)
+SKGError &SKGError::setReturnCode(int iReturnCode)
 {
     m_rc = iReturnCode;
     return *this;
 }
 
-SKGError& SKGError::setMessage(const QString& iMessage)
+SKGError &SKGError::setMessage(const QString &iMessage)
 {
     m_message = iMessage;
     return *this;
@@ -111,7 +118,7 @@ QString SKGError::getMessage() const
     return m_message;
 }
 
-SKGError& SKGError::setProperty(const QString& iProperty)
+SKGError &SKGError::setProperty(const QString &iProperty)
 {
     m_property = iProperty;
     return *this;
@@ -125,7 +132,7 @@ QString SKGError::getProperty() const
 QString SKGError::getFullMessage() const
 {
     QString output('[');
-    output += (m_rc == 0 ? QLatin1String("SUC") : (m_rc > 0 ? QLatin1String("ERR") : QLatin1String("WAR")));
+    output += (m_rc == 0 ? QStringLiteral("SUC") : (m_rc > 0 ? QStringLiteral("ERR") : QStringLiteral("WAR")));
     output += '-';
 
     QString tmp;
@@ -156,8 +163,7 @@ int SKGError::getHistoricalSize() const
     return output;
 }
 
-
-SKGError& SKGError::setAction(const QString& iAction)
+SKGError &SKGError::setAction(const QString &iAction)
 {
     if (m_action != iAction) {
         m_action = iAction;
@@ -170,7 +176,7 @@ QString SKGError::getAction() const
     return m_action;
 }
 
-SKGError& SKGError::addError(int iRc, const QString& iMessage, const QString& iAction)
+SKGError &SKGError::addError(int iRc, const QString &iMessage, const QString &iAction)
 {
     auto pe = new SKGError(*this);
     setReturnCode(iRc);
@@ -181,14 +187,12 @@ SKGError& SKGError::addError(int iRc, const QString& iMessage, const QString& iA
     return *this;
 }
 
-SKGError& SKGError::addError(const SKGError& iError)
+SKGError &SKGError::addError(const SKGError &iError)
 {
     return addError(iError.getReturnCode(), iError.getMessage());
 }
 
-SKGError* SKGError::getPreviousError() const
+SKGError *SKGError::getPreviousError() const
 {
     return m_previousError;
 }
-
-
