@@ -23,15 +23,11 @@
 #include <qdir.h>
 #include <qdom.h>
 #include <qfile.h>
+#include <qjsengine.h>
 #include <qlocale.h>
 #include <qmath.h>
 #include <qregularexpression.h>
 #include <qsavefile.h>
-#ifdef SKG_QT6
-#include <qjsengine.h>
-#else
-#include <qscriptengine.h>
-#endif
 #include <qsqldatabase.h>
 #include <qsqldriver.h>
 #include <qsqlerror.h>
@@ -190,7 +186,7 @@ QString SKGServices::searchCriteriasToWhereClause(const SKGServices::SKGSearchCr
                     if (whereclause.isEmpty()) {
                         whereclause = std::move(subWhereClause);
                     } else {
-                        whereclause = i18nc("Logical condition", "(%1) and (%2)", whereclause, subWhereClause);
+                        whereclause = i18nc("Logical condition", "(%1) or (%2)", whereclause, subWhereClause);
                     }
                 } else if (criteria.mode == '-') {
                     if (subWhereClause.isEmpty()) {
@@ -378,11 +374,7 @@ double SKGServices::stringToDouble(const QString &iNumber, bool iUseLocale)
     number.remove(reg);
     if (number.contains(QStringLiteral("/"))) {
         // Use script engine
-#ifdef SKG_QT6
         QJSEngine myEngine;
-#else
-        QScriptEngine myEngine;
-#endif
         const auto result = myEngine.evaluate(number);
         if (result.isNumber()) {
             return result.toNumber();
@@ -625,7 +617,7 @@ QStringList SKGServices::splitCSVLine(const QString &iString, QChar iSeparator,
                     item.clear();
                     isInBlock = false;
                     // 320112 vvvv
-                    // Reset the block character to autorize mix
+                    // Reset the block character to authorize mix
                     cote = ' ';
                     // 320112 ^^^^
 
@@ -654,7 +646,7 @@ QStringList SKGServices::splitCSVLine(const QString &iString, QChar iSeparator,
             item.clear();
             isInBlock = false;
             // 320112 vvvv
-            // Reset the block character to autorize mix
+            // Reset the block character to authorize mix
             cote = ' ';
             // 320112 ^^^^
         } else {
@@ -1268,7 +1260,7 @@ SKGError SKGServices::cryptFile(const QString &iFileSource,
     // Read document
     QByteArray input;
     QByteArray uba;
-    err = downloadToStream(QUrl::fromLocalFile(iFileSource), input);
+    err = downloadToStream(QUrl::fromUserInput(iFileSource), input);
     IFOK(err)
     {
         bool isFileEncrypted = (input.startsWith(QByteArray((iHeaderFile % QStringLiteral("_ENCRYPT")).toLatin1())));
@@ -1276,7 +1268,7 @@ SKGError SKGServices::cryptFile(const QString &iFileSource,
         SKGTRACEL(10) << "isFileEncrypted=[" << static_cast<unsigned int>(isFileEncrypted) << ']' << Qt::endl;
 
         // !!!!! Remove Cipher encryption to remove security hole (thank you to Vincent P) !!!!!
-        // Only in sqlcipher mode. WARNING: in sqlite mode the issue is still there => add a message to push people to swith in sqlcipher mode
+        // Only in sqlcipher mode. WARNING: in sqlite mode the issue is still there => add a message to push people to switch in sqlcipher mode
         if (iEncrypt && !sqliteMode) {
             // The input file is a sqlcipher file and we must save it
             // We just have to add a new header to the input file
@@ -1714,9 +1706,19 @@ SKGError SKGServices::executeSelectSqliteOrder(const QSqlDatabase &iDb, const QS
             elapse1 = SKGServices::getMicroTime() - elapse;
         }
 
+        int nbRows = query.size();
+        if (nbRows == -1)
+            oResult.reserve(5000);
+        if (nbRows > 0)
+            oResult.reserve(nbRows);
+
         // Addition of column names
         QSqlRecord rec = query.record();
         QStringList line;
+        int nbFields = rec.count();
+        if (nbRows > 0)
+            line.reserve(nbFields);
+
         int index = 0;
         while (index != -1) {
             QString val = rec.fieldName(index);
@@ -1747,7 +1749,11 @@ SKGError SKGServices::executeSelectSqliteOrder(const QSqlDatabase &iDb, const QS
         if (SKGServices::SKGSqlTraces != -1) {
             double elapse2 = SKGServices::getMicroTime() - elapse;
             if (elapse1 >= SKGServices::SKGSqlTraces) {
-                SKGTRACE << "executeSqliteOrder:" << iSqlOrder << " TIME=" << elapse1 << " ms,  (with fetch):" << elapse2 << " ms" << Qt::endl;
+                SKGTRACE << "executeSqliteOrder: " << iSqlOrder << " (" << oResult.count() << "x" << nbFields << ") TIME=" << elapse1
+                         << " ms !!!,  (with fetch):" << elapse2 << " ms" << Qt::endl;
+            } else if (elapse2 >= SKGServices::SKGSqlTraces) {
+                SKGTRACE << "executeSqliteOrder: " << iSqlOrder << " (" << oResult.count() << "x" << nbFields << ") TIME=" << elapse1
+                         << " ms,  (with fetch):" << elapse2 << " ms !!!" << Qt::endl;
             }
         }
     }
@@ -1762,7 +1768,7 @@ SKGError SKGServices::readPropertyFile(const QString &iFileName, QHash<QString,
     // Open file
     QFile file(iFileName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-        err = SKGError(ERR_FAIL, i18nc("An erro message", "Open file '%1' failed", iFileName));
+        err = SKGError(ERR_FAIL, i18nc("An error message", "Open file '%1' failed", iFileName));
     } else {
         // Read file
         QTextStream stream(&file);
