@@ -24,7 +24,7 @@
  *  SKGError err;
  *
  *  // Begin transaction
- *   SKGBEGINTRANSACTION(Your_SKGDocument, QLatin1String("The_Name_Of_The_Transaction"), err)
+ *   SKGBEGINTRANSACTION(Your_SKGDocument, QStringLiteral("The_Name_Of_The_Transaction"), err)
  *
  *  // Check the error
  *  if(!err)
@@ -37,15 +37,13 @@
  * } // END OF THE TRANSACTION
  * @endcode
  */
-#define SKGBEGINTRANSACTION(Document, Name, Error) \
-    SKGTransactionMng TOKENPASTE2(transaction_, __LINE__)(&(Document), Name, &(Error));
+#define SKGBEGINTRANSACTION(Document, Name, Error) SKGTransactionMng TOKENPASTE2(transaction_, __LINE__)(&(Document), Name, &(Error));
 
 /**
  * @def SKGBEGINLIGHTTRANSACTION(Document, Name, Error)
  * Macro to start a new light transaction (without views computation)
  */
-#define SKGBEGINLIGHTTRANSACTION(Document, Name, Error) \
-    SKGTransactionMng transactionlight_(&(Document), Name, &(Error), 1, false);
+#define SKGBEGINLIGHTTRANSACTION(Document, Name, Error) SKGTransactionMng transactionlight_(&(Document), Name, &(Error), 1, false);
 /**
  * @def SKGBEGINPROGRESSTRANSACTION(Document, Name, Error)
  * Macro to start a new transaction
@@ -75,30 +73,32 @@
  * } // END OF THE TRANSACTION
  * @endcode
  */
-#define SKGBEGINPROGRESSTRANSACTION(Document, Name, Error, Nb) \
-    SKGTransactionMng TOKENPASTE2(transaction_, __LINE__)(&(Document), Name, &(Error), Nb);
+#define SKGBEGINPROGRESSTRANSACTION(Document, Name, Error, Nb) SKGTransactionMng TOKENPASTE2(transaction_, __LINE__)(&(Document), Name, &(Error), Nb);
 
 /**
  * @def SKGBEGINLIGHTPROGRESSTRANSACTION(Document, Name, Error)
  * Macro to start a new light transaction (without views computation)
  */
-#define SKGBEGINLIGHTPROGRESSTRANSACTION(Document, Name, Error, Nb) \
+#define SKGBEGINLIGHTPROGRESSTRANSACTION(Document, Name, Error, Nb)                                                                                            \
     SKGTransactionMng TOKENPASTE2(transactionlight_, __LINE__)(&(Document), Name, &(Error), Nb, false);
 
 /**
  * @def SKGENDTRANSACTION(Document,  Error)
  * End correctly a transaction
  */
-#define SKGENDTRANSACTION(Document,  Error) \
-    if (!(Error)) {(Error) = (Document)->endTransaction(true);} \
-    else {(Document)->endTransaction(false);}
+#define SKGENDTRANSACTION(Document, Error)                                                                                                                     \
+    if (!(Error)) {                                                                                                                                            \
+        (Error) = (Document)->endTransaction(true);                                                                                                            \
+    } else {                                                                                                                                                   \
+        (Document)->endTransaction(false);                                                                                                                     \
+    }
 
 class SKGError;
 class SKGDocument;
 
 /**
-* Facilitate the transaction management
-*/
+ * Facilitate the transaction management
+ */
 class SKGBASEMODELER_EXPORT SKGTransactionMng
 {
 public:
@@ -114,7 +114,7 @@ public:
      * It is used to call the progress callback.
      * @see The SKGError
      */
-    explicit SKGTransactionMng(SKGDocument* iDocument, const QString& iName, SKGError* iError, int iNbStep = 1, bool iRefreshViews = true);
+    explicit SKGTransactionMng(SKGDocument *iDocument, const QString &iName, SKGError *iError, int iNbStep = 1, bool iRefreshViews = true);
 
     /**
      * Destructor
@@ -124,8 +124,8 @@ public:
 private:
     Q_DISABLE_COPY(SKGTransactionMng)
 
-    SKGError* m_error;
-    SKGDocument* m_parentDocument;
+    SKGError *m_error;
+    SKGDocument *m_parentDocument;
     bool m_errorInBeginTransaction;
 };
 
