@@ -4,23 +4,24 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
-* This file implements classes SKGTreeMap.
-*
-* @author Stephane MANKOWSKI
-*/
+ * This file implements classes SKGTreeMap.
+ *
+ * @author Stephane MANKOWSKI
+ */
 #include "skgtreemap.h"
 
 #include "skgtraces.h"
 #include <utility>
 
-SKGTreeMap::SKGTreeMap(QString  iID,
-                       double iValue,
-                       double iX,
-                       double iY,
-                       double iW,
-                       double iH)
-    : m_id(std::move(iID)), m_value(iValue), m_x(iX), m_y(iY), m_w(iW), m_h(iH)
-{}
+SKGTreeMap::SKGTreeMap(QString iID, double iValue, double iX, double iY, double iW, double iH)
+    : m_id(std::move(iID))
+    , m_value(iValue)
+    , m_x(iX)
+    , m_y(iY)
+    , m_w(iW)
+    , m_h(iH)
+{
+}
 
 SKGTreeMap::~SKGTreeMap() = default;
 
@@ -74,7 +75,7 @@ double SKGTreeMap::getH() const
     return m_h;
 }
 
-void SKGTreeMap::addChild(const SKGTreeMap& iChildren)
+void SKGTreeMap::addChild(const SKGTreeMap &iChildren)
 {
     m_children.append(iChildren);
 }
@@ -90,7 +91,7 @@ void SKGTreeMap::computeValuesAndSort()
     if (m_children.count() != 0) {
         // Compute the value
         double sum = 0.0;
-        for (auto& item : m_children) {
+        for (auto &item : m_children) {
             item.computeValuesAndSort();
             sum += item.getValue();
         }
@@ -99,9 +100,8 @@ void SKGTreeMap::computeValuesAndSort()
         m_value = sum;
 
         // Sort the children by abs(value) desc
-        std::sort(m_children.begin(), m_children.end(), [](const SKGTreeMap & a, const SKGTreeMap & b) -> bool {
-            if (qAbs(a.getValue() - b.getValue()) < 10e-5)
-            {
+        std::sort(m_children.begin(), m_children.end(), [](const SKGTreeMap &a, const SKGTreeMap &b) -> bool {
+            if (qAbs(a.getValue() - b.getValue()) < 10e-5) {
                 return a.getID() < b.getID();
             }
             return a.getValue() > b.getValue();
@@ -113,10 +113,10 @@ QMap<QString, SKGTreeMap> SKGTreeMap::getAllTilesById() const
 {
     QMap<QString, SKGTreeMap> output;
     output.insert(getID(), *this);
-    for (const auto& item : std::as_const(m_children)) {
+    for (const auto &item : std::as_const(m_children)) {
         output.insert(item.getID(), item);
         auto children = item.getAllTilesById();
-        for (const auto& item2 : std::as_const(children)) {
+        for (const auto &item2 : std::as_const(children)) {
             output.insert(item2.getID(), item2);
         }
     }
@@ -149,7 +149,7 @@ void SKGTreeMap::compute()
             // Set the first
             m_children[0].setX(getX());
             m_children[0].setY(getY());
-            m_children[0].setW(isValueZero ? 0.0 : getW()*m_children.at(0).getValue() / getValue());
+            m_children[0].setW(isValueZero ? 0.0 : getW() * m_children.at(0).getValue() / getValue());
             m_children[0].setH(getH());
 
             m_children[0].compute();
@@ -167,7 +167,7 @@ void SKGTreeMap::compute()
             m_children[0].setX(getX());
             m_children[0].setY(getY());
             m_children[0].setW(getW());
-            m_children[0].setH(isValueZero ? 0.0 : getH()*m_children.at(0).getValue() / getValue());
+            m_children[0].setH(isValueZero ? 0.0 : getH() * m_children.at(0).getValue() / getValue());
 
             m_children[0].compute();
 
@@ -251,7 +251,7 @@ void SKGTreeMap::compute()
             double y = getW() >= getH() ? getY() : getY() + previous_gh;
             double w = getW() >= getH() ? getW() - previous_gw : getW();
             double h = getW() >= getH() ? getH() : getH() - previous_gh;
-            SKGTreeMap rest(QLatin1String(""), getValue() - sum, x, y, w, h);
+            SKGTreeMap rest(QString(), getValue() - sum, x, y, w, h);
 
             // Add all items to compute
             for (int i = optimum + 1; i < nb; ++i) {
