@@ -16,9 +16,6 @@
 #ifdef SKG_DBUS
 #include <kdbusservice.h>
 #endif
-#ifndef SKG_QT6
-#include <kdelibs4configmigrator.h>
-#endif
 #include <klocalizedstring.h>
 
 #include <QtQuickControls2/qquickstyle.h>
@@ -74,24 +71,12 @@ int main(int argc, char **argv)
     QApplication::setAttribute(Qt::AA_ShareOpenGLContexts, true);
 #endif
 
-#ifndef SKG_QT6
-    if (!SKGServices::getEnvVariable(QStringLiteral("SKGHIGHDPI")).isEmpty()) {
-        QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-        QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    }
-#endif
     QApplication app(argc, argv);
     QIcon appIcon = SKGServices::fromTheme(QStringLiteral("skrooge"));
     if (!appIcon.isNull()) {
         app.setWindowIcon(appIcon);
     }
 
-#ifndef SKG_QT6
-    // Migration kf4 => kf5
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("skrooge"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("skroogerc"));
-    migrate.migrate();
-#endif
     // To use CPU instead CPU for QML (needed for printing)
     qputenv("QMLSCENE_DEVICE", "softwarecontext");
 
@@ -126,9 +111,7 @@ int main(int argc, char **argv)
                     QStringLiteral("siddharth.kde@gmail.com"),
                     QString(),
                     QStringLiteral("h4xordood"));
-    /*about.addAuthor(i18nc("Fullname", "Michael LONGMIRE"), i18nc("A job description", "Splash screen photographer"), QString(), QString()
-                    , QString()
-                   );*/
+    about.addAuthor(i18nc("Fullname", "Mathieu STERN"), i18nc("A job description", "Splash screen photographer"), QString(), QString(), QString());
     about.setOtherText(i18nc("The description of the application",
                              "The application name is inspired by Charles Dicken's tale <i>A Christmas Carol</i>, where the main character, Ebenezer Scrooge, "
                              "a grumpy old narrow man, gets visited by three ghosts who change the way he sees the world, in a good way."));
