@@ -1,7 +1,7 @@
 #!/bin/sh
 
 #initialisation
-. `dirname $0`/init.sh
+. "`dirname \"$0\"`/init.sh"
 
 sikulirun unit
 rc=$?
