@@ -2,11 +2,11 @@
 EXE=skgtestcalculatoredit
 
 #initialisation
-. `dirname $0`/init.sh
+. "`dirname \"$0\"`/init.sh"
 
 unset SKGTRACE #does not work if traces activated
 
-${EXE}
+"${EXE}"
 rc=$?
 if [ $rc != 0 ] ; then
 	exit $rc
