@@ -2,15 +2,15 @@
 EXE=skgtestimportstockqif
 
 #initialisation
-. `dirname $0`/init.sh
+. "`dirname \"$0\"`/init.sh"
 
-${EXE}
+"${EXE}"
 rc=$?
 if [ $rc != 0 ] ; then
 	exit $rc
 fi
 
-#checkDiff ${OUT}/skgtestimportqif/ref.qif ${REF}/skgtestimportqif/ref.qif 
+#checkDiff "${OUT}/skgtestimportqif/ref.qif" "${REF}/skgtestimportqif/ref.qif"
 
 
-exit 0
\ No newline at end of file
+exit 0
