@@ -49,14 +49,17 @@
 #include <QtTest>
 
 #undef Q_ASSERT
-#define Q_ASSERT  QVERIFY
+#define Q_ASSERT QVERIFY
 
 Q_DECLARE_METATYPE(QModelIndex)
 
 /*!
     Connect to all of the models signals.  Whenever anything happens recheck everything.
 */
-ModelTest::ModelTest(QAbstractItemModel* model, QObject* iParent) : QObject(iParent), model(model), fetchingMore(false)
+ModelTest::ModelTest(QAbstractItemModel *model, QObject *iParent)
+    : QObject(iParent)
+    , model(model)
+    , fetchingMore(false)
 {
     Q_ASSERT(model);
 
@@ -141,7 +144,7 @@ void ModelTest::nonDestructiveBasicTest()
  */
 void ModelTest::rowCount()
 {
-//     qDebug() << "rc";
+    //     qDebug() << "rc";
     // check top row
     QModelIndex topIndex = model->index(0, 0, QModelIndex());
     int rows = model->rowCount(topIndex);
@@ -151,7 +154,7 @@ void ModelTest::rowCount()
     }
 
     QModelIndex secondLevelIndex = model->index(0, 0, topIndex);
-    if (secondLevelIndex.isValid()) {   // not the top level
+    if (secondLevelIndex.isValid()) { // not the top level
         // check a row count where parent is valid
         rows = model->rowCount(secondLevelIndex);
         Q_ASSERT(rows >= 0);
@@ -188,7 +191,7 @@ void ModelTest::columnCount()
  */
 void ModelTest::hasIndex()
 {
-//     qDebug() << "hi";
+    //     qDebug() << "hi";
     // Make sure that invalid values returns an invalid index
     Q_ASSERT(model->hasIndex(-2, -2) == false);
     Q_ASSERT(model->hasIndex(-2, 0) == false);
@@ -214,7 +217,7 @@ void ModelTest::hasIndex()
  */
 void ModelTest::index()
 {
-//     qDebug() << "i";
+    //     qDebug() << "i";
     // Make sure that invalid values returns an invalid index
     Q_ASSERT(model->index(-2, -2) == QModelIndex());
     Q_ASSERT(model->index(-2, 0) == QModelIndex());
@@ -245,7 +248,7 @@ void ModelTest::index()
  */
 void ModelTest::parent()
 {
-//     qDebug() << "p";
+    //     qDebug() << "p";
     // Make sure the model wont crash and will return an invalid QModelIndex
     // when asked for the parent of an invalid index.
     Q_ASSERT(model->parent(QModelIndex()) == QModelIndex());
@@ -300,7 +303,7 @@ void ModelTest::parent()
     found the basic bugs because it is easier to figure out the problem in
     those tests then this one.
  */
-void ModelTest::checkChildren(const QModelIndex& iParent, int currentDepth)
+void ModelTest::checkChildren(const QModelIndex &iParent, int currentDepth)
 {
     // First just try walking back up the tree.
     QModelIndex p = iParent;
@@ -366,24 +369,23 @@ void ModelTest::checkChildren(const QModelIndex& iParent, int currentDepth)
             // If the next test fails here is some somewhat useful debug you play with.
 
             if (model->parent(idx) != iParent) {
-                qDebug() << r << c << currentDepth << model->data(idx).toString()
-                         << model->data(iParent).toString();
+                qDebug() << r << c << currentDepth << model->data(idx).toString() << model->data(iParent).toString();
                 qDebug() << idx << iParent << model->parent(idx);
-//                 And a view that you can even use to show the model.
-//                 QTreeView view;
-//                 view.setModel(model);
-//                 view.show();
+                //                 And a view that you can even use to show the model.
+                //                 QTreeView view;
+                //                 view.setModel(model);
+                //                 view.show();
             }
 
             // Check that we can get back our real parent.
-//             qDebug() << model->parent ( index ) << parent;
+            //             qDebug() << model->parent ( index ) << parent;
             Q_ASSERT(model->parent(idx) == iParent);
 
             // recursively go down the children
             if (model->hasChildren(idx) && currentDepth < 10) {
                 // qDebug() << r << c << "has children" << model->rowCount(index);
                 checkChildren(idx, ++currentDepth);
-            }/* else { if (currentDepth >= 10) qDebug() << "checked 10 deep"; };*/
+            } /* else { if (currentDepth >= 10) qDebug() << "checked 10 deep"; };*/
 
             // make sure that after testing the children that the index doesn't change.
             QModelIndex newerIndex = model->index(r, c, iParent);
@@ -406,14 +408,13 @@ void ModelTest::data()
         return;
     }
 
-
     for (int r = 0; r < nbRows; ++r) {
         for (int c = 0; c < nbColumns; ++c) {
             // A valid index should have a valid QVariant data
             Q_ASSERT(model->index(r, c).isValid());
 
             // shouldn't be able to set data on an invalid index
-            Q_ASSERT(model->setData(QModelIndex(), QLatin1String("foo"), Qt::DisplayRole) == false);
+            Q_ASSERT(model->setData(QModelIndex(), QStringLiteral("foo"), Qt::DisplayRole) == false);
 
             // General Purpose roles that should return a QString
             QVariant variant = model->data(model->index(r, c), Qt::ToolTipRole);
@@ -432,7 +433,7 @@ void ModelTest::data()
             // General Purpose roles that should return a QSize
             variant = model->data(model->index(r, c), Qt::SizeHintRole);
             if (variant.isValid()) {
-                Q_ASSERT(variant.canConvert<QSize> ());
+                Q_ASSERT(variant.canConvert<QSize>());
             }
 
             // MANKOWSKI: UserRole
@@ -444,7 +445,7 @@ void ModelTest::data()
             // General Purpose roles that should return a QFont
             QVariant fontVariant = model->data(model->index(r, c), Qt::FontRole);
             if (fontVariant.isValid()) {
-                Q_ASSERT(fontVariant.canConvert<QFont> ());
+                Q_ASSERT(fontVariant.canConvert<QFont>());
             }
 
             // Check that the alignment is one we know about
@@ -457,21 +458,19 @@ void ModelTest::data()
             // General Purpose roles that should return a QColor
             QVariant colorVariant = model->data(model->index(r, c), Qt::BackgroundRole);
             if (colorVariant.isValid()) {
-                Q_ASSERT(colorVariant.canConvert<QColor> ());
+                Q_ASSERT(colorVariant.canConvert<QColor>());
             }
 
             colorVariant = model->data(model->index(r, c), Qt::ForegroundRole);
             if (colorVariant.isValid()) {
-                Q_ASSERT(colorVariant.canConvert<QColor> ());
+                Q_ASSERT(colorVariant.canConvert<QColor>());
             }
 
             // Check that the "check state" is one we know about.
             QVariant checkStateVariant = model->data(model->index(r, c), Qt::CheckStateRole);
             if (checkStateVariant.isValid()) {
                 int state = checkStateVariant.toInt();
-                Q_ASSERT(state == Qt::Unchecked ||
-                         state == Qt::PartiallyChecked ||
-                         state == Qt::Checked);
+                Q_ASSERT(state == Qt::Unchecked || state == Qt::PartiallyChecked || state == Qt::Checked);
             }
         }
     }
@@ -482,12 +481,12 @@ void ModelTest::data()
 
     \sa rowsInserted()
  */
-void ModelTest::rowsAboutToBeInserted(const QModelIndex& iParent, int start, int end)
+void ModelTest::rowsAboutToBeInserted(const QModelIndex &iParent, int start, int end)
 {
     Q_UNUSED(end)
-//    qDebug() << "rowsAboutToBeInserted" << "start=" << start << "end=" << end << "parent=" << model->data ( parent ).toString()
-//    << "current count of parent=" << model->rowCount ( parent );  // << "display of last=" << model->data( model->index(start-1, 0, parent) );
-//     qDebug() << model->index(start-1, 0, parent) << model->data( model->index(start-1, 0, parent) );
+    //    qDebug() << "rowsAboutToBeInserted" << "start=" << start << "end=" << end << "parent=" << model->data ( parent ).toString()
+    //    << "current count of parent=" << model->rowCount ( parent );  // << "display of last=" << model->data( model->index(start-1, 0, parent) );
+    //     qDebug() << model->index(start-1, 0, parent) << model->data( model->index(start-1, 0, parent) );
     Changing c;
     c.parent = iParent;
     c.oldSize = model->rowCount(iParent);
@@ -501,18 +500,18 @@ void ModelTest::rowsAboutToBeInserted(const QModelIndex& iParent, int start, int
 
     \sa rowsAboutToBeInserted()
  */
-void ModelTest::rowsInserted(const QModelIndex& iParent, int start, int end)
+void ModelTest::rowsInserted(const QModelIndex &iParent, int start, int end)
 {
     Changing c = insert.pop();
     Q_ASSERT(c.parent == iParent);
-//    qDebug() << "rowsInserted"  << "start=" << start << "end=" << end << "oldsize=" << c.oldSize
-//    << "parent=" << model->data ( parent ).toString() << "current rowcount of parent=" << model->rowCount ( parent );
+    //    qDebug() << "rowsInserted"  << "start=" << start << "end=" << end << "oldsize=" << c.oldSize
+    //    << "parent=" << model->data ( parent ).toString() << "current rowcount of parent=" << model->rowCount ( parent );
 
-//    for (int ii=start; ii <= end; ii++)
-//    {
-//      qDebug() << "itemWasInserted:" << ii << model->data ( model->index ( ii, 0, parent ));
-//    }
-//    qDebug();
+    //    for (int ii=start; ii <= end; ii++)
+    //    {
+    //      qDebug() << "itemWasInserted:" << ii << model->data ( model->index ( ii, 0, parent ));
+    //    }
+    //    qDebug();
 
     Q_ASSERT(c.oldSize + (end - start + 1) == model->rowCount(iParent));
     Q_ASSERT(c.last == model->data(model->index(start - 1, 0, c.parent)));
@@ -549,7 +548,7 @@ void ModelTest::layoutChanged()
 
     \sa rowsRemoved()
  */
-void ModelTest::rowsAboutToBeRemoved(const QModelIndex& iParent, int start, int end)
+void ModelTest::rowsAboutToBeRemoved(const QModelIndex &iParent, int start, int end)
 {
     qDebug() << "ratbr" << iParent << start << end;
     Changing c;
@@ -565,7 +564,7 @@ void ModelTest::rowsAboutToBeRemoved(const QModelIndex& iParent, int start, int
 
     \sa rowsAboutToBeRemoved()
  */
-void ModelTest::rowsRemoved(const QModelIndex& iParent, int start, int end)
+void ModelTest::rowsRemoved(const QModelIndex &iParent, int start, int end)
 {
     qDebug() << "rr" << iParent << start << end;
     Changing c = remove.pop();
@@ -574,5 +573,3 @@ void ModelTest::rowsRemoved(const QModelIndex& iParent, int start, int end)
     Q_ASSERT(c.last == model->data(model->index(start - 1, 0, c.parent)));
     Q_ASSERT(c.next == model->data(model->index(start, 0, c.parent)));
 }
-
-
