@@ -26,19 +26,19 @@ void SKGTESTMainPanel::Test()
     // Create main panel
     SKGMainPanel mainpanel(nullptr, &doc);
 
-    QVERIFY2(!doc.load(SKGTest::getTestPath(QLatin1String("IN")) % "/advice.skg"), "Load document failed");
+    QVERIFY2(!doc.load(SKGTest::getTestPath(QStringLiteral("IN")) % "/advice.skg"), "Load document failed");
     SKGError err;
     {
         // Scope of the transaction
-        SKGBEGINTRANSACTION(doc, QLatin1String("PROP"), err)
-        doc.setParameter(QLatin1String("SKG_LAST_BUDGET_PROCESSING"), QLatin1String(""));
+        SKGBEGINTRANSACTION(doc, QStringLiteral("PROP"), err)
+        doc.setParameter(QStringLiteral("SKG_LAST_BUDGET_PROCESSING"), QString());
     }
 
     // Check plugins
     {
-        SKGBEGINTRANSACTION(doc, QLatin1String("PLUGINS"), err)
+        SKGBEGINTRANSACTION(doc, QStringLiteral("PLUGINS"), err)
         int i = 0;
-        SKGInterfacePlugin* plugin = nullptr;
+        SKGInterfacePlugin *plugin = nullptr;
         do {
             plugin = mainpanel.getPluginByIndex(i);
             if (plugin != nullptr) {
@@ -50,7 +50,7 @@ void SKGTESTMainPanel::Test()
                 plugin->isInPagesChooser();
                 plugin->isEnabled();
 
-                SKGTabPage* tab = plugin->getWidget();
+                SKGTabPage *tab = plugin->getWidget();
                 if (tab != nullptr) {
                     tab->printableWidgets();
                     tab->activateEditor();
@@ -67,7 +67,7 @@ void SKGTESTMainPanel::Test()
                 int nbd = plugin->getNbDashboardWidgets();
                 for (int j = 0; j < nbd + 1; ++j) {
                     SKGTRACE << "    Dashboard " << j << "/" << nbd + 1 << ": " << plugin->getDashboardWidgetTitle(j) << Qt::endl;
-                    SKGBoardWidget* bw = plugin->getDashboardWidget(j);
+                    SKGBoardWidget *bw = plugin->getDashboardWidget(j);
                     if (bw != nullptr) {
                         bw->setState(bw->getState());
                         bw->getDefaultStateAttribute();
@@ -81,7 +81,7 @@ void SKGTESTMainPanel::Test()
                 plugin->savePreferences();
 
                 SKGAdviceList adviceList = plugin->advice(QStringList());
-                for (const auto& advice : std::as_const(adviceList)) {
+                for (const auto &advice : std::as_const(adviceList)) {
                     SKGTRACE << "    Advice: " << advice.getUUID() << Qt::endl;
                     for (int k = 0; k < 5; ++k) {
                         plugin->executeAdviceCorrection(advice.getUUID(), k);
@@ -100,8 +100,8 @@ void SKGTESTMainPanel::Test()
     SKGTRACE << "processArguments" << Qt::endl;
     mainpanel.processArguments(QStringList());
 
-    mainpanel.openPage(QLatin1String("skg://skrooge_operation_plugin"));
-    SKGTabPage* page = mainpanel.currentPage();
+    mainpanel.openPage(QStringLiteral("skg://skrooge_operation_plugin"));
+    SKGTabPage *page = mainpanel.currentPage();
     mainpanel.switchPinPage(page);
     mainpanel.currentPageHistoryItem();
 
@@ -127,4 +127,3 @@ void SKGTESTMainPanel::Test()
 }
 
 QTEST_MAIN(SKGTESTMainPanel)
-
