@@ -966,7 +966,6 @@ int main(int argc, char **argv)
             imp1.setImportParameters(parameters);
             SKGTESTERROR(QStringLiteral("CSV.importFile"), imp1.importFile(), true)
 
-            document1.dump(DUMPOPERATION | DUMPACCOUNT);
             SKGAccountObject account(&document1);
             SKGTESTERROR(QStringLiteral("ACCOUNT.load"), account.setName(QStringLiteral("494159")), true)
             SKGTESTERROR(QStringLiteral("ACCOUNT.load"), account.load(), true)
@@ -974,6 +973,35 @@ int main(int argc, char **argv)
         }
     }
 
+    {
+        // 492495
+        QLocale::setDefault(QLocale::German);
+
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.load()"), document1.load(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportcsv/492495.skg"), true)
+
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_CSV"), err)
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportcsv/494159.csv"));
+            QMap<QString, QString> parameters = imp1.getImportParameters();
+            parameters[QStringLiteral("automatic_search_columns")] = 'N';
+            parameters[QStringLiteral("header_position")] = QStringLiteral("1");
+            parameters[QStringLiteral("columns_positions")] = QStringLiteral("|date||payee|||||amount");
+            imp1.setImportParameters(parameters);
+            imp1.setAutomaticApplyRules(true);
+            SKGTESTERROR(QStringLiteral("CSV.importFile"), imp1.importFile(), true)
+
+            document1.dump(DUMPOPERATION | DUMPACCOUNT);
+            int nb = 0;
+            SKGTESTERROR(QStringLiteral("imp1.getNbObjects"), document1.getNbObjects(QStringLiteral("account"), QString(), nb), true)
+            SKGTEST(QStringLiteral("ACCOUNT:nb"), SKGServices::intToString(nb), QStringLiteral("2"))
+
+            SKGTESTERROR(QStringLiteral("imp1.getNbObjects"), document1.getNbObjects(QStringLiteral("bank"), QString(), nb), true)
+            SKGTEST(QStringLiteral("BANK:nb"), SKGServices::intToString(nb), QStringLiteral("1"))
+        }
+    }
     // End test
     SKGENDTEST()
 } // NOLINT(readability/fn_size)
