@@ -69,21 +69,21 @@ int main(int argc, char **argv)
         accounts[QStringLiteral("Charlie's 401(k) (Contributions)")] = 13192.68;
         accounts[QStringLiteral("Commodities")] = 8745.0000;
         accounts[QStringLiteral("Commodities (Cash)")] = 255.0;
-        accounts[QStringLiteral("ETF Brokerage Account")] = 690.0;
+        accounts[QStringLiteral("ETF Brokerage Account")] = 1560.0;
         accounts[QStringLiteral("ETF Brokerage Account (Cash)")] = 2310.0;
         accounts[QStringLiteral("Escrow Account")] = 28100.0;
         accounts[QStringLiteral("Home Loan")] = -149122.08;
-        accounts[QStringLiteral("Investments to Watch")] = 0.0;
+        accounts[QStringLiteral("Investments to Watch")] = 110.25;
         accounts[QStringLiteral("Previous card (No longer used)")] = -984.25;
         accounts[QStringLiteral("Primary Residence")] = 355000.0;
-        accounts[QStringLiteral("WoodGrove Finance Stock Options")] = 0.0;
+        accounts[QStringLiteral("WoodGrove Finance Stock Options")] = 45000;
         accounts[QStringLiteral("WoodGrove Finance Stock Options (Cash)")] = 0.0;
         accounts[QStringLiteral("Woodgrove Bank Checking")] = 22871.06;
         accounts[QStringLiteral("Woodgrove Bank Credit Card")] = 19305.74;
         accounts[QStringLiteral("Woodgrove Bank Savings")] = 22946.30;
-        accounts[QStringLiteral("Woodgrove Bond Account")] = 57916.20;
+        accounts[QStringLiteral("Woodgrove Bond Account")] = 62160.85;
         accounts[QStringLiteral("Woodgrove Bond Account (Cash)")] = -57916.20;
-        accounts[QStringLiteral("Woodgrove Investments")] = 1574.62;
+        accounts[QStringLiteral("Woodgrove Investments")] = 254176.78;
         accounts[QStringLiteral("Woodgrove Investments (Cash)")] = -1594.62;
         accounts[QStringLiteral("Woodgrove Platinum Card")] = -836.0;
         t1.expectedAccountAmount = accounts;
