@@ -129,7 +129,7 @@ int main(int argc, char **argv)
                                                      account),
                      true)
         SKGTESTERROR(QStringLiteral("ACCOUNT.load"), account.load(), true)
-        SKGTEST(QStringLiteral("ACCOUNT:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("0cd"))
+        SKGTEST(QStringLiteral("ACCOUNT:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("0"))
     }
 
     {
