@@ -257,42 +257,6 @@ int main(int argc, char **argv)
         }
     }
 
-    {
-        // BULK import
-        SKGDocumentBank document1;
-        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
-        SKGError err;
-        {
-            // Scope of the transaction
-            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_BULK"), err)
-
-            SKGTESTBOOL("PUTENV.bulk", qputenv("PATH", (in + "/skgtestimportbackend/bulk/:" + path).toLatin1()), true)
-
-            SKGImportExportManager imp1(&document1, QUrl(QStringLiteral(".bulk")));
-            SKGTESTERROR(QStringLiteral("WEBOOB.importFile"), imp1.importFile(), true)
-        }
-
-        // Check
-        {
-            SKGAccountObject account;
-            SKGTESTERROR(QStringLiteral("ACCOUNT.getObjectByName"),
-                         SKGNamedObject::getObjectByName(&document1, QStringLiteral("v_account"), QStringLiteral("12345"), account),
-                         true)
-            SKGTESTERROR(QStringLiteral("ACCOUNT.load"), account.load(), true)
-            SKGTEST(QStringLiteral("ACCOUNT:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("10"))
-        }
-
-        // Check
-        {
-            SKGAccountObject account;
-            SKGTESTERROR(QStringLiteral("ACCOUNT.getObjectByName"),
-                         SKGNamedObject::getObjectByName(&document1, QStringLiteral("v_account"), QStringLiteral("78900"), account),
-                         true)
-            SKGTESTERROR(QStringLiteral("ACCOUNT.load"), account.load(), true)
-            SKGTEST(QStringLiteral("ACCOUNT:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("20"))
-        }
-    }
-
     {
         // STAMM
         SKGDocumentBank document1;
