@@ -18,25 +18,26 @@
  * @param argc the number of arguments
  * @param argv the list of arguments
  */
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
     Q_UNUSED(argc)
     Q_UNUSED(argv)
 
     // Init test
-    SKGINITTEST(true) {
+    SKGINITTEST(true)
+    {
         // Test load old version of files
         {
             SKGDocumentBank document1;
-            SKGTESTERROR(QLatin1String("DOC:load"), document1.load(SKGTest::getTestPath(QLatin1String("IN")) % "/skgtestmigration/version_0.1.skg"), true)
+            SKGTESTERROR(QStringLiteral("DOC:load"), document1.load(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestmigration/version_0.1.skg"), true)
         }
         {
             SKGDocumentBank document1;
-            SKGTESTERROR(QLatin1String("DOC:load"), document1.load(SKGTest::getTestPath(QLatin1String("IN")) % "/skgtestmigration/version_0.3.skg"), true)
+            SKGTESTERROR(QStringLiteral("DOC:load"), document1.load(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestmigration/version_0.3.skg"), true)
         }
         {
             SKGDocumentBank document1;
-            SKGTESTERROR(QLatin1String("DOC:load"), document1.load(SKGTest::getTestPath(QLatin1String("IN")) % "/skgtestmigration/version_1.12.skg"), true)
+            SKGTESTERROR(QStringLiteral("DOC:load"), document1.load(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestmigration/version_1.12.skg"), true)
         }
     }
 
