@@ -210,8 +210,6 @@ int main(int argc, char **argv)
             SKGTESTBOOL("RECOP:templateOp1==ope2", (templateOp1 == ope2), createTemplateForRecurrent)
             SKGTEST(QStringLiteral("OP:getRecurrentOperation"), ope2.getRecurrentOperation(), recuope1.getID())
 
-            document1.dump(DUMPOPERATION);
-
             const auto testProcess = [&](SKGRecurrentOperationObject &recuope, int resultingOperationsCount) {
                 int nbi = 0;
                 SKGTESTERROR(QStringLiteral("RECOP:process"), recuope.process(nbi), true)
@@ -235,7 +233,6 @@ int main(int argc, char **argv)
 
             SKGTRACE << "####### Process a schedule" << Qt::endl;
             testProcess(recuope1, 3);
-            document1.dump(DUMPOPERATION);
 
             SKGTESTERROR(QStringLiteral("RECOP:setPeriodIncrement"), recuope1.setPeriodIncrement(2), true)
             SKGTESTERROR(QStringLiteral("RECOP:setPeriodUnit"), recuope1.setPeriodUnit(SKGRecurrentOperationObject::DAY), true)
@@ -348,17 +345,14 @@ int main(int argc, char **argv)
             SKGTRACE << "####### Assign a schedule to a preceeding operation" << Qt::endl;
             start_date = d1.addMonths(-3);
             testAssign(recuope1, start_date, QStringLiteral("10 tickets (old)"), 4);
-            document1.dump(DUMPOPERATION);
 
             SKGTRACE << "####### Assign a schedule to a succeeding operation" << Qt::endl;
             end_date = d2.addMonths(2);
             testAssign(recuope1, end_date, QStringLiteral("10 tickets (new)"), 5);
-            document1.dump(DUMPOPERATION);
 
             SKGTRACE << "####### Remove all scheduled transactions" << Qt::endl;
             removeAllScheduled(recuope1);
             testDocumentIsEmpty();
-            document1.dump(DUMPOPERATION);
 
             SKGTRACE << "####### Unassign last transaction from a schedule" << Qt::endl;
             {
@@ -375,8 +369,6 @@ int main(int argc, char **argv)
                     SKGTEST(QStringLiteral("OP:getAttribute"), op.getAttribute(QStringLiteral("r_recurrentoperation_id")), QStringLiteral("0"))
                 }
 
-                document1.dump(DUMPOPERATION);
-
                 recuope.load();
                 SKGTESTBOOL(QStringLiteral("RECOP:exist"), recuope.exist(), recurrentOperationIsTemplate)
 
@@ -404,8 +396,6 @@ int main(int argc, char **argv)
 
                 removeOperation(op);
 
-                document1.dump(DUMPOPERATION);
-
                 recuope.load();
                 SKGTESTBOOL(QStringLiteral("RECOP:exist"), recuope.exist(), createTemplateForRecurrent)
 
@@ -440,8 +430,6 @@ int main(int argc, char **argv)
                 SKGTESTERROR(QStringLiteral("OP:setRecurrentOperation"), firstOp.setRecurrentOperation(0), true)
                 SKGTEST(QStringLiteral("OP:getAttribute"), firstOp.getAttribute(QStringLiteral("r_recurrentoperation_id")), QStringLiteral("0"))
 
-                document1.dump(DUMPOPERATION);
-
                 recuope.load();
                 SKGTEST(QStringLiteral("RECOP:exist"), static_cast<unsigned int>(recuope.exist()), static_cast<unsigned int>(true))
 
@@ -483,8 +471,6 @@ int main(int argc, char **argv)
                 SKGOperationObject firstOp(recopsP.first());
                 removeOperation(firstOp);
 
-                document1.dump(DUMPOPERATION);
-
                 recuope.load();
                 SKGTEST(QStringLiteral("RECOP:exist"), static_cast<unsigned int>(recuope.exist()), static_cast<unsigned int>(true))
 
@@ -529,8 +515,6 @@ int main(int argc, char **argv)
                 SKGTESTERROR(QStringLiteral("RECOP:getRecurredOperations"), recuope.getRecurredOperations(recopsP), true)
                 SKGTEST(QStringLiteral("RECOP:recopsP.count"), recopsP.count(), !!newTemplateState && !sourceOperationIsTemplate ? 1 : 0)
 
-                document1.dump(DUMPOPERATION);
-
                 removeAllScheduled(recuope);
                 testDocumentIsEmpty();
             }
@@ -560,8 +544,6 @@ int main(int argc, char **argv)
                 SKGTESTERROR(QStringLiteral("RECOP:getRecurredOperations"), recuope.getRecurredOperations(recopsP), true)
                 SKGTEST(QStringLiteral("RECOP:recopsP.count"), recopsP.count(), !sourceOperationIsTemplate ? (!!newTemplateState ? 2 : 1) : 0)
 
-                document1.dump(DUMPOPERATION);
-
                 removeAllScheduled(recuope);
                 testDocumentIsEmpty();
             }
@@ -577,6 +559,63 @@ int main(int argc, char **argv)
         }
     }
 
+    // 491382
+    {
+        struct TestDataAdapter {
+            QDate previousDate;
+            int increment;
+            SKGRecurrentOperationObject::Adapter adapter;
+            QDate expectedNextDate;
+        };
+
+        std::vector<TestDataAdapter> testDataAdapterSet{
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::NONE, QDate(2025, 10, 18)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::PREVIOUS_MONDAY, QDate(2025, 10, 13)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::PREVIOUS_TUESDAY, QDate(2025, 10, 14)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::PREVIOUS_WEDNESDAY, QDate(2025, 10, 15)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::PREVIOUS_THURSDAY, QDate(2025, 10, 16)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::PREVIOUS_FRIDAY, QDate(2025, 10, 17)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::PREVIOUS_SATURDAY, QDate(2025, 10, 18)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::PREVIOUS_SUNDAY, QDate(2025, 10, 12)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::CLOSEST_MONDAY, QDate(2025, 10, 20)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::CLOSEST_TUESDAY, QDate(2025, 10, 21)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::CLOSEST_WEDNESDAY, QDate(2025, 10, 15)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::CLOSEST_THURSDAY, QDate(2025, 10, 16)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::CLOSEST_FRIDAY, QDate(2025, 10, 17)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::CLOSEST_SATURDAY, QDate(2025, 10, 18)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::CLOSEST_SUNDAY, QDate(2025, 10, 19)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::NEXT_MONDAY, QDate(2025, 10, 20)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::NEXT_TUESDAY, QDate(2025, 10, 21)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::NEXT_WEDNESDAY, QDate(2025, 10, 22)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::NEXT_THURSDAY, QDate(2025, 10, 23)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::NEXT_FRIDAY, QDate(2025, 10, 24)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::NEXT_SATURDAY, QDate(2025, 10, 18)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::NEXT_SUNDAY, QDate(2025, 10, 19)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::PREVIOUS_OPEN_DAY, QDate(2025, 10, 17)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::CLOSEST_OPEN_DAY, QDate(2025, 10, 17)},
+            {QDate(2025, 10, 11), 7, SKGRecurrentOperationObject::NEXT_OPEN_DAY, QDate(2025, 10, 20)},
+            {QDate(2025, 10, 11), 1, SKGRecurrentOperationObject::PREVIOUS_MONDAY, QDate(2025, 10, 12)}, // Adapter can not be applied
+            {QDate(2025, 10, 1), 31, SKGRecurrentOperationObject::FIRST_OPEN_DAY_OF_MONTH, QDate(2025, 11, 3)},
+        };
+
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
+        for (const auto &t : testDataAdapterSet) {
+            SKGRecurrentOperationObject recuope(&document1, 1);
+            recuope.setPeriodIncrement(t.increment);
+            recuope.setPeriodUnit(SKGRecurrentOperationObject::DAY);
+            recuope.setDate(t.previousDate);
+            recuope.setAdapter(t.adapter);
+            SKGTEST(QStringLiteral("RECOP:getNextDate ") % SKGServices::intToString(t.adapter), recuope.getNextDate().toString(), t.expectedNextDate.toString())
+        }
+
+        SKGRecurrentOperationObject recuope(&document1, 1);
+        recuope.setPeriodIncrement(1);
+        recuope.setPeriodUnit(SKGRecurrentOperationObject::MONTH);
+        recuope.setDate(QDate(2025, 2, 1));
+        recuope.setAdapter(SKGRecurrentOperationObject::NEXT_OPEN_DAY);
+        SKGTEST(QStringLiteral("RECOP:getNextDate "), recuope.getNextDate().toString(), QDate(2025, 3, 3).toString())
+    }
     // End test
     SKGENDTEST()
 }
