@@ -23,9 +23,9 @@ void SKGTESTWidgetCollection::Test()
     KLocalizedString::setApplicationDomain("skrooge");
 
     SKGWidgetCollectionDesignerPlugin col(this);
-    QList<QDesignerCustomWidgetInterface*> widgets = col.customWidgets();
+    QList<QDesignerCustomWidgetInterface *> widgets = col.customWidgets();
     for (int i = 0; i < widgets.count(); ++i) {
-        QDesignerCustomWidgetInterface* widget = widgets.at(i);
+        QDesignerCustomWidgetInterface *widget = widgets.at(i);
         QCOMPARE(widget != nullptr, true);
 
         widget->isContainer();
@@ -33,12 +33,12 @@ void SKGTESTWidgetCollection::Test()
         widget->initialize(nullptr);
         QCOMPARE(widget->isInitialized(), true);
         widget->icon();
-        QCOMPARE(widget->domXml() != QLatin1String(""), true);
-        QCOMPARE(widget->group(), QLatin1String("SKG Widgets"));
-        QCOMPARE(widget->includeFile() != QLatin1String(""), true);
-        QCOMPARE(widget->name() != QLatin1String(""), true);
-        QCOMPARE(widget->toolTip() != QLatin1String(""), true);
-        QCOMPARE(widget->whatsThis() != QLatin1String(""), true);
+        QCOMPARE(widget->domXml() != QString(), true);
+        QCOMPARE(widget->group(), QStringLiteral("SKG Widgets"));
+        QCOMPARE(widget->includeFile() != QString(), true);
+        QCOMPARE(widget->name() != QString(), true);
+        QCOMPARE(widget->toolTip() != QString(), true);
+        QCOMPARE(widget->whatsThis() != QString(), true);
         QCOMPARE(widget->createWidget(nullptr) != nullptr, true);
     }
 
@@ -52,12 +52,11 @@ void SKGTESTWidgetCollection::Test()
     SKGWebView web(nullptr);
     web.onZoomIn();
     web.onZoomOut();
-    web.exportInFile(SKGTest::getTestPath(QLatin1String("OUT")) % "/skgtestwidgetcollection/export.pdf");
-    web.exportInFile(SKGTest::getTestPath(QLatin1String("OUT")) % "/skgtestwidgetcollection/export.html");
-    web.exportInFile(SKGTest::getTestPath(QLatin1String("OUT")) % "/skgtestwidgetcollection/export.jpg");
+    web.exportInFile(SKGTest::getTestPath(QStringLiteral("OUT")) % "/skgtestwidgetcollection/export.pdf");
+    web.exportInFile(SKGTest::getTestPath(QStringLiteral("OUT")) % "/skgtestwidgetcollection/export.html");
+    web.exportInFile(SKGTest::getTestPath(QStringLiteral("OUT")) % "/skgtestwidgetcollection/export.jpg");
 
     SKGGraphicsScene graphScene;
 }
 
 QTEST_MAIN(SKGTESTWidgetCollection)
-
