@@ -810,7 +810,7 @@ void test_stringToSearchCriterias(int &nberror, int &nbcheck, bool showonlyfailu
                                                       QStringList() << QStringLiteral("t_comment"),
                                                       nullptr,
                                                       true),
-            QStringLiteral("(((t_comment:v3) and ((t_comment:v1) and (t_comment:v2))) and not (t_comment:v4)) and not (t_comment:v5)"));
+            QStringLiteral("(((t_comment:v3) or ((t_comment:v1) and (t_comment:v2))) and not (t_comment:v4)) and not (t_comment:v5)"));
 
     SKGTEST(QStringLiteral("STR:searchCriteriasToWhereClause"),
             SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(QStringLiteral("-v5")),
@@ -934,6 +934,9 @@ int main(int argc, char **argv)
 
         QByteArray tmp;
         SKGTESTERROR(QStringLiteral("STR:downloadToStream"), SKGServices::downloadToStream(QUrl::fromLocalFile(QStringLiteral("notfound")), tmp), false)
+        SKGTESTERROR(QStringLiteral("STR:downloadToStream"),
+                     SKGServices::downloadToStream(QUrl::fromUserInput(QStringLiteral("https://skrooge.org/skgtestimporturl/test.skg")), tmp),
+                     true)
 
         SKGTEST(QStringLiteral("STR:getFullPathCommandLine"),
                 SKGServices::getFullPathCommandLine(QStringLiteral("skrooge-release.py --help")),
